<?php

namespace app\components\filters;

use Yii;
use yii\filters\AccessControl;
use yii\web\ForbiddenHttpException;

/**
 * Class AppAccessControl
 */
class AppAccessControl extends AccessControl
{
    /**
     * @inheritdoc
     */
    public $except = [
        'user/*',
        'debug/*',
        'gii/*',
    ];

    /**
     * @inheritdoc
     * @throws \yii\web\ForbiddenHttpException
     */
    public function init()
    {
        $this->denyCallback = function () {
            if ($this->user->getIsGuest()) {
                $this->user->loginRequired();
            } else {
                throw new ForbiddenHttpException(Yii::t('app', 'Não tem permissão neste momento para aceder a esta opção.'));
            }
        };

        $this->rules = [
            [
                'allow' => true,
                'roles' => ['admin'],
                'controllers' => [
                    'nationality',
                    'document-type',
                    'zone1',
                    'zone2',
                    'zone3',
                    'organization-region',
                    'education',
                    'vocation-skill-type',
                    'event-kind',
                    'skill',
                    'cluster',
                    'entity-scope',
                    'cycle',
                    'event',
                    'login',
                ],
            ],
            [
                'allow' => true,
                'roles' => ['admin', 'assistant'],
                'controllers' => [
                    'entity',
                    'participant',
                    'venue-section',
                    'event-skill',
                    'event-participant',
                    'access-manager',
                ],
            ],
            [
                'allow' => true,
                'roles' => ['admin', 'assistant', 'user'],
                'controllers' => [
                    'zone',
                    'site',
                    'participant-profile',
                    'platform-manager',
                    'gridview/*',
                ],
            ],
        ];

        parent::init();
    }
}
