<?php

namespace app\components\metronic;

use yii\web\AssetBundle;

/**
 * Class MetronicAssetBundle
 */
class MetronicAssetBundle extends AssetBundle
{
    const EMPTY_ASSET = 'N0/@$$3T$';
    const EMPTY_PATH = 'N0/P@T#';
    const BASE_ASSET = 'K3/@$$3T$';
    const BASE_PATH = 'K3/P@T#';

    /* @inheritdoc */
    public $sourcePath = self::BASE_PATH;

    /* @inheritdoc */
    public $js = self::BASE_ASSET;

    /* @inheritdoc */
    public $css = self::BASE_ASSET;

    /* @inheritdoc */
    public $depends = [
        'yii\web\JqueryAsset',
        'yii\bootstrap\BootstrapAsset',
        'app\components\metronic\MetronicAsset',
    ];

    /**
     * @inheritdoc
     */
    public function init()
    {
        parent::init();
        if ($this->js === self::BASE_ASSET) {
            $this->js = [];
        }
        if ($this->css === self::BASE_ASSET) {
            $this->css = [];
        }
        if ($this->sourcePath === self::BASE_PATH) {
            $this->sourcePath = null;
        }
    }

    /**
     * Set up CSS and JS asset arrays based on the base-file names
     *
     * @param string $type whether 'css' or 'js'
     * @param array $files the list of 'css' or 'js' basefile names
     */
    protected function setupAssets($type, $files = [])
    {
        if ($this->$type === self::EMPTY_ASSET) {
            $this->$type = [];
        } else {
            $srcFiles = [];
            $minFiles = [];
            foreach ($files as $file) {
                $srcFiles[] = "{$file}.{$type}";
                $minFiles[] = "{$file}.min.{$type}";
            }

            $arrFiles = YII_DEBUG ? $srcFiles : $minFiles;
            if ($this->$type === self::BASE_ASSET) {
                $this->$type = $arrFiles;
            } else {
                $this->$type = array_merge($arrFiles, $this->$type);
            }
        }
    }

    /**
     * Sets the source path if empty
     *
     * @param string $path the path to be set
     */
    protected function setSourcePath($path)
    {
        if ($this->sourcePath === self::BASE_PATH) {
            $this->sourcePath = $path;
        } elseif ($this->sourcePath === self::EMPTY_PATH) {
            $this->sourcePath = null;
        }
    }
}
