<?php

namespace app\components\metronic\widgets;

use Yii;
use yii\helpers\ArrayHelper;
use yii\helpers\Html;
use yii\helpers\Url;
use yii\widgets\Menu;

/**
 * Class SidebarMenu
 */
class SidebarMenu extends Menu
{
    /*
     * Page sidebar options
     */

    const PAGE_SIDEBAR_OPTION_DATA_AUTO_SCROLL = 'data-auto-scroll';
    const PAGE_SIDEBAR_OPTION_DATA_AUTO_SPEED = 'data-auto-speed';

    /*
     * Page sidebar menu classes
     */
    const PAGE_SIDEBAR_MENU_LIGHT = 'page-sidebar-menu-light';
    const PAGE_SIDEBAR_MENU_HOVER_SUBMENU = 'page-sidebar-menu-hover-submenu';
    const PAGE_SIDEBAR_MENU_CLISED = 'page-sidebar-menu-closed';

    /*
     * Page sidebar menu options
     */
    const PAGE_SIDEBAR_MENU_OPTION_DATA_AUTO_SCROLL = 'data-auto-scroll';
    const PAGE_SIDEBAR_MENU_OPTION_DATA_KEEP_EXPAND = 'data-keep-expand';
    const PAGE_SIDEBAR_MENU_OPTION_DATA_AUTO_SPEED = 'data-auto-speed';
    const PAGE_SIDEBAR_MENU_OPTION_DATA_SLIDE_SPEED = 'data-slide-speed';

    /* @inheritdoc */
    public $firstItemCssClass = 'start';

    /* @inheritdoc */
    public $lastItemCssClass = 'last';

    /* @inheritdoc */
    public $submenuTemplate = "\n<ul class='sub-menu'>\n{items}\n</ul>\n";

    /* @inheritdoc */
    public $linkTemplate = '{icon} {badge} {label} {arrow}';

    /* @var array */
    public $pageSidebarOptions = [];

    /* @var array */
    public $pageSidebarMenuOptions = [];

    /**
     * @inheritdoc
     */
    public function init()
    {
        parent::init();
        $this->initOptions();
    }

    /**
     * @inheritdoc
     *
     * @SuppressWarnings(PHPMD.UnusedLocalVariable)
     */
    public function run()
    {
        echo Html::beginTag('div', $this->options) . "\n";
        echo Html::beginTag('div', $this->pageSidebarOptions) . "\n";

        if ($this->route === null && Yii::$app->controller !== null) {
            $this->route = Yii::$app->controller->getRoute();
        }
        if ($this->params === null) {
            $this->params = Yii::$app->request->getQueryParams();
        }
        $items = $this->normalizeItems($this->items, $hasActiveChild);
        if (!empty($items)) {
            $tag = ArrayHelper::remove($this->pageSidebarMenuOptions, 'tag', 'ul');

            if ($tag !== false) {
                echo Html::tag($tag, $this->renderItems($items), $this->pageSidebarMenuOptions);
            } else {
                echo $this->renderItems($items);
            }
        }

        echo Html::endTag('div') . "\n";
        echo Html::endTag('div') . "\n";
    }

    /**
     * @inheritdoc
     */
    protected function renderItem($item)
    {
        $linkContent = strtr(ArrayHelper::getValue($item, 'template', $this->linkTemplate), [
            '{label}' => $this->pullItemLabel($item),
            '{icon}' => $this->pullItemIcon($item),
            '{arrow}' => $this->pullItemArrow($item),
            '{badge}' => $this->pullItemBadge($item),
        ]);

        $item = ArrayHelper::merge($item, ['linkOptions' => ['class' => 'nav-link nav-toggle']]);

        return Html::a($linkContent, $this->pullItemUrl($item), $item['linkOptions']);
    }

    /**
     *
     */
    private function initOptions()
    {
        if (!isset($this->pageSidebarMenuOptions['data-keep-expand'])) {
            $this->pageSidebarMenuOptions['data-keep-expand'] = 'false';
        }
        if (!isset($this->pageSidebarMenuOptions['data-auto-scroll'])) {
            $this->pageSidebarMenuOptions['data-auto-scroll'] = 'true';
        }
        if (!isset($this->pageSidebarMenuOptions['data-slide-speed'])) {
            $this->pageSidebarMenuOptions['data-slide-speed'] = '200';
        }

        Html::addCssClass($this->options, 'page-sidebar-wrapper');
        Html::addCssClass($this->pageSidebarOptions, ['page-sidebar', 'navbar-collapse', 'collapse']);
        Html::addCssClass($this->pageSidebarMenuOptions, ['page-sidebar-menu']);
    }

    /**
     * @param $item
     *
     * @return string
     */
    private function pullItemUrl($item)
    {
        $url = ArrayHelper::getValue($item, 'url', '#');

        if ('#' === $url) {
            return 'javascript:;';
        }

        return Url::to($item['url']);
    }

    /**
     * @param $item
     *
     * @return string
     */
    private function pullItemLabel($item)
    {
        $label = ArrayHelper::getValue($item, 'label', '');
        $level = ArrayHelper::getValue($item, 'level', 1);
        if (1 == $level) {
            return Html::tag('span', $label, ['class' => 'title']);
        }

        return sprintf(' %s', $label);
    }

    /**
     * @param $item
     *
     * @return string
     */
    private function pullItemIcon($item)
    {
        $icon = ArrayHelper::getValue($item, 'icon', null);
        if ($icon) {
            return Html::tag('i', '', ['class' => $icon]);
        }

        return '';
    }

    /**
     * @param $item
     *
     * @return string
     */
    private function pullItemArrow($item)
    {
        $active = ArrayHelper::getValue($item, 'active', false);
        $items = ArrayHelper::getValue($item, 'items', []);

        if (!empty($items)) {
            return Html::tag('span', '', ['class' => 'arrow' . ($active ? ' open' : '')]);
        }

        if ($active) {
            return Html::tag('span', '', ['class' => 'selected']);
        }

        return '';
    }

    /**
     * @param $item
     *
     * @throws \Exception
     * @return string
     */
    private function pullItemBadge($item)
    {
        if (!isset($item['badge']) || $item['badge'] === null) {
            return '';
        }

        return Badge::widget($item['badge']);
    }

    /**
     * @inheritdoc
     */
    public static function widget($config = [])
    {
        $cache = Yii::$app->get('cache', false);
        $cacheKey = __CLASS__;
        $hash = md5(json_encode($config));
        if (!YII_DEBUG && ($data = $cache->get($cacheKey)) !== false && isset($data[1]) && $data[1] === $hash) {
            $widget = $data[0];
        } else {
            $widget = parent::widget($config);
            $cache->set($cacheKey, [$widget, $hash], 600);
        }

        return $widget;
    }
}
