<?php

namespace app\controllers;

use app\models\Entity;
use app\models\search\EntitySearch;
use app\models\Zone2;
use app\models\Zone3;
use Yii;
use yii\web\NotFoundHttpException;
use yii\web\Response;

/**
 * EntityController implements the CRUD actions for Entity model.
 */
class EntityController extends MainController
{
    /**
     * Lists all Entity models.
     * @return mixed
     */
    public function actionIndex()
    {
        $searchModel = new EntitySearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single Entity model.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new Entity model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        $model = new Entity();

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            return $this->redirect(['view', 'id' => $model->id_entity]);
        }

        return $this->render('create', [
            'model' => $model,
        ]);
    }

    /**
     * Updates an existing Entity model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate($id)
    {
        $model = $this->findModel($id);

        $post = Yii::$app->request->post();
        if ($model->load($post) && $model->save()) {
            return $this->redirect(['view', 'id' => $model->id_entity]);
        }

        return $this->render('update', [
            'model' => $model,
        ]);
    }

    /**
     * Deletes an existing Entity model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionDelete($id)
    {
        $this->findModel($id)->delete();

        return $this->redirect(['index']);
    }

    /**
     * @param integer $id_zone1
     * @return array
     * @throws \yii\db\Exception
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionZone2($id_zone1)
    {
        Yii::$app->response->format = Response::FORMAT_JSON;

        return Zone2::find()
            ->select(['id_zone2', 'name' => new \yii\db\Expression('CONCAT("ID:",id_zone2,\' - \',name)')])
            ->andWhere(['id_zone1' => $id_zone1])
            ->createCommand()
            ->queryAll(\PDO::FETCH_KEY_PAIR);
    }

    /**
     * @param integer $id_zone2
     * @return array
     * @throws \yii\db\Exception
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionZone3($id_zone2)
    {
        Yii::$app->response->format = Response::FORMAT_JSON;

        return Zone3::find()
            ->select(['id_zone3', 'name' => new \yii\db\Expression('CONCAT("ID:",id_zone3,\' - \',name)')])
            ->andWhere(['id_zone2' => $id_zone2])
            ->createCommand()
            ->queryAll(\PDO::FETCH_KEY_PAIR);
    }

    /**
     * Finds the Entity model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return Entity the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = Entity::findOne($id)) !== null) {
            return $model;
        }

        throw new NotFoundHttpException(Yii::t('app', 'The requested page does not exist.'));
    }
}
