<?php

namespace app\controllers;

use app\models\EventParticipant;
use app\models\Participant;
use app\models\search\EventParticipantSearch;
use app\models\search\EventParticipantViewSearch;
use Yii;
use yii\web\NotFoundHttpException;
use yii\web\Response;

/**
 * EventParticipantController implements the CRUD actions for EventParticipant model.
 */
class EventParticipantController extends MainController
{
    /**
     * Lists all EventParticipant models.
     * @return mixed
     */
    public function actionIndex()
    {
        $searchModel = new EventParticipantSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Lists all EventParticipant models only for view.
     * @return mixed
     */
    public function actionIndexView()
    {
        $searchModel = new EventParticipantViewSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        return $this->render('index-view', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single EventParticipant model.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new EventParticipant model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        $model = new EventParticipant();

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            return $this->redirect(['view', 'id' => $model->id_event_participant]);
        }

        return $this->render('create', [
            'model' => $model,
        ]);
    }

    /**
     * Updates an existing EventParticipant model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate($id)
    {
        $model = $this->findModel($id);

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            return $this->redirect(['view', 'id' => $model->id_event_participant]);
        }

        return $this->render('update', [
            'model' => $model,
        ]);
    }

    /**
     * Deletes an existing EventParticipant model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionDelete($id)
    {
        $eventParticipant = $this->findModel($id);
        $id_event = $eventParticipant->eventSkill->id_event;

        $eventParticipant->delete();

        return $this->redirect(['index', 'EventParticipantSearch' => ['id_event' => $id_event]]);
    }

    /**
     * Finds the EventParticipant model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return EventParticipant the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = EventParticipant::findOne($id)) !== null) {
            return $model;
        }

        throw new NotFoundHttpException(Yii::t('app', 'The requested page does not exist.'));
    }

    public function actionEntity($id_participant)
    {
        Yii::$app->response->format = Response::FORMAT_JSON;

        return Participant::find()
            ->select('id_entity_current')
            ->andWhere(['id_participant' => $id_participant])
            ->scalar() ?: '';
    }
}
