<?php

namespace app\controllers;

use app\models\EventSkill;
use app\models\search\EventSkillSearch;
use app\models\Skill;
use app\models\VenueSection;
use Yii;
use yii\web\NotFoundHttpException;
use yii\web\Response;

/**
 * EventSkillController implements the CRUD actions for EventSkill model.
 */
class EventSkillController extends MainController
{
    /**
     * Lists all EventSkill models.
     * @return mixed
     */
    public function actionIndex()
    {
        $searchModel = new EventSkillSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single EventSkill model.
     * @param string $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new EventSkill model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate($id_event)
    {
        $model = new EventSkill(['id_event' => $id_event]);

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            return $this->redirect(['view', 'id' => $model->id_event_skill]);
        }

        return $this->render('create', [
            'model' => $model,
        ]);
    }

    /**
     * Updates an existing EventSkill model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param string $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate($id)
    {
        $model = $this->findModel($id);

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            return $this->redirect(['view', 'id' => $model->id_event_skill]);
        }

        return $this->render('update', [
            'model' => $model,
        ]);
    }

    /**
     * Deletes an existing EventSkill model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param string $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionDelete($id)
    {
        $this->findModel($id)->delete();

        return $this->redirect(['index']);
    }

    /**
     * Finds the EventSkill model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param string $id
     * @return EventSkill the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = EventSkill::findOne($id)) !== null) {
            return $model;
        }

        throw new NotFoundHttpException(Yii::t('app', 'The requested page does not exist.'));
    }

    public function actionVenues($id_event)
    {
        Yii::$app->response->format = Response::FORMAT_JSON;

        return VenueSection::find()
            ->select(['id_venue_section', 'name' => new \yii\db\Expression('CONCAT("ID:",id_venue_section,\' - \',name)')])
            ->andWhere(['id_event' => $id_event])
            ->createCommand()
            ->queryAll(\PDO::FETCH_KEY_PAIR);
    }

    public function actionCluster($id_skill)
    {
        Yii::$app->response->format = Response::FORMAT_JSON;

        return Skill::find()
            ->select('id_cluster')
            ->andWhere(['id_skill' => $id_skill])
            ->scalar() ?: '';
    }
}
