<?php

namespace app\controllers;

use app\models\Login;
use app\models\LoginForm;
use app\models\Participant;
use app\models\search\LoginSearch;
use Yii;
use yii\web\NotFoundHttpException;

/**
 * LoginController implements the CRUD actions for Login model.
 */
class LoginController extends MainController
{
    /**
     * Lists all Login models.
     * @return mixed
     */
    public function actionIndex()
    {
        $searchModel = new LoginSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single Login model.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Updates an existing Login model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate($id)
    {
        $model = new LoginForm($this->findModel($id));

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            return $this->redirect(['view', 'id' => $model->login->id_login]);
        }

        return $this->render('update', [
            'model' => $model,
        ]);
    }

    public function actionCreateLogin($id)
    {
        $participant = Participant::findOne($id);

        if (!$participant) {
            throw new NotFoundHttpException(Yii::t('app', 'The requested page does not exist.'));
        }

        if ($participant->createLogin()) {
            Yii::$app->getSession()->setFlash('success', Yii::t('app', 'Password gerada com sucesso e enviada para o email do participante.'));
        } else {
            Yii::$app->getSession()->setFlash('danger', Yii::t('app', 'Ocorreu um erro ao gerar password do participante.'));
        }

        return $this->redirect(['index']);
    }

    /**
     * Finds the Login model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return Login the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = Login::findOne($id)) !== null) {
            return $model;
        }

        throw new NotFoundHttpException(Yii::t('app', 'The requested page does not exist.'));
    }
}
