<?php

namespace app\controllers;

use app\helpers\ActiveForm;
use app\models\Participant;
use app\models\search\ParticipantManagedSearch;
use app\models\UploadPictureForm;
use Yii;
use yii\filters\AccessControl;
use yii\helpers\ArrayHelper;
use yii\web\ForbiddenHttpException;
use yii\web\NotFoundHttpException;
use yii\web\Response;
use yii\web\UploadedFile;

/**
 * PlatformManagerController implements the CRUD actions for Participant model.
 */
class PlatformManagerController extends MainController
{
    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::className(),
                'rules' => [
                    [
                        'allow' => Yii::$app->user->identity->participant->canManagePlatform(),
                        'denyCallback' => function () {
                            throw new
                            ForbiddenHttpException(Yii::t('app', 'Não tem permissão neste momento para aceder a esta opção (para mais informações contacte o secretariado)'));
                        },
                    ],
                ],
            ],
        ];
    }

//    /**
//     * @return mixed
//     * @throws \yii\base\InvalidParamException
//     */
//    public function actionEntities()
//    {
//        $searchModel = new EntitySearch();
//        $params = Yii::$app->request->queryParams;
//        $params['EntitySearch']['id_participant_platform_manager'] = Yii::$app->user->identity->participant->id_participant;
//        $dataProvider = $searchModel->search($params);
//
//        return $this->render('entities', [
//            'searchModel' => $searchModel,
//            'dataProvider' => $dataProvider,
//        ]);
//    }

    /**
     * @return mixed
     * @throws \yii\base\InvalidParamException
     */
    public function actionParticipants()
    {
        $platformManager = Yii::$app->user->identity->participant;
        $searchModel = new ParticipantManagedSearch($platformManager);
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        return $this->render('participants', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
            'platformManager' => $platformManager,
        ]);
    }

    public function actionViewParticipant($id)
    {
        return $this->render('view-participant', [
            'model' => $this->findParticipant($id),
        ]);
    }

    /**
     * Updates an existing Participant model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     * @throws \yii\db\Exception
     * @throws \yii\base\InvalidParamException
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdateParticipant($id)
    {
        $model = $this->findParticipant($id);

        if (Yii::$app->request->isAjax && $model->load(Yii::$app->request->post())) {
            Yii::$app->response->format = Response::FORMAT_JSON;
            return ActiveForm::validate($model);
        }

        if ($model->load(Yii::$app->request->post())) {
            $transaction = Yii::$app->db->beginTransaction();

            try {
                if ($model->save() & $model->saveImageRightFile(UploadedFile::getInstance($model, 'image_rights_file'))) {
                    $transaction->commit();

                    return $this->redirect(['view-participant', 'id' => $id, 'id_entity' => ArrayHelper::getValue(Yii::$app->request->queryParams, 'id_entity')]);
                }

            } catch (\Exception $e) {
                $transaction->rollBack();

                Yii::$app->getSession()->setFlash('danger', $e->getMessage());
            }
        }

        return $this->render('update-participant', [
            'model' => $model,
        ]);
    }

    public function actionUploadPicture($id)
    {
        $model = new UploadPictureForm(['participant' => $this->findParticipant($id)]);

        if ($model->load(Yii::$app->request->post())) {
            $model->picture = UploadedFile::getInstance($model, 'picture');
            if ($model->upload()) {
                Yii::$app->getSession()->setFlash('success', Yii::t('app', 'Foto atualizada com sucesso.'));
            }
        }

        return $this->render('upload-picture', [
            'model' => $model,
        ]);
    }

    public function actionPicture($id, $sizeBig = 1)
    {
        $model = new UploadPictureForm(['participant' => $this->findParticipant($id)]);
        $filePath = $model->filePath((bool)$sizeBig);

        return $filePath ? Yii::$app->response->sendFile($filePath) : '';
    }

    public function actionImageRights($id)
    {
        $model = $this->findParticipant($id);
        $filePath = $model->imageRightsFilePath();

        return $filePath ? Yii::$app->response->sendFile($filePath) : '';
    }

    public function actionDeletePicture($id)
    {
        $this->findParticipant($id)->deletePicture();

        return $this->redirect(['upload-picture', 'id' => $id]);
    }

    protected function findParticipant($id)
    {
        if (($model = Participant::findOne($id)) !== null) {
            if (!Yii::$app->user->identity->participant->canManageParticipant($model)) {
                throw new ForbiddenHttpException(Yii::t('app', 'Você não tem permissão para aceder a este participante.'));
            }

            return $model;
        }

        throw new NotFoundHttpException(Yii::t('app', 'The requested page does not exist.'));
    }
}
