<?php

namespace app\models;

use Yii;

/**
 * This is the model class for table "access_manager".
 *
 * @property int $id_access_manager
 * @property string $name
 * @property string $id_event
 * @property int $access_all_platform_manager
 * @property int $access_all_participants
 * @property int $access_restricted_logins
 * @property string $restricted_logins_list
 *
 * @property Event $event
 */
class AccessManager extends BaseModel
{
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'access_manager';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['name', 'access_all_platform_manager', 'access_all_participants', 'access_restricted_logins', 'id_event'], 'required'],
            [['access_all_platform_manager', 'access_all_participants', 'access_restricted_logins'], 'integer'],
            [['restricted_logins_list'], 'string'],
            [['name'], 'string', 'max' => 255],
            [['id_event'], 'string', 'max' => 10],
            [['id_event'], 'exist', 'skipOnError' => true, 'targetClass' => Event::className(), 'targetAttribute' => ['id_event' => 'id_event']],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id_access_manager' => Yii::t('app', 'Id Gestão de Acesso'),
            'name' => Yii::t('app', 'Nome'),
            'id_event' => Yii::t('app', 'Id_evento'),
            'access_all_platform_manager' => Yii::t('app', 'Acesso Todos Gestor Plataforma'),
            'access_all_participants' => Yii::t('app', 'Acesso Todos Participantes'),
            'access_restricted_logins' => Yii::t('app', 'Acesso Logins Restritos'),
            'restricted_logins_list' => Yii::t('app', 'Lista de Logins Restritos'),
        ];
    }
    /**
     * @inheritdoc
     */
    public function attributeHints()
    {
        return [
            'restricted_logins_list' => Yii::t('app', 'Exemplo:').'{1001}{1002}{1003}',
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getEvent()
    {
        return $this->hasOne(Event::className(), ['id_event' => 'id_event']);
    }

    /**
     * @inheritdoc
     * @return \app\models\query\AccessManagerQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new \app\models\query\AccessManagerQuery(get_called_class());
    }

    public function canDelete()
    {
        return false;
    }
}
