<?php

namespace app\models;

use Yii;

/**
 * This is the model class for table "admin_level".
 *
 * @property int $id_admin_level
 * @property string $name
 * @property int $can_admin
 * @property int $can_assistant
 * @property int $can_user
 * @property int $isAdmin
 *
 * @property Login[] $logins
 */
class AdminLevel extends BaseModel
{
    CONST ROLE_ADMIN = 1;
    CONST ROLE_ASSISTANT = 2;
    CONST ROLE_USER = 3;

    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'admin_level';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        $rules = [
            [['name'], 'required'],
            [['name'], 'string', 'max' => 255],
        ];

        foreach ($this->attributes() as $attribute) {
            if (strpos($attribute, 'can_') === 0) {
                $rules[] = [[$attribute], 'integer'];
            }
        }

        return $rules;
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id_admin_level' => Yii::t('app', 'Id Admin Level'),
            'name' => Yii::t('app', 'Nome'),
            'can_admin' => Yii::t('app', 'Can Admin'),
            'can_assistant' => Yii::t('app', 'Can Assistant'),
            'can_user' => Yii::t('app', 'Can User'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getLogins()
    {
        return $this->hasMany(Login::className(), ['id_admin_level' => 'id_admin_level']);
    }

    public function checkPermission($permission)
    {
        $roleAttribute = "can_{$permission}";
        return (bool)$this->$roleAttribute;
    }

    public static function dropdown()
    {
        static $dropdown;

        if ($dropdown === null) {
            $models = static::find()->all();
            foreach ($models as $model) {
                $dropdown[$model->id] = $model->name;
            }
        }
        return $dropdown;
    }

    public function canDelete()
    {
        return false;
    }

    public function getIsAdmin()
    {
        return $this->id_admin_level !== self::ROLE_USER;
    }
}
