<?php

namespace app\models;

use app\components\validators\NoSpaceValidator;
use Yii;

/**
 * This is the model class for table "clusters".
 *
 * @property string $id_cluster
 * @property string $name
 *
 * @property EventSkill[] $eventsSkills
 * @property Skill[] $skills
 */
class Cluster extends BaseModel
{
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'clusters';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id_cluster', 'name'], 'required'],
            [['id_cluster'], 'string', 'max' => 25],
            [['id_cluster'], NoSpaceValidator::class],
            [['name'], 'string', 'max' => 100],
            [['id_cluster'], 'unique'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id_cluster' => Yii::t('app', 'Id_cluster'),
            'name' => Yii::t('app', 'Nome'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getEventsSkills()
    {
        return $this->hasMany(EventSkill::className(), ['id_cluster' => 'id_cluster']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getSkills()
    {
        return $this->hasMany(Skill::className(), ['id_cluster' => 'id_cluster']);
    }

    /**
     * @inheritdoc
     * @return \app\models\query\ClusterQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new \app\models\query\ClusterQuery(get_called_class());
    }

    /**
     * @return bool
     */
    public function canDelete()
    {
        $canDelete = !(bool)self::find()->andWhere(['{{%clusters}}.id_cluster' => $this->id_cluster])->innerJoinWith('eventsSkills')->exists();
        $canDelete = $canDelete && !(bool)self::find()->andWhere(['{{%clusters}}.id_cluster' => $this->id_cluster])->innerJoinWith('skills')->exists();

        return $canDelete;
    }
}
