<?php

namespace app\models;

use Yii;

/**
 * This is the model class for table "cycles".
 *
 * @property int $id_cycle
 * @property string $name
 * @property string $date_start
 * @property string $date_end
 * @property int $active
 *
 * @property Event[] $events
 */
class Cycle extends BaseModel
{
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'cycles';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['name', 'date_start', 'date_end', 'active'], 'required'],
            [['date_start', 'date_end'], 'safe'],
            [['active'], 'integer'],
            [['active'], 'default', 'value' => 0],
            [['name'], 'string', 'max' => 100],
            [['date_start'], 'date', 'max' => $this->date_end, 'format' => 'php:Y-m-d'],
            [['date_end'], 'date', 'min' => $this->date_start, 'format' => 'php:Y-m-d'],
            [
                'date_start',
                'compare',
                'compareAttribute' => 'date_end',
                'operator' => '<=',
                'type' => 'date',
                'message' => Yii::t('app', 'Data Início deve ser menor ou igual à Data Fim'),
            ],
            [
                'date_end',
                'compare',
                'compareAttribute' => 'date_start',
                'operator' => '>=',
                'type' => 'date',
                'message' => Yii::t('app', 'Data Fim deve ser maior ou igual à Data Início'),
            ],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id_cycle' => Yii::t('app', 'Id_ciclo'),
            'name' => Yii::t('app', 'Nome'),
            'date_start' => Yii::t('app', 'Data Início'),
            'date_end' => Yii::t('app', 'Data Fim'),
            'active' => Yii::t('app', 'Ativo'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getEvents()
    {
        return $this->hasMany(Event::className(), ['id_cycle' => 'id_cycle']);
    }

    /**
     * @inheritdoc
     * @return \app\models\query\CycleQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new \app\models\query\CycleQuery(get_called_class());
    }

    /**
     * @return bool
     */
    public function canDelete()
    {
        return !(bool)self::find()->andWhere(['{{%cycles}}.id_cycle' => $this->id_cycle])->innerJoinWith('events')->exists();
    }
}
