<?php

namespace app\models;

use Yii;

/**
 * This is the model class for table "entities".
 *
 * @property int $id_entity
 * @property string $name
 * @property int $id_participant_platform_manager
 * @property string $address
 * @property string $city
 * @property string $postal_code
 * @property string $id_zone1
 * @property string $id_zone2
 * @property string $id_zone3
 * @property int $id_entity_scope
 * @property int $entity_is_main
 * @property int $id_entity_main
 * @property string $phone
 * @property string $email
 * @property string $direction_name
 * @property string $direction_email
 * @property string $direction_position
 * @property string $alternative_contact_name
 * @property string $alternative_contact_email
 * @property string $alternative_contact_direct_phone
 * @property string $notes
 * @property int $active
 *
 * @property Zone1 $zone1
 * @property Zone2 $zone2
 * @property Zone3 $zone3
 * @property Entity $entityMain
 * @property Entity[] $entities
 * @property EntityScope $entityScope
 * @property Participant $participantPlatformManager
 * @property EventParticipant[] $eventsParticipants
 * @property Participant[] $participants
 */
class Entity extends BaseModel
{
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'entities';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [
                [
                    'name',
                    'address',
                    'city',
                    'postal_code',
                    'entity_is_main',
                    'phone',
                    'email',
                    'direction_name',
                    'direction_email',
                    'direction_position',
                    'alternative_contact_name',
                    'alternative_contact_email',
                    'alternative_contact_direct_phone',
                    'id_participant_platform_manager',
                    'id_zone1',
                    'id_zone2',
                    'id_entity_scope',
                    'active',
                ],
                'required',
            ],
            [['phone', 'alternative_contact_direct_phone',], 'string', 'min' => 9, 'max' => 25, 'tooShort' => Yii::t('app', 'Número deve conter no mínimo 9 dígitos.')],
            [['phone', 'alternative_contact_direct_phone',], 'match', 'pattern' => '/^\s*?\d+\s*$/', 'message' => Yii::t('app', 'Informe somente números.')],
            [['id_participant_platform_manager', 'id_entity_scope', 'entity_is_main', 'id_entity_main', 'active'], 'integer'],
            [['notes'], 'string'],
            [['id_zone1', 'id_zone2', 'id_zone3'], 'default', 'value' => null],
            [['entity_is_main', 'active'], 'default', 'value' => 0],
            [['email', 'direction_email', 'alternative_contact_email'], 'email'],
            [['name', 'address', 'direction_name', 'alternative_contact_name'], 'string', 'max' => 200],
            [['city', 'email', 'direction_email', 'direction_position', 'alternative_contact_email'], 'string', 'max' => 100],
            [['postal_code', 'id_zone1', 'id_zone2', 'id_zone3'], 'string', 'max' => 25],

            [['id_zone1'], 'exist', 'skipOnError' => true, 'skipOnEmpty' => true, 'targetClass' => Zone1::className(), 'targetAttribute' => ['id_zone1' => 'id_zone1']],
            [['id_zone2'], 'exist', 'skipOnError' => true, 'skipOnEmpty' => true, 'targetClass' => Zone2::className(), 'targetAttribute' => ['id_zone2' => 'id_zone2']],
            [['id_zone3'], 'exist', 'skipOnError' => true, 'skipOnEmpty' => true, 'targetClass' => Zone3::className(), 'targetAttribute' => ['id_zone3' => 'id_zone3']],
            [['id_entity_main'], 'exist', 'skipOnError' => true, 'targetClass' => Entity::className(), 'targetAttribute' => ['id_entity_main' => 'id_entity']],
            [['id_entity_scope'], 'exist', 'skipOnError' => true, 'targetClass' => EntityScope::className(), 'targetAttribute' => ['id_entity_scope' => 'id_entity_scope']],
            [
                ['id_participant_platform_manager'],
                'exist',
                'skipOnError' => true,
                'targetClass' => Participant::className(),
                'targetAttribute' => ['id_participant_platform_manager' => 'id_participant'],
            ],
            [
                ['id_zone3'],
                'required',
                'when' => function ($model) {
                    return Zone3::find()->andWhere(['id_zone2' => $model->id_zone2])->exists();
                },
                'whenClient' => 'function (attribute, value) 
                {
                    return $("#entity-id_zone3 option[value!=\'\']").length > 0;
                }',
            ],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id_entity' => Yii::t('app', 'ID Entidade'),
            'name' => Yii::t('app', 'Nome'),
            'id_participant_platform_manager' => Yii::t('app', 'Gestor Plataforma'),
            'address' => Yii::t('app', 'Endereço'),
            'city' => Yii::t('app', 'Cidade'),
            'postal_code' => Yii::t('app', 'Código Postal'),
            'id_zone1' => Yii::t('app', 'Distrito'),
            'id_zone2' => Yii::t('app', 'Concelho'),
            'id_zone3' => Yii::t('app', 'Freguesia'),
            'id_entity_scope' => Yii::t('app', 'Tipo de Entidade'),
            'entity_is_main' => Yii::t('app', 'Entidade Principal'),
            'id_entity_main' => Yii::t('app', 'ID Entidade Principal'),
            'phone' => Yii::t('app', 'Telefone Geral'),
            'email' => Yii::t('app', 'Email Geral'),
            'direction_name' => Yii::t('app', 'Nome Direção'),
            'direction_email' => Yii::t('app', 'Email Direção'),
            'direction_position' => Yii::t('app', 'Cargo Direção'),
            'alternative_contact_name' => Yii::t('app', 'Nome Contacto Alt.'),
            'alternative_contact_email' => Yii::t('app', 'Email Contacto Alt.'),
            'alternative_contact_direct_phone' => Yii::t('app', 'Telefone Direto Cont.'),
            'notes' => Yii::t('app', 'Notas'),
            'active' => Yii::t('app', 'Ativo'),
        ];
    }

    public function attributeHints()
    {
        return [
            'direction_name' => Yii::t('app', 'Nome do responsável da direção/administração da entidade'),
            'direction_position' => Yii::t('app', 'Cargo do responsável da direção/administração da entidade'),
            'alternative_contact_name' => Yii::t('app', 'Nome da pessoa a contactar / responsável pela gestão da plataforma'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getZone1()
    {
        return $this->hasOne(Zone1::className(), ['id_zone1' => 'id_zone1']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getZone2()
    {
        return $this->hasOne(Zone2::className(), ['id_zone2' => 'id_zone2']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getZone3()
    {
        return $this->hasOne(Zone3::className(), ['id_zone3' => 'id_zone3']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getEntityMain()
    {
        return $this->hasOne(Entity::className(), ['id_entity' => 'id_entity_main']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getEntities()
    {
        return $this->hasMany(Entity::className(), ['id_entity_main' => 'id_entity']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getEntityScope()
    {
        return $this->hasOne(EntityScope::className(), ['id_entity_scope' => 'id_entity_scope']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getParticipantPlatformManager()
    {
        return $this->hasOne(Participant::className(), ['id_participant' => 'id_participant_platform_manager']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getEventsParticipants()
    {
        return $this->hasMany(EventParticipant::className(), ['id_entity' => 'id_entity']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getParticipants()
    {
        return $this->hasMany(Participant::className(), ['id_entity_current' => 'id_entity']);
    }

    /**
     * @inheritdoc
     * @return \app\models\query\EntityQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new \app\models\query\EntityQuery(get_called_class());
    }

    public function beforeSave($insert)
    {
        if (sizeof($this->zone2->zone3s) == 0) {
            $this->id_zone3 = null;
        }

        if ($this->entity_is_main) {
            $this->id_entity_main = null;
        }

        return parent::beforeSave($insert);
    }

    public function canDelete()
    {
        // TODO: Ajustar implementação.
        return true;
    }
}
