<?php

namespace app\models;

use Yii;

/**
 * This is the model class for table "entities_registration".
 *
 * @property int $id_entity_registration
 * @property int $id_event
 * @property string $name
 * @property string $adress
 * @property string $city
 * @property string $postal_code
 * @property string $id_zone1
 * @property string $id_zone2
 * @property string $id_zone3
 * @property int $id_organization_region
 * @property int $id_entity_scope
 * @property string $phone
 * @property string $email
 * @property string $direction_name
 * @property string $direction_email
 * @property string $direction_position
 * @property string $platform_manager_name
 * @property string $platform_manager_email
 * @property string $platform_manager_direct_phone
 * @property string $registered_skills
 * @property int $id_registration_status
 *
 * @property Zone1 $zone1
 * @property Zone2 $zone2
 * @property Zone3 $zone3
 * @property OrganizationRegion $organizationRegion
 * @property RegistrationStatus $registrationStatus
 */
class EntityRegistration extends BaseModel
{
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'entities_registration';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id_event', 'name', 'adress', 'city', 'postal_code', 'id_zone1', 'id_zone2', 'id_zone3', 'id_organization_region', 'id_entity_scope', 'phone', 'email', 'direction_name', 'direction_email', 'direction_position', 'platform_manager_name', 'platform_manager_email', 'platform_manager_direct_phone', 'registered_skills', 'id_registration_status'], 'required'],
            [['id_event', 'id_organization_region', 'id_entity_scope', 'id_registration_status'], 'integer'],
            [['registered_skills'], 'string'],
            [['name', 'adress', 'direction_name', 'platform_manager_name'], 'string', 'max' => 200],
            [['city', 'email', 'direction_email', 'direction_position', 'platform_manager_email'], 'string', 'max' => 100],
            [['postal_code', 'id_zone1', 'id_zone2', 'id_zone3', 'phone', 'platform_manager_direct_phone'], 'string', 'max' => 25],
            [['id_zone1'], 'exist', 'skipOnError' => true, 'targetClass' => Zone1::className(), 'targetAttribute' => ['id_zone1' => 'id_zone1']],
            [['id_zone2'], 'exist', 'skipOnError' => true, 'targetClass' => Zone2::className(), 'targetAttribute' => ['id_zone2' => 'id_zone2']],
            [['id_zone3'], 'exist', 'skipOnError' => true, 'targetClass' => Zone3::className(), 'targetAttribute' => ['id_zone3' => 'id_zone3']],
            [['id_organization_region'], 'exist', 'skipOnError' => true, 'targetClass' => OrganizationRegion::className(), 'targetAttribute' => ['id_organization_region' => 'id_organization_region']],
            [['id_registration_status'], 'exist', 'skipOnError' => true, 'targetClass' => RegistrationStatus::className(), 'targetAttribute' => ['id_registration_status' => 'id_registration_status']],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id_entity_registration' => Yii::t('app', 'Id Entity Registration'),
            'id_event' => Yii::t('app', 'Id Event'),
            'name' => Yii::t('app', 'Name'),
            'adress' => Yii::t('app', 'Adress'),
            'city' => Yii::t('app', 'City'),
            'postal_code' => Yii::t('app', 'Postal Code'),
            'id_zone1' => Yii::t('app', 'Id Zone1'),
            'id_zone2' => Yii::t('app', 'Id Zone2'),
            'id_zone3' => Yii::t('app', 'Id Zone3'),
            'id_organization_region' => Yii::t('app', 'Id Organization Region'),
            'id_entity_scope' => Yii::t('app', 'Id Entity Scope'),
            'phone' => Yii::t('app', 'Phone'),
            'email' => Yii::t('app', 'Email'),
            'direction_name' => Yii::t('app', 'Direction Name'),
            'direction_email' => Yii::t('app', 'Direction Email'),
            'direction_position' => Yii::t('app', 'Direction Position'),
            'platform_manager_name' => Yii::t('app', 'Platform Manager Name'),
            'platform_manager_email' => Yii::t('app', 'Platform Manager Email'),
            'platform_manager_direct_phone' => Yii::t('app', 'Platform Manager Direct Phone'),
            'registered_skills' => Yii::t('app', 'Registered Skills'),
            'id_registration_status' => Yii::t('app', 'Id Registration Status'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getZone1()
    {
        return $this->hasOne(Zone1::className(), ['id_zone1' => 'id_zone1']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getZone2()
    {
        return $this->hasOne(Zone2::className(), ['id_zone2' => 'id_zone2']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getZone3()
    {
        return $this->hasOne(Zone3::className(), ['id_zone3' => 'id_zone3']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getOrganizationRegion()
    {
        return $this->hasOne(OrganizationRegion::className(), ['id_organization_region' => 'id_organization_region']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getRegistrationStatus()
    {
        return $this->hasOne(RegistrationStatus::className(), ['id_registration_status' => 'id_registration_status']);
    }

    /**
     * @inheritdoc
     * @return \app\models\query\EntitiesRegistrationQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new \app\models\query\EntitiesRegistrationQuery(get_called_class());
    }

    public function canDelete()
    {
        // TODO: Ajustar
        return true;
    }
}
