<?php

namespace app\models;

use app\components\validators\NoSpaceValidator;
use Yii;

/**
 * This is the model class for table "events".
 *
 * @property string $id_event
 * @property string $name
 * @property int $id_cycle
 * @property int $id_event_kind
 * @property string $date_start
 * @property string $date_end
 * @property string $notes
 * @property int $active
 *
 * @property Cycle $cycle
 * @property EventKind $eventKind
 */
class Event extends BaseModel
{
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'events';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id_event', 'name', 'id_cycle', 'id_event_kind', 'date_start', 'date_end', 'active'], 'required'],
            [['id_event'], NoSpaceValidator::class],
            [['id_cycle', 'id_event_kind', 'active'], 'integer'],
            [['date_start', 'date_end'], 'safe'],
            [['notes'], 'string'],
            [['id_event'], 'string', 'max' => 10],
            [['name'], 'string', 'max' => 200],
            [['id_event_kind'], 'unique'],
            [['id_event'], 'unique'],
            [['id_cycle'], 'exist', 'skipOnError' => true, 'targetClass' => Cycle::className(), 'targetAttribute' => ['id_cycle' => 'id_cycle']],
            [['id_event_kind'], 'exist', 'skipOnError' => true, 'targetClass' => EventKind::className(), 'targetAttribute' => ['id_event_kind' => 'id_event_kind']],
            [['active'], 'default', 'value' => 0],
            [['date_start'], 'date', 'max' => $this->date_end, 'format' => 'php:Y-m-d'],
            [['date_end'], 'date', 'min' => $this->date_start, 'format' => 'php:Y-m-d'],
            [
                'date_start',
                'compare',
                'compareAttribute' => 'date_end',
                'operator' => '<=',
                'type' => 'date',
                'message' => Yii::t('app', 'Data Início deve ser menor ou igual à Data Fim'),
            ],
            [
                'date_end',
                'compare',
                'compareAttribute' => 'date_start',
                'operator' => '>=',
                'type' => 'date',
                'message' => Yii::t('app', 'Data Fim deve ser maior ou igual à Data Início'),
            ],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id_event' => Yii::t('app', 'Id_evento'),
            'name' => Yii::t('app', 'Nome'),
            'id_cycle' => Yii::t('app', 'id_ciclo'),
            'id_event_kind' => Yii::t('app', 'Id_tipo_evento'),
            'date_start' => Yii::t('app', 'Data Início'),
            'date_end' => Yii::t('app', 'Data Fim'),
            'notes' => Yii::t('app', 'Notas'),
            'active' => Yii::t('app', 'Ativo'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getCycle()
    {
        return $this->hasOne(Cycle::className(), ['id_cycle' => 'id_cycle']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getEventKind()
    {
        return $this->hasOne(EventKind::className(), ['id_event_kind' => 'id_event_kind']);
    }

    /**
     * @inheritdoc
     * @return \app\models\query\EventQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new \app\models\query\EventQuery(get_called_class());
    }

    public function canDelete()
    {
        // TODO: Ajustar implementação.
        return true;
    }
}
