<?php

namespace app\models;

use Yii;

/**
 * This is the model class for table "events_participants".
 *
 * @property int $id_event_participant
 * @property int $id_entity
 * @property int $id_participant
 * @property string $id_event_skill
 * @property int $id_participant_type
 * @property int $id_event_participant_state
 *
 * @property Entity $entity
 * @property EventParticipantState $eventParticipantState
 * @property EventSkill $eventSkill
 * @property Participant $participant
 * @property ParticipantType $participantType
 */
class EventParticipant extends BaseModel
{
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'events_participants';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id_entity', 'id_participant', 'id_event_skill', 'id_participant_type', 'id_event_participant_state'], 'required'],
            [['id_entity', 'id_participant', 'id_participant_type', 'id_event_participant_state'], 'integer'],
            [['id_event_skill'], 'string', 'max' => 21],
            [['id_entity'], 'exist', 'skipOnError' => true, 'targetClass' => Entity::className(), 'targetAttribute' => ['id_entity' => 'id_entity']],
            [
                ['id_event_participant_state'],
                'exist',
                'skipOnError' => true,
                'targetClass' => EventParticipantState::className(),
                'targetAttribute' => ['id_event_participant_state' => 'id_event_participant_state'],
            ],
            [['id_event_skill'], 'exist', 'skipOnError' => true, 'targetClass' => EventSkill::className(), 'targetAttribute' => ['id_event_skill' => 'id_event_skill']],
            [['id_participant'], 'exist', 'skipOnError' => true, 'targetClass' => Participant::className(), 'targetAttribute' => ['id_participant' => 'id_participant']],
            [
                ['id_participant_type'],
                'exist',
                'skipOnError' => true,
                'targetClass' => ParticipantType::className(),
                'targetAttribute' => ['id_participant_type' => 'id_participant_type'],
            ],
            [['id_event_skill'], 'exist', 'skipOnError' => true, 'targetClass' => EventSkill::className(), 'targetAttribute' => ['id_event_skill' => 'id_event_skill']],
            [['id_event_skill'], 'validateParticipantEvent'],
            [['id_participant_type'], 'validateParticipantTypeDateBirth'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id_event_participant' => Yii::t('app', 'Id_evento_participante'),
            'id_entity' => Yii::t('app', 'Id_entidade'),
            'id_participant' => Yii::t('app', 'Id_participante'),
            'id_event_skill' => Yii::t('app', 'Id_evento_profissao'),
            'id_participant_type' => Yii::t('app', 'Id_tipo_participante'),
            'id_event_participant_state' => Yii::t('app', 'Id_evento_estado_participante'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getEntity()
    {
        return $this->hasOne(Entity::className(), ['id_entity' => 'id_entity']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getEventParticipantState()
    {
        return $this->hasOne(EventParticipantState::className(), ['id_event_participant_state' => 'id_event_participant_state']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getEventSkill()
    {
        return $this->hasOne(EventSkill::className(), ['id_event_skill' => 'id_event_skill']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getParticipant()
    {
        return $this->hasOne(Participant::className(), ['id_participant' => 'id_participant']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getParticipantType()
    {
        return $this->hasOne(ParticipantType::className(), ['id_participant_type' => 'id_participant_type']);
    }

    /**
     * @inheritdoc
     * @return \app\models\query\EventParticipantQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new \app\models\query\EventParticipantQuery(get_called_class());
    }

    public function canDelete()
    {
        return $this->participant->canDelete();
    }

    public function validateParticipantEvent()
    {
        if ($this->isNewRecord) {
            $exists = self::find()->joinWith('eventSkill')
                ->andWhere([
                    '{{%events_skills}}.id_event' => $this->eventSkill->id_event,
                    '{{%events_participants}}.id_participant' => $this->id_participant,
                ])->exists();

            if ($exists) {
                $this->addError(
                    'id_event_skill',
                    Yii::t('app', 'Erro: Este participante já se encontra associado a este evento. Não é possível ter mais do que uma função por evento.')
                );
            }
        }
    }

    public function validateParticipantTypeDateBirth()
    {
        if ((int)$this->id_participant_type === 601) {
            $participanteDateBirth = $this->participant->date_birth;

            if ($participanteDateBirth < $this->eventSkill->date_born_start || $participanteDateBirth > $this->eventSkill->date_born_end) {
                $this->addError(
                    'id_participant_type',
                    Yii::t('app', 'Erro: Registo de Concorrente com idade fora dos limites definidos para a profissão. 
                    Não é permitido o registo de concorrentes nascidos fora das datas autorizadas.')
                );
            }
        }
    }
}
