<?php

namespace app\models;

use Yii;

/**
 * This is the model class for table "events_skills".
 *
 * @property string $id_event_skill
 * @property string $id_event
 * @property string $id_skill
 * @property string $name
 * @property string $id_cluster
 * @property int $id_competition_type
 * @property int $id_venue_section
 * @property string $date_born_start
 * @property string $date_born_end
 * @property string $notes
 *
 * @property EventParticipant[] $eventsParticipants
 * @property Skill $skill
 * @property VenueSection $venueSection
 * @property CompetitionType $competitionType
 * @property Cluster $cluster
 * @property Event $event
 */
class EventSkill extends BaseModel
{
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'events_skills';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id_event', 'id_skill', 'name', 'id_cluster', 'id_competition_type', 'id_venue_section', 'date_born_start', 'date_born_end'], 'required'],
            [['id_competition_type', 'id_venue_section'], 'integer'],
            [['date_born_start', 'date_born_end'], 'safe'],
            [['notes'], 'string'],
            [['id_event_skill'], 'string', 'max' => 21],
            [['id_event', 'id_skill'], 'string', 'max' => 10],
            [['name'], 'string', 'max' => 200],
            [['id_cluster'], 'string', 'max' => 25],
            [['id_event_skill'], 'unique'],
            [['id_skill'], 'exist', 'skipOnError' => true, 'targetClass' => Skill::className(), 'targetAttribute' => ['id_skill' => 'id_skill']],
            [['id_venue_section'], 'exist', 'skipOnError' => true, 'targetClass' => VenueSection::className(), 'targetAttribute' => ['id_venue_section' => 'id_venue_section']],
            [['id_competition_type'], 'exist', 'skipOnError' => true, 'targetClass' => CompetitionType::className(), 'targetAttribute' => ['id_competition_type' => 'id_competition_type']],
            [['id_cluster'], 'exist', 'skipOnError' => true, 'targetClass' => Cluster::className(), 'targetAttribute' => ['id_cluster' => 'id_cluster']],
            [['date_born_start'], 'date', 'max' => $this->date_born_end, 'format' => 'php:Y-m-d'],
            [['date_born_end'], 'date', 'min' => $this->date_born_start, 'format' => 'php:Y-m-d'],
            [
                'date_born_start',
                'compare',
                'compareAttribute' => 'date_born_end',
                'operator' => '<=',
                'type' => 'date',
                'message' => Yii::t('app', 'Data_nascimento_inicio deve ser menor ou igual à data_nascimento_fim'),
            ],
            [
                'date_born_end',
                'compare',
                'compareAttribute' => 'date_born_start',
                'operator' => '>=',
                'type' => 'date',
                'message' => Yii::t('app', 'data_nascimento_fim deve ser maior ou igual à Data_nascimento_inicio'),
            ],
            [['id_skill'], 'unique', 'targetAttribute' => ['id_event', 'id_skill'], 'message' => Yii::t('app', 'Esta profissão já foi registrada para este evento.')]
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id_event_skill' => Yii::t('app', 'Id_evento_profissao'),
            'id_event' => Yii::t('app', 'Id_evento'),
            'id_skill' => Yii::t('app', 'Id_profissao'),
            'name' => Yii::t('app', 'Nome'),
            'id_cluster' => Yii::t('app', 'Id_cluster'),
            'id_competition_type' => Yii::t('app', 'Id_tipo_competicao'),
            'id_venue_section' => Yii::t('app', 'Id_evento_seccao'),
            'date_born_start' => Yii::t('app', 'Data nascimento início'),
            'date_born_end' => Yii::t('app', 'Data nascimento fim'),
            'notes' => Yii::t('app', 'Notes'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getEventsParticipants()
    {
        return $this->hasMany(EventParticipant::className(), ['id_event_skill' => 'id_event_skill']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getEvent()
    {
        return $this->hasOne(Event::className(), ['id_event' => 'id_event']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getSkill()
    {
        return $this->hasOne(Skill::className(), ['id_skill' => 'id_skill']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getVenueSection()
    {
        return $this->hasOne(VenueSection::className(), ['id_venue_section' => 'id_venue_section']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getCompetitionType()
    {
        return $this->hasOne(CompetitionType::className(), ['id_competition_type' => 'id_competition_type']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getCluster()
    {
        return $this->hasOne(Cluster::className(), ['id_cluster' => 'id_cluster']);
    }

    /**
     * @inheritdoc
     * @return \app\models\query\EventSkillQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new \app\models\query\EventSkillQuery(get_called_class());
    }

    public function canDelete()
    {
        // TODO: Ajustar implementação.
        return true;
    }

    public function beforeSave($insert)
    {
        if ($insert) {
            $this->id_event_skill = "{$this->id_event}_{$this->id_skill}";
        }

        return parent::beforeSave($insert);
    }

    public function __set($name, $value)
    {
        if (!$this->isNewRecord && in_array($name, ['id_event_skill', 'id_event', 'id_skill'])) {
            return;
        }

        parent::__set($name, $value);
    }
}
