<?php

namespace app\models;

use Yii;
use yii\web\IdentityInterface;

/**
 * This is the model class for table "login".
 *
 * @property int $id_login
 * @property int $id_admin_level
 * @property int $status
 * @property string $password
 * @property string $auth_key
 * @property string $access_token
 * @property string $logged_in_ip
 * @property string $logged_in_at
 * @property string $created_ip
 * @property string $created_at
 * @property string $updated_at
 * @property string $banned_at
 * @property string $banned_reason
 * @property string $email_verified
 * @property boolean $isAdmin
 *
 * @property AdminLevel $adminLevel
 * @property LoginAuth[] $loginAuths
 * @property LoginToken[] $loginTokens
 * @property Participant $participant
 */
class Login extends BaseModel implements IdentityInterface
{
    const STATUS_INACTIVE = 0;

    const STATUS_ACTIVE = 1;

    const STATUS_BANNED = 2;

    public static function tableName()
    {
        return 'login';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id_login', 'id_admin_level', 'status'], 'required'],
            [['id_login', 'id_admin_level', 'status', 'email_verified'], 'integer'],
            [['logged_in_at', 'created_at', 'updated_at', 'banned_at'], 'safe'],
            [['password', 'auth_key', 'access_token', 'logged_in_ip', 'created_ip', 'banned_reason'], 'string', 'max' => 255],
            [['id_login'], 'unique'],
            [['id_admin_level'], 'exist', 'skipOnError' => true, 'targetClass' => AdminLevel::className(), 'targetAttribute' => ['id_admin_level' => 'id_admin_level']],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id_login' => Yii::t('app', 'Id_login'),
            'id_admin_level' => Yii::t('app', 'Id_nivel_administrador'),
            'status' => Yii::t('app', 'Activo'),
            'password' => Yii::t('app', 'Password'),
            'auth_key' => Yii::t('app', 'Auth Key'),
            'access_token' => Yii::t('app', 'Access Token'),
            'logged_in_ip' => Yii::t('app', 'Logged In Ip'),
            'logged_in_at' => Yii::t('app', 'Logged In At'),
            'created_ip' => Yii::t('app', 'Created Ip'),
            'created_at' => Yii::t('app', 'Created At'),
            'updated_at' => Yii::t('app', 'Updated At'),
            'banned_at' => Yii::t('app', 'Banned At'),
            'banned_reason' => Yii::t('app', 'Banned Reason'),
            'email_verified' => Yii::t('app', 'Email Verificado'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getAdminLevel()
    {
        return $this->hasOne(AdminLevel::className(), ['id_admin_level' => 'id_admin_level']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getParticipant()
    {
        return $this->hasOne(Participant::className(), ['id_login' => 'id_login']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getLoginAuths()
    {
        return $this->hasMany(LoginAuth::className(), ['id_login' => 'id_login']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getLoginTokens()
    {
        return $this->hasMany(LoginToken::className(), ['id_login' => 'id_login']);
    }

    public static function findIdentity($id)
    {
        return static::findOne($id);
    }

    public static function findIdentityByAccessToken($token, $type = null)
    {
        return static::findOne(["access_token" => $token]);
    }

    public function getId()
    {
        return $this->id_login;
    }

    public function getAuthKey()
    {
        return $this->auth_key;
    }

    public function validateAuthKey($authKey)
    {
        return $this->auth_key === $authKey;
    }

    public function validatePassword($password)
    {
        return Yii::$app->security->validatePassword($password, $this->password);
    }

    public function updateLoginMeta()
    {
        $this->logged_in_ip = Yii::$app->request->userIP;
        $this->logged_in_at = gmdate("Y-m-d H:i:s");
        return $this->save(false, ["logged_in_ip", "logged_in_at"]);
    }

    public function can($permissionName, $params = [], $allowCaching = true)
    {
        $auth = Yii::$app->getAuthManager();
        if ($auth) {
            if ($allowCaching && empty($params) && isset($this->permissionCache[$permissionName])) {
                return $this->permissionCache[$permissionName];
            }
            $access = $auth->checkAccess($this->getId(), $permissionName, $params);
            if ($allowCaching && empty($params)) {
                $this->permissionCache[$permissionName] = $access;
            }
            return $access;
        }

        return $this->adminLevel->checkPermission($permissionName);
    }

    public function canDelete()
    {
        return false;
    }

    public function getIsAdmin()
    {
        return $this->adminLevel && $this->adminLevel->isAdmin;
    }
}
