<?php

namespace app\models;

use Yii;

/**
 * This is the model class for table "login_auth".
 *
 * @property int $id_login_auth
 * @property int $id_login
 * @property string $provider
 * @property string $provider_id
 * @property string $provider_attributes
 * @property string $created_at
 * @property string $updated_at
 *
 * @property Login $login
 */
class LoginAuth extends BaseModel
{
    const TYPE_EMAIL_ACTIVATE = 1;

    const TYPE_EMAIL_CHANGE = 2;

    const TYPE_PASSWORD_RESET = 3;

    const TYPE_EMAIL_LOGIN = 4;
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'login_auth';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id_login_auth', 'provider', 'provider_id', 'provider_attributes'], 'required'],
            [['id_login_auth', 'id_login'], 'integer'],
            [['provider_attributes'], 'string'],
            [['created_at', 'updated_at'], 'safe'],
            [['provider', 'provider_id'], 'string', 'max' => 255],
            [['id_login_auth'], 'unique'],
            [['id_login'], 'exist', 'skipOnError' => true, 'targetClass' => Login::className(), 'targetAttribute' => ['id_login' => 'id_login']],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id_login_auth' => Yii::t('app', 'Id Login Auth'),
            'id_login' => Yii::t('app', 'Id Login'),
            'provider' => Yii::t('app', 'Provider'),
            'provider_id' => Yii::t('app', 'Provider ID'),
            'provider_attributes' => Yii::t('app', 'Provider Attributes'),
            'created_at' => Yii::t('app', 'Created At'),
            'updated_at' => Yii::t('app', 'Updated At'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getLogin()
    {
        return $this->hasOne(Login::className(), ['id_login' => 'id_login']);
    }
    
    public function behaviors()
    {
        return [
            'timestamp' => [
                'class' => 'yii\behaviors\TimestampBehavior',
                'value' => function ($event) {
                    return gmdate("Y-m-d H:i:s");
                },
            ],
        ];
    }

    public function setUser($userId)
    {
        $this->id_login = $userId;
        return $this;
    }

    public function setProviderAttributes($attributes)
    {
        $this->provider_attributes = json_encode($attributes);
        return $this;
    }

    public function getProviderAttributes()
    {
        return json_decode($this->provider_attributes, true);
    }

    public function canDelete()
    {
        // TODO: Ajustar implementação.
        return true;
    }
}
