<?php

namespace app\models;

use app\components\validators\NoSpaceValidator;
use Yii;
use yii\base\Model;

/**
 * LoginForm is the model behind the login form.
 *
 * @property User|null $user This property is read-only.
 *
 */
class LoginForm extends Model
{
    public $password;
    public $passwordConfirm;
    public $emailVerified;
    public $active;
    public $isAdmin;
    public $adminLevel;

    /** @var Login */
    public $login;

    public function __construct(Login $login, array $config = [])
    {
        $this->login = $login;
        $this->emailVerified = $login->email_verified;
        $this->active = $login->status;
        $this->isAdmin = $login->isAdmin;
        $this->adminLevel = $login->isAdmin ? $login->id_admin_level : null;

        parent::__construct($config);
    }

    /**
     * @return array the validation rules.
     */
    public function rules()
    {
        return [
            [['emailVerified', 'active', 'isAdmin'], 'required'],
            [
                ['adminLevel'],
                'required',
                'when' => function ($model) {
                    return $model->isAdmin;
                },
                'whenClient' => 'function (attribute, value) 
                {
                    return $(\'#loginform-isadmin\').bootstrapSwitch(\'state\');;
                }',
            ],
            ['password', 'string', 'length' => [8, 255], 'tooShort' => Yii::t('app', 'A password deve conter no mínimo 8 caracteres.')],
            ['password', 'match', 'pattern' => '/(?:[0-9][^ ]*[A-Za-z][^ ]*)|(?:[A-Za-z][^ ]*[0-9][^ ]*)/', 'message' => Yii::t('app', 'A password deve conter letras e números.')],
            ['password', NoSpaceValidator::class],
            ['passwordConfirm', 'compare', 'compareAttribute' => 'password'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'password' => Yii::t('app', 'Password'),
            'passwordConfirm' => Yii::t('app', 'Digite a password novamente'),
            'emailVerified' => Yii::t('app', 'Email Verificado'),
            'active' => Yii::t('app', 'Login Activo'),
            'isAdmin' => Yii::t('app', 'Utilizador Admin'),
            'adminLevel' => Yii::t('app', 'Nível de Admin'),
        ];
    }

    public function save()
    {
        if (!$this->validate()) {
            return false;
        }

        if ($this->password) {
            $this->login->password = Yii::$app->security->generatePasswordHash($this->password);
        }

        $this->login->email_verified = $this->emailVerified;
        $this->login->status = $this->active;
        $this->login->id_admin_level = $this->isAdmin ? $this->adminLevel : AdminLevel::ROLE_USER;

        return $this->login->save(false);
    }
}
