<?php

namespace app\models;

use Yii;

/**
 * This is the model class for table "login_token".
 *
 * @property int $id_login_token
 * @property int $id_login
 * @property int $type
 * @property string $token
 * @property string $data
 * @property string $created_at
 * @property string $expired_at
 *
 * @property Login $login
 */
class LoginToken extends BaseModel
{
    const TYPE_EMAIL_ACTIVATE = 1;

    const TYPE_EMAIL_CHANGE = 2;

    const TYPE_PASSWORD_RESET = 3;

    const TYPE_EMAIL_LOGIN = 4;

    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'login_token';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id_login_token', 'type', 'token'], 'required'],
            [['id_login_token', 'id_login', 'type'], 'integer'],
            [['created_at', 'expired_at'], 'safe'],
            [['token', 'data'], 'string', 'max' => 255],
            [['id_login_token'], 'unique'],
            [['id_login'], 'exist', 'skipOnError' => true, 'targetClass' => Login::className(), 'targetAttribute' => ['id_login' => 'id_login']],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id_login_token' => Yii::t('app', 'Id Login Token'),
            'id_login' => Yii::t('app', 'Id Login'),
            'type' => Yii::t('app', 'Type'),
            'token' => Yii::t('app', 'Token'),
            'data' => Yii::t('app', 'Data'),
            'created_at' => Yii::t('app', 'Created At'),
            'expired_at' => Yii::t('app', 'Expired At'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getLogin()
    {
        return $this->hasOne(Login::className(), ['id_login' => 'id_login']);
    }
    
    public function behaviors()
    {
        return 
        [
            'timestamp' => 
            [
                'class' => 'yii\behaviors\TimestampBehavior',
                'updatedAtAttribute' => false,
                'value' => function ($event) 
                {
                    return gmdate("Y-m-d H:i:s");
                },
            ],
        ];
    }

    public static function generate($userId, $type, $data = null, $expireTime = null)
    {
        $checkExpiration = false;
        if ($userId) 
        {
            $model = static::findByUser($userId, $type, $checkExpiration);
        }
        else
        {
            $model = static::findByData($data, $type, $checkExpiration);
        }
        if (!$model) 
        {
            $model = new static();
        }

        $model->id_login = $userId;
        $model->type = $type;
        $model->data = $data;
        $model->created_at = gmdate("Y-m-d H:i:s");
        $model->expired_at = $expireTime;
        $model->token = Yii::$app->security->generateRandomString();
        $model->save();
        return $model;
    }

    public static function findBy($field, $value, $type, $checkExpiration)
    {
        $query = static::find()->where([$field => $value, "type" => $type ]);
        if ($checkExpiration) 
        {
            $now = gmdate("Y-m-d H:i:s");
            $query->andWhere("([[expired_at]] >= '$now' or [[expired_at]] is NULL)");
        }
        return $query->one();
    }

    public static function findByUser($userId, $type, $checkExpiration = true)
    {
        return static::findBy("id_login", $userId, $type, $checkExpiration);
    }

    public static function findByToken($token, $type, $checkExpiration = true)
    {
        return static::findBy("token", $token, $type, $checkExpiration);
    }

    public static function findByData($data, $type, $checkExpiration = true)
    {
        return static::findBy("data", $data, $type, $checkExpiration);
    }

    public function canDelete()
    {
        // TODO: Ajustar implementação.
        return true;
    }
}
