<?php

namespace app\models;

use app\components\validators\NoSpaceValidator;
use app\helpers\ConstantsHelper;
use Yii;
use yii\base\InvalidCallException;
use yii\helpers\ArrayHelper;
use yii\helpers\FileHelper;
use yii\helpers\Url;
use yii\web\UploadedFile;

/**
 * This is the model class for table "participants".
 *
 * @property int $id_participant
 * @property int $id_login
 * @property string $name
 * @property string $nickname
 * @property string $email
 * @property string $email_alternative
 * @property int $id_nationality
 * @property string $date_birth
 * @property string $place_of_birth
 * @property int $id_document_type
 * @property string $identification_number
 * @property string $date_expiration
 * @property string $tax_number
 * @property string $social_security_number
 * @property string $address
 * @property string $city
 * @property string $postal_code
 * @property string $id_zone1
 * @property string $id_zone2
 * @property string $id_zone3
 * @property string $phone
 * @property string $phone_alternative
 * @property int $id_education
 * @property int $id_vocational_skills_type
 * @property string $vocational_skills
 * @property string $id_gender
 * @property string $tshirt_size
 * @property string $iban
 * @property string $extra01
 * @property string $extra02
 * @property string $extra03
 * @property string $extra04
 * @property string $extra05
 * @property string $extra06
 * @property string $extra07
 * @property string $extra08
 * @property string $extra09
 * @property string $extra10
 * @property int $dietary_restriction
 * @property int $dr01
 * @property int $dr02
 * @property int $dr03
 * @property int $dr04
 * @property int $dr05
 * @property int $dr06
 * @property int $dr07
 * @property int $dr08
 * @property string $dr_other
 * @property string $image_rights_upload
 * @property int $id_entity_current
 * @property string $notes
 * @property string $picture
 * @property int $active
 * @property boolean $isPlatformManager
 *
 * @property Entity[] $entities
 * @property EventParticipant[] $eventsParticipants
 * @property Education $education
 * @property Zone3 $zone3
 * @property Entity $entityCurrent
 * @property Gender $gender
 * @property DocumentType $documentType
 * @property Nationality $nationality
 * @property VocationSkillType $vocationalSkillsType
 * @property Zone1 $zone1
 * @property Zone2 $zone2
 * @property Login $login
 */
class Participant extends BaseModel
{
    const SCENARIO_FORM = 'scenarioForm';
    const SCENARIO_BASIC = 'scenarioBasic';

    /**
     * @var UploadedFile
     */
    public $image_rights_file;

    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'participants';
    }

    public function scenarios()
    {
        return ArrayHelper::merge(parent::scenarios(), [
            self::SCENARIO_BASIC => ['name', 'nickname', 'email', 'date_birth', 'tax_number', 'id_entity_current', 'active', 'id_gender'],
        ]);
    }


    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [
                [
                    'name',
                    'nickname',
                    'email',
                    'date_birth',
                    'place_of_birth',
                    'date_expiration',
                    'social_security_number',
                    'address',
                    'city',
                    'identification_number',
                    'tax_number',
                    'postal_code',
                    'phone',
                    'tshirt_size',
                    'id_entity_current',
                    'dietary_restriction',
                    'id_gender',
                    'active',
                    'id_nationality',
                    'id_document_type',
                    'id_zone1',
                    'id_zone2',
                    'id_education',
                    'id_vocational_skills_type',
                ],
                'required',
            ],
            [['image_rights_upload',], 'required', 'on' => self::SCENARIO_FORM],
            [['id_login', 'id_nationality', 'id_document_type', 'id_education', 'id_vocational_skills_type', 'dietary_restriction', 'id_entity_current', 'active'], 'integer'],
            [['date_birth', 'date_expiration', 'dr01', 'dr02', 'dr03', 'dr04', 'dr05', 'dr06', 'dr07', 'dr08'], 'safe'],
            [['notes'], 'string'],
            ['iban', 'string', 'skipOnEmpty' => true, 'length' => 25, 'on' => self::SCENARIO_FORM],
            ['iban', NoSpaceValidator::class, 'skipOnEmpty' => true],
            ['dietary_restriction', 'default', 'value' => 0],
            [['identification_number', 'tax_number'], 'unique'],
            [['name', 'address'], 'string', 'max' => 200],
            [['nickname'], 'string', 'max' => 50],
            [['image_rights_upload'], 'string', 'max' => 100],
            [['email', 'email_alternative'], 'email'],
            [['email', 'email_alternative', 'place_of_birth', 'city', 'vocational_skills', 'extra01', 'extra02', 'extra03', 'extra04', 'extra05', 'extra06', 'extra07', 'extra08', 'extra09', 'extra10', 'dr_other', 'picture'], 'string', 'max' => 100],
            [['identification_number', 'tax_number', 'social_security_number', 'postal_code', 'id_zone1', 'id_zone2', 'id_zone3', 'phone', 'phone_alternative', 'tshirt_size'], 'string', 'max' => 25],
            [['id_gender'], 'string', 'max' => 1],
            [['iban'], 'string', 'max' => 25],
            [['email'], 'unique'],
            [['email'], 'email'],
            [['identification_number'], 'unique'],
            [['tax_number'], 'unique'],
            [['id_education'], 'exist', 'skipOnError' => true, 'targetClass' => Education::className(), 'targetAttribute' => ['id_education' => 'id_education']],
            [['id_zone3'], 'exist', 'skipOnError' => true, 'targetClass' => Zone3::className(), 'targetAttribute' => ['id_zone3' => 'id_zone3']],
            [['id_entity_current'], 'exist', 'skipOnError' => true, 'targetClass' => Entity::className(), 'targetAttribute' => ['id_entity_current' => 'id_entity']],
            [['id_gender'], 'exist', 'skipOnError' => true, 'targetClass' => Gender::className(), 'targetAttribute' => ['id_gender' => 'id_gender']],
            [['id_document_type'], 'exist', 'skipOnError' => true, 'targetClass' => DocumentType::className(), 'targetAttribute' => ['id_document_type' => 'id_document_type']],
            [['id_nationality'], 'exist', 'skipOnError' => true, 'targetClass' => Nationality::className(), 'targetAttribute' => ['id_nationality' => 'id_nationality']],
            [['id_vocational_skills_type'], 'exist', 'skipOnError' => true, 'targetClass' => VocationSkillType::className(), 'targetAttribute' => ['id_vocational_skills_type' => 'id_vocational_skills_type']],
            [['id_zone1'], 'exist', 'skipOnError' => true, 'targetClass' => Zone1::className(), 'targetAttribute' => ['id_zone1' => 'id_zone1']],
            [['id_zone2'], 'exist', 'skipOnError' => true, 'targetClass' => Zone2::className(), 'targetAttribute' => ['id_zone2' => 'id_zone2']],
            [
                ['id_zone3'],
                'required',
                'when' => function ($model) {
                    return Zone3::find()->andWhere(['id_zone2' => $model->id_zone2])->exists();
                },
                'whenClient' => 'function (attribute, value) 
                {
                    return $("#participant-id_zone3 option[value!=\'\']").length > 0;
                }',
            ],
            [['phone', 'phone_alternative'], 'string', 'min' => 9, 'max' => 25, 'tooShort' => Yii::t('app', 'Número deve conter no mínimo 9 dígitos.')],
            [['phone', 'phone_alternative'], 'match', 'pattern' => '/^\s*?\d+\s*$/', 'message' => Yii::t('app', 'Informe somente números.')],
            [['id_zone1', 'id_zone2', 'id_zone3'], 'default', 'value' => null],
            [
                'image_rights_file',
                'file',
            ],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id_participant' => Yii::t('app', 'Id_participante'),
            'id_login' => Yii::t('app', 'Id Login'),
            'name' => Yii::t('app', 'Nome'),
            'nickname' => Yii::t('app', 'Nome Abreviado'),
            'email' => Yii::t('app', 'Email'),
            'email_alternative' => Yii::t('app', 'Email Alternative'),
            'id_nationality' => Yii::t('app', 'Id_nacionalidade'),
            'date_birth' => Yii::t('app', 'Data Nascimento'),
            'place_of_birth' => Yii::t('app', 'Local Nascimento'),
            'id_document_type' => Yii::t('app', 'Id_tipo_documento'),
            'identification_number' => Yii::t('app', 'Número Doc. Identificação'),
            'date_expiration' => Yii::t('app', 'Data validade'),
            'tax_number' => Yii::t('app', 'Número Contribuinte'),
            'social_security_number' => Yii::t('app', 'Número Seg. Social'),
            'address' => Yii::t('app', 'Morada'),
            'city' => Yii::t('app', 'Localidade'),
            'postal_code' => Yii::t('app', 'Código postal'),
            'id_zone1' => Yii::t('app', 'Distrito'),
            'id_zone2' => Yii::t('app', 'Concelho'),
            'id_zone3' => Yii::t('app', 'Freguesia'),
            'phone' => Yii::t('app', 'Telefone'),
            'phone_alternative' => Yii::t('app', 'Telef. Alternativo'),
            'id_education' => Yii::t('app', 'Id_habilitacao'),
            'id_vocational_skills_type' => Yii::t('app', 'Id_formacao_profissional'),
            'vocational_skills' => Yii::t('app', 'Curso Profissional'),
            'id_gender' => Yii::t('app', 'Gênero'),
            'tshirt_size' => Yii::t('app', 'Tamanho T-shirt'),
            'iban' => Yii::t('app', 'Iban'),
            'extra01' => Yii::t('app', ConstantsHelper::constantLabel('extra01')),
            'extra02' => Yii::t('app', ConstantsHelper::constantLabel('extra02')),
            'extra03' => Yii::t('app', ConstantsHelper::constantLabel('extra03')),
            'extra04' => Yii::t('app', ConstantsHelper::constantLabel('extra04')),
            'extra05' => Yii::t('app', ConstantsHelper::constantLabel('extra05')),
            'extra06' => Yii::t('app', ConstantsHelper::constantLabel('extra06')),
            'extra07' => Yii::t('app', ConstantsHelper::constantLabel('extra07')),
            'extra08' => Yii::t('app', ConstantsHelper::constantLabel('extra08')),
            'extra09' => Yii::t('app', ConstantsHelper::constantLabel('extra09')),
            'extra10' => Yii::t('app', ConstantsHelper::constantLabel('extra10')),
            'dietary_restriction' => Yii::t('app', 'Restrições Alimentares'),
            'dr01' => Yii::t('app', ConstantsHelper::constantLabel('dr01')),
            'dr02' => Yii::t('app', ConstantsHelper::constantLabel('dr02')),
            'dr03' => Yii::t('app', ConstantsHelper::constantLabel('dr03')),
            'dr04' => Yii::t('app', ConstantsHelper::constantLabel('dr04')),
            'dr05' => Yii::t('app', ConstantsHelper::constantLabel('dr05')),
            'dr06' => Yii::t('app', ConstantsHelper::constantLabel('dr06')),
            'dr07' => Yii::t('app', ConstantsHelper::constantLabel('dr07')),
            'dr08' => Yii::t('app', ConstantsHelper::constantLabel('dr08')),
            'dr_other' => Yii::t('app', 'Outras Restrições'),
            'id_entity_current' => Yii::t('app', 'Id_entidade_atual'),
            'notes' => Yii::t('app', 'Notas'),
            'picture' => Yii::t('app', 'Foto'),
            'active' => Yii::t('app', 'Ativo'),
            'image_rights_upload' => Yii::t('app', 'Autorização Direitos de Imagem'),
        ];
    }


    public function attributeHints()
    {
        return [
            'postal_code' => Yii::t('app', 'Exemplo') . ': 9999-999',
            'id_vocational_skills_type' => Yii::t('app', 'Selecionar o tipo de formação profissional que frequenta/frequentou (Se não frequentou selecione Não Aplicável)'),
            'vocational_skills' => Yii::t('app', 'Se frequentou um curso profissional coloque o nome do curso aqui'),
            'extra01' => Yii::t('app', ConstantsHelper::constantHint('extra01')),
            'extra02' => Yii::t('app', ConstantsHelper::constantHint('extra02')),
            'extra03' => Yii::t('app', ConstantsHelper::constantHint('extra03')),
            'extra04' => Yii::t('app', ConstantsHelper::constantHint('extra04')),
            'extra05' => Yii::t('app', ConstantsHelper::constantHint('extra05')),
            'extra06' => Yii::t('app', ConstantsHelper::constantHint('extra06')),
            'extra07' => Yii::t('app', ConstantsHelper::constantHint('extra07')),
            'extra08' => Yii::t('app', ConstantsHelper::constantHint('extra08')),
            'extra09' => Yii::t('app', ConstantsHelper::constantHint('extra09')),
            'extra10' => Yii::t('app', ConstantsHelper::constantHint('extra10')),
            'dr01' => Yii::t('app', ConstantsHelper::constantHint('dr01')),
            'dr02' => Yii::t('app', ConstantsHelper::constantHint('dr02')),
            'dr03' => Yii::t('app', ConstantsHelper::constantHint('dr03')),
            'dr04' => Yii::t('app', ConstantsHelper::constantHint('dr04')),
            'dr05' => Yii::t('app', ConstantsHelper::constantHint('dr05')),
            'dr06' => Yii::t('app', ConstantsHelper::constantHint('dr06')),
            'dr07' => Yii::t('app', ConstantsHelper::constantHint('dr07')),
            'dr08' => Yii::t('app', ConstantsHelper::constantHint('dr08')),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getEntities()
    {
        return $this->hasMany(Entity::className(), ['id_participant_platform_manager' => 'id_participant']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getEventsParticipants()
    {
        return $this->hasMany(EventParticipant::className(), ['id_participant' => 'id_participant']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getEducation()
    {
        return $this->hasOne(Education::className(), ['id_education' => 'id_education']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getZone3()
    {
        return $this->hasOne(Zone3::className(), ['id_zone3' => 'id_zone3']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getEntityCurrent()
    {
        return $this->hasOne(Entity::className(), ['id_entity' => 'id_entity_current']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getGender()
    {
        return $this->hasOne(Gender::className(), ['id_gender' => 'id_gender']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getDocumentType()
    {
        return $this->hasOne(DocumentType::className(), ['id_document_type' => 'id_document_type']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getNationality()
    {
        return $this->hasOne(Nationality::className(), ['id_nationality' => 'id_nationality']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getVocationalSkillsType()
    {
        return $this->hasOne(VocationSkillType::className(), ['id_vocational_skills_type' => 'id_vocational_skills_type']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getZone1()
    {
        return $this->hasOne(Zone1::className(), ['id_zone1' => 'id_zone1']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getZone2()
    {
        return $this->hasOne(Zone2::className(), ['id_zone2' => 'id_zone2']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getLogin()
    {
        return $this->hasOne(Login::className(), ['id_login' => 'id_login']);
    }

    /**
     * @inheritdoc
     * @return \app\models\query\ParticipantQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new \app\models\query\ParticipantQuery(get_called_class());
    }

    public function canDelete()
    {
        $canDelete = !(bool)$this->getEntities()->exists();
        $canDelete = $canDelete && !(bool)$this->getEventsParticipants()->exists();

        return $canDelete;
    }

    public function beforeSave($insert)
    {
        if (!$this->dietary_restriction) {
            for ($i = 1; $i <= 6; $i++) {
                $drAttribute = 'dr' . sprintf('%02d', $i);
                $this->$drAttribute = null;
            }

            $this->dr_other = null;
        }

        return parent::beforeSave($insert);
    }


    public function pictureFilePath($sizeBig = true)
    {
        $size = $sizeBig ? 'big' : 'small';

        $file = FileHelper::findFiles(PARTICIPANTS_IMAGES_DIR, [
            'only' => [
                "{$this->picture}_{$size}.*",
            ],
        ]);

        $file = reset($file);

        return $file;
    }

    public function pictureUrl($sizeBig = true)
    {
        if ($this->picture) {
            return Url::to(['/participant/picture', 'id' => $this->id_participant, 'sizeBig' => (int)$sizeBig]);
        }

        return '/img/avatar_300x300.png';
    }

    public function deletePicture()
    {
        if ($this->picture) {
            unlink($this->pictureFilePath());
            unlink($this->pictureFilePath(false));
            $this->updateAttributes(['picture' => null]);
        }
    }

    public function saveImageRightFile(UploadedFile $file = null)
    {
        //Update model without changing file
        if ($file === null && file_exists($this->imageRightsFilePath())) {
            return true;
        }

        //Error: Participant must be saved before because the file will be saved with id_participant.
        if ($this->isNewRecord) {
            $this->addError(
                'image_rights_upload',
                Yii::t('app', 'Para guardar a autorização de direitos de imagem deve-se primeiro armazenar o registro de participante no banco de dados.')
            );

            $this->updateAttributes(['image_rights_upload' => null]);

            return false;
        }

        //Error: trying to save without image rights upload
        if ($file === null && !file_exists($this->imageRightsFilePath())) {
            $this->addError('image_rights_upload', $this->getAttributeLabel('image_rights_upload') . ' ' . Yii::t('app', 'obrigatório'));

            $this->updateAttributes(['image_rights_upload' => null]);

            return false;
        }

        $name = "{$this->id_participant}.{$file->extension}";
        $file->saveAs(PARTICIPANTS_IMAGE_RIGHTS_DIR . $name);
        $this->clearOldImageRightsFiles($name);
        $this->updateAttributes(['image_rights_upload' => $name]);

        return true;
    }

    public function imageRightsFilePath()
    {
        $file = PARTICIPANTS_IMAGE_RIGHTS_DIR . $this->image_rights_upload;

        return is_file($file) ? $file : false;
    }

    public function imageRightsUrl()
    {
        if (!$this->image_rights_upload) {
            return false;
        }

        return Url::to(['/participant/image-rights', 'id' => $this->id_participant]);
    }

    /**
     * @param $name
     * @throws \yii\base\InvalidParamException
     */
    private function clearOldImageRightsFiles($name)
    {
        $oldFiles = FileHelper::findFiles(PARTICIPANTS_IMAGE_RIGHTS_DIR, ['only' => [$this->id_participant . '.*'], 'except' => [$name],
        ]);

        foreach ($oldFiles as $file) {
            unlink($file);
        }
    }

    public function delete()
    {
        if (parent::delete()) {
            $this->clearAllFiles();

            return true;
        }

        return false;
    }

    /**
     * @throws \yii\base\InvalidParamException
     */
    private function clearAllFiles()
    {
        $oldFiles = array_merge(
            FileHelper::findFiles(PARTICIPANTS_IMAGE_RIGHTS_DIR, ['only' => [$this->id_participant . '.*']]),
            FileHelper::findFiles(PARTICIPANTS_IMAGES_DIR, ['only' => [$this->id_participant . '_*',]])
        );

        foreach ($oldFiles as $file) {
            unlink($file);
        }
    }

    public function getIsPlatformManager()
    {
        return $this->getEntities()->exists();
    }

    public function canManagePlatform()
    {
        $allowPlatformManage = AccessManager::find()
            ->andWhere([
                'OR',
                ['id_access_manager' => 4, 'access_all_platform_manager' => 1],
                [
                    'AND',
                    ['id_access_manager' => 4],
                    ['access_restricted_logins' => 1],
                    ['like', 'restricted_logins_list', "{{$this->login->id_login}}"],
                ],
            ])
            ->exists();

        return $this->isPlatformManager && $allowPlatformManage;
    }

    public function canManageParticipant(Participant $participant)
    {
        $allowPlatformManage = $this->getEntities()
            ->andWhere([
                'entities.id_entity' => $participant->id_entity_current,
            ])
            ->exists();

        return $this->canManagePlatform() && $allowPlatformManage;
    }

    public function createLogin()
    {
        $transaction = Yii::$app->db->beginTransaction();

        try {
            if ($this->id_login) {
                throw new InvalidCallException(Yii::t('app', 'Não é possível gerar um novo login para um participante que já o possui.'));
            }

            $password = Yii::$app->security->generateRandomString(4) . random_int(1000, 9999);

            $login = new Login([
                'id_admin_level' => AdminLevel::ROLE_USER,
                'status' => Login::STATUS_ACTIVE,
                'password' => Yii::$app->security->generatePasswordHash($password),
            ]);

            $login->save(false);

            $login->link('participant', $this);

            Yii::$app->mailer->compose(['html' => 'login/create', 'text' => 'login/text/create'], [
                'login' => $login,
                'participant' => $this,
                'password' => $password,
            ])
                ->setTo($this->email)
                ->setSubject(Yii::t('app', 'WorldSkills Portugal') . ' ' . Yii::t('app', 'Dados de Acesso'))
                ->send();

            $transaction->commit();

            return true;
        } catch (\Exception $e) {
            $transaction->rollBack();

            if (YII_DEBUG) {
                throw $e;
            }

            Yii::error($e);

            Yii::$app->getSession()->setFlash('danger', Yii::t('app', 'Não foi possível gerar login para o participante {0}.', $this->name));
        }

        return false;
    }

    public function isCompetitorEnrolledToEvent()
    {
        return EventParticipant::find()
            ->andWhere([
                'id_participant' => $this->id_participant,
                'id_participant_type' => 601,
            ])
            ->exists();
    }
}
