<?php

namespace app\models;

use Yii;
use yii\helpers\ArrayHelper;
use yii\helpers\Url;

class ParticipantProfile extends Participant
{
    /**
     * @inheritdoc
     */
    public function rules()
    {
        return ArrayHelper::merge(parent::rules(), [
            [
                [
                    'name',
                    'nickname',
                    'email',
                    'date_birth',
                    'place_of_birth',
                    'date_expiration',
                    'social_security_number',
                    'address',
                    'city',
                    'identification_number',
                    'tax_number',
                    'postal_code',
                    'phone',
                    'tshirt_size',
                    'id_entity_current',
                    'dietary_restriction',
                    'id_gender',
                    'active',
                    'id_nationality',
                    'id_document_type',
                    'id_zone1',
                    'id_zone2',
                    'id_education',
                    'id_vocational_skills_type',
                    'image_rights_upload',
                ],
                'required',
            ],
            ['iban', 'string', 'skipOnEmpty' => true],
        ]);
    }

    /**
     * @inheritdoc
     * @return \app\models\query\ParticipantQuery the active query used by this AR class.
     */
    public static function find()
    {
        return parent::find()->andWhere(['id_login' => Yii::$app->user->identity->getId()]);
    }

    public function canDelete()
    {
        return false;
    }

    public function pictureUrl($sizeBig = true)
    {
        if ($this->picture) {
            return Url::to(['/participant-profile/picture', 'sizeBig' => (int)$sizeBig]);
        }

        return '/img/avatar_300x300.png';
    }

    public function imageRightsUrl()
    {
        if (!$this->image_rights_upload) {
            return false;
        }

        return Url::to(['/participant-profile/image-rights']);
    }

    public function formName()
    {
        return 'Participant';
    }

    public function canUpdate()
    {
        return AccessManager::find()
            ->andWhere([
                'OR',
                ['id_access_manager' => 4, 'access_all_participants' => 1],
                [
                    'AND',
                    ['id_access_manager' => 4],
                    ['access_restricted_logins' => 1],
                    ['like', 'restricted_logins_list', $this->id_participant],
                ],
            ])
            ->exists();
    }
}
