<?php

namespace app\models;

use app\components\validators\NoSpaceValidator;
use Yii;
use yii\base\Model;

/**
 * LoginForm is the model behind the login form.
 *
 * @property User|null $user This property is read-only.
 *
 */
class PasswordForm extends Model
{
    public $password;
    public $passwordConfirm;

    /** @var Login */
    private $_user;

    public function __construct(Login $login, array $config = [])
    {
        $this->_user = $login;

        parent::__construct($config);
    }


    /**
     * @return array the validation rules.
     */
    public function rules()
    {
        return [
            [['password', 'passwordConfirm'], 'required'],
            ['password', 'string', 'length' => [8, 255], 'tooShort' => Yii::t('app', 'A password deve conter no mínimo 8 caracteres.')],
            ['password', 'match', 'pattern' => '/(?:[0-9][^ ]*[A-Za-z][^ ]*)|(?:[A-Za-z][^ ]*[0-9][^ ]*)/', 'message' => Yii::t('app', 'A password deve conter letras e números.')],
            ['password', NoSpaceValidator::class],
            ['passwordConfirm', 'compare', 'compareAttribute' => 'password'],
        ];
    }
    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'password' => Yii::t('app', 'Password'),
            'passwordConfirm' => Yii::t('app', 'Digite a password novamente'),
        ];
    }

    public function save()
    {
        if (!$this->validate()) {
            return false;
        }

        $this->_user->password = Yii::$app->security->generatePasswordHash($this->password);

        return $this->_user->save();
    }
}
