<?php

namespace app\models;

use app\components\validators\NoSpaceValidator;
use Yii;

/**
 * This is the model class for table "skills".
 *
 * @property string $id_skill
 * @property string $name
 * @property string $id_cluster
 * @property string $notes
 *
 * @property EventSkill[] $eventsSkills
 * @property Cluster $cluster
 */
class Skill extends BaseModel
{
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'skills';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id_skill', 'name', 'id_cluster'], 'required'],
            [['id_skill'], NoSpaceValidator::class],
            [['notes'], 'string'],
            [['id_skill'], 'string', 'max' => 10],
            [['name'], 'string', 'max' => 200],
            [['id_cluster'], 'string', 'max' => 25],
            [['id_skill'], 'unique'],
            [['id_cluster'], 'exist', 'skipOnError' => true, 'targetClass' => Cluster::className(), 'targetAttribute' => ['id_cluster' => 'id_cluster']],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id_skill' => Yii::t('app', 'Id_profissao'),
            'name' => Yii::t('app', 'Nome'),
            'id_cluster' => Yii::t('app', 'Id_cluster'),
            'notes' => Yii::t('app', 'Notas'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getEventsSkills()
    {
        return $this->hasMany(EventSkill::className(), ['id_skill' => 'id_skill']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getCluster()
    {
        return $this->hasOne(Cluster::className(), ['id_cluster' => 'id_cluster']);
    }

    /**
     * @inheritdoc
     * @return \app\models\query\SkillQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new \app\models\query\SkillQuery(get_called_class());
    }

    /**
     * @return bool
     */
    public function canDelete()
    {
        $canDelete = !(bool)self::find()->andWhere(['{{%skills}}.id_skill' => $this->id_skill])->innerJoinWith('eventsSkills')->exists();

        return $canDelete;
    }
}
