<?php

namespace app\models;

use Imagine\Image\Box;
use Imagine\Image\Point;
use Yii;
use yii\base\Model;
use yii\helpers\FileHelper;
use yii\helpers\Json;
use yii\imagine\Image;
use yii\web\UploadedFile;


/**
 *
 * @property  $id string
 *
 * Class UploadPictureForm
 */
class UploadPictureForm extends Model
{
    /**
     * @var Participant
     */
    public $participant;

    /**
     * @var UploadedFile
     */
    public $picture;

    public $crop_info;

    public function rules()
    {
        return [
            [
                'picture',
                'image',
                'extensions' => ['jpg', 'jpeg', 'png', 'gif'],
                'minWidth' => 300,
                'minHeight' => 300,
                'tooSmall' => Yii::t('app', 'Erro: Imagem muito pequena (deve fazer upload de uma imagem superior a 300x300)'),
                'mimeTypes' => ['image/jpeg', 'image/pjpeg', 'image/png', 'image/gif'],
            ],
            ['crop_info', 'safe'],

        ];
    }

    public function attributeLabels()
    {
        return [
            'picture' => Yii::t('app', 'Foto'),
        ];
    }

    public function upload()
    {
        if ($this->validate()) {
            // open image
            $image = Image::getImagine()->open($this->picture->tempName);

            // rendering information about crop of ONE option 
            $cropInfo = Json::decode($this->crop_info)[0];
            $cropInfo['dw'] = (int)($cropInfo['dw'] ?? null); //new width image
            $cropInfo['dh'] = (int)($cropInfo['dh'] ?? null); //new height image
            $cropInfo['x'] = abs(($cropInfo['x'] ?? null)); //begin position of frame crop by X
            $cropInfo['y'] = abs(($cropInfo['y'] ?? null)); //begin position of frame crop by Y
            // Properties bolow we don't use in this example
            //$cropInfo['ratio'] = $cropInfo['ratio'] == 0 ? 1.0 : (float)$cropInfo['ratio']; //ratio image. 
            //$cropInfo['w'] = (int)$cropInfo['w']; //width of cropped image
            //$cropInfo['h'] = (int)$cropInfo['h']; //height of cropped image

            //delete old images
            $this->clearOldPics();

            //saving original
            $newSizeThumb = new Box($cropInfo['dw'], $cropInfo['dh']);
            $cropSizeThumb = new Box(300, 300); //frame size of crop
            $cropPointThumb = new Point($cropInfo['x'], $cropInfo['y']);
            $pathThumbImage = PARTICIPANTS_IMAGES_DIR . '/' . $this->id . '_big.' . $this->picture->getExtension();

            $image->resize($newSizeThumb)
                ->crop($cropPointThumb, $cropSizeThumb)
                ->save($pathThumbImage, ['quality' => 100]);

            //saving small
            $newSizeThumb = new Box(150, 150);
            $pathThumbImage = PARTICIPANTS_IMAGES_DIR . '/' . $this->id . '_small.' . $this->picture->getExtension();

            $image->resize($newSizeThumb)
                ->save($pathThumbImage, ['quality' => 100]);


            $this->participant->updateAttributes(['picture' => $this->id]);

            return true;
        }

        return false;
    }

    public function getId()
    {
        return $this->participant->id_participant . '_' . md5($this->participant->id_participant);
    }

    /**
     * @param bool $sizeBig
     * @return string
     * @throws \yii\base\InvalidParamException
     */
    public function filePath($sizeBig = true)
    {
        $size = $sizeBig ? 'big' : 'small';

        $file = FileHelper::findFiles(PARTICIPANTS_IMAGES_DIR, [
            'only' => [
                "{$this->id}_{$size}.*",
            ],
        ]);

        $file = $file[0] ?? '';

        return $file;
    }

    private function clearOldPics()
    {
        $oldImages = FileHelper::findFiles(PARTICIPANTS_IMAGES_DIR, [
            'only' => [
                $this->id . '_big.*',
                $this->id . '_small.*',
            ],
        ]);
        for ($i = 0; $i != count($oldImages); $i++) {
            unlink($oldImages[$i]);
        }
    }
}