<?php

namespace app\models;

use app\components\validators\NoSpaceValidator;
use Yii;
use yii\db\ActiveRecord;

/**
 * This is the model class for table "zone2".
 *
 * @property string $id_zone2
 * @property string $name
 * @property string $id_zone1
 * @property int $id_organization_region
 *
 * @property Entity[] $entities
 * @property EntityRegistration[] $entitiesRegistrations
 * @property Participant[] $participants
 * @property OrganizationRegion $organizationRegion
 * @property Zone1 $zone1
 * @property Zone3[] $zone3s
 */
class Zone2 extends ActiveRecord
{
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'zone2';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id_zone2', 'name', 'id_zone1', 'id_organization_region'], 'required'],
            [['id_zone2'], NoSpaceValidator::class],
            [['id_organization_region'], 'integer'],
            [['id_zone2', 'id_zone1'], 'string', 'max' => 25],
            [['name'], 'string', 'max' => 100],
            [['id_zone2'], 'unique'],
            [['id_organization_region'], 'exist', 'skipOnError' => true, 'targetClass' => OrganizationRegion::className(), 'targetAttribute' => ['id_organization_region' => 'id_organization_region']],
            [['id_zone1'], 'exist', 'skipOnError' => true, 'targetClass' => Zone1::className(), 'targetAttribute' => ['id_zone1' => 'id_zone1']],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id_zone2' => Yii::t('app', 'Id_concelho'),
            'name' => Yii::t('app', 'Nome'),
            'id_zone1' => Yii::t('app', 'Id_distrito'),
            'id_organization_region' => Yii::t('app', 'Id_regiao_organizacao'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getEntities()
    {
        return $this->hasMany(Entity::className(), ['id_zone2' => 'id_zone2']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getEntitiesRegistrations()
    {
        return $this->hasMany(EntityRegistration::className(), ['id_zone2' => 'id_zone2']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getParticipants()
    {
        return $this->hasMany(Participant::className(), ['id_zone2' => 'id_zone2']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getOrganizationRegion()
    {
        return $this->hasOne(OrganizationRegion::className(), ['id_organization_region' => 'id_organization_region']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getZone1()
    {
        return $this->hasOne(Zone1::className(), ['id_zone1' => 'id_zone1']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getZone3s()
    {
        return $this->hasMany(Zone3::className(), ['id_zone2' => 'id_zone2']);
    }

    /**
     * @inheritdoc
     * @return \app\models\query\Zone2Query the active query used by this AR class.
     */
    public static function find()
    {
        return new \app\models\query\Zone2Query(get_called_class());
    }

    /**
     * @return bool
     */
    public function canDelete()
    {
        $canDelete = !(bool)self::find()->andWhere(['{{%zone2}}.id_zone2' => $this->id_zone2])->innerJoinWith('entities')->exists();
        $canDelete = $canDelete && !(bool)self::find()->andWhere(['{{%zone2}}.id_zone2' => $this->id_zone2])->innerJoinWith('entitiesRegistrations')->exists();
        $canDelete = $canDelete && !(bool)self::find()->andWhere(['{{%zone2}}.id_zone2' => $this->id_zone2])->innerJoinWith('participants')->exists();
        $canDelete = $canDelete && !(bool)self::find()->andWhere(['{{%zone2}}.id_zone2' => $this->id_zone2])->innerJoinWith('zone3s')->exists();

        return $canDelete;
    }
}
