<?php

namespace app\models;

use app\components\validators\NoSpaceValidator;
use Yii;

/**
 * This is the model class for table "zone3".
 *
 * @property string $id_zone3
 * @property string $name
 * @property string $id_zone2
 *
 * @property Entity[] $entities
 * @property EntityRegistration[] $entitiesRegistrations
 * @property Participant[] $participants
 * @property Zone2 $zone2
 */
class Zone3 extends BaseModel
{
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'zone3';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id_zone3', 'name', 'id_zone2'], 'required'],
            [['id_zone3'], NoSpaceValidator::class],
            [['id_zone3', 'id_zone2'], 'string', 'max' => 25],
            [['name'], 'string', 'max' => 100],
            [['id_zone3'], 'unique'],
            [['id_zone2'], 'exist', 'skipOnError' => true, 'targetClass' => Zone2::className(), 'targetAttribute' => ['id_zone2' => 'id_zone2']],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id_zone3' => Yii::t('app', 'Id_freguesia'),
            'name' => Yii::t('app', 'Nome'),
            'id_zone2' => Yii::t('app', 'id_concelho'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getEntities()
    {
        return $this->hasMany(Entity::className(), ['id_zone3' => 'id_zone3']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getEntitiesRegistrations()
    {
        return $this->hasMany(EntityRegistration::className(), ['id_zone3' => 'id_zone3']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getParticipants()
    {
        return $this->hasMany(Participant::className(), ['id_zone3' => 'id_zone3']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getZone2()
    {
        return $this->hasOne(Zone2::className(), ['id_zone2' => 'id_zone2']);
    }

    /**
     * @inheritdoc
     * @return \app\models\query\Zone3Query the active query used by this AR class.
     */
    public static function find()
    {
        return new \app\models\query\Zone3Query(get_called_class());
    }

    /**
     * @return bool
     */
    public function canDelete()
    {
        $canDelete = !(bool)self::find()->andWhere(['{{%zone3}}.id_zone3' => $this->id_zone3])->innerJoinWith('entities')->exists();
        $canDelete = $canDelete && !(bool)self::find()->andWhere(['{{%zone3}}.id_zone3' => $this->id_zone3])->innerJoinWith('entitiesRegistrations')->exists();
        $canDelete = $canDelete && !(bool)self::find()->andWhere(['{{%zone3}}.id_zone3' => $this->id_zone3])->innerJoinWith('participants')->exists();

        return $canDelete;
    }
}
