<?php

namespace app\models\search;

use app\models\Entity;
use yii\base\Model;
use yii\data\ActiveDataProvider;

/**
 * EntitySearch represents the model behind the search form of `\app\models\Entity`.
 */
class EntitySearch extends Entity
{
    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id_entity', 'id_participant_platform_manager', 'id_entity_scope', 'entity_is_main', 'id_entity_main', 'active'], 'integer'],
            [
                [
                    'name',
                    'address',
                    'city',
                    'postal_code',
                    'id_zone1',
                    'id_zone2',
                    'id_zone3',
                    'phone',
                    'email',
                    'direction_name',
                    'direction_email',
                    'direction_position',
                    'alternative_contact_name',
                    'alternative_contact_email',
                    'alternative_contact_direct_phone',
                    'notes',
                    'id_participant_platform_manager',
                    'id_entity_scope',
                    'entity_is_main',
                    'id_entity_main',
                    'active',
                ],
                'safe',
            ],
        ];
    }

    /**
     * @inheritdoc
     */
    public function scenarios()
    {
        // bypass scenarios() implementation in the parent class
        return Model::scenarios();
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params)
    {
        $query = Entity::find();

        // add conditions that should always apply here

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
            'pagination' => [
                'pageSize' => 40,
            ],
        ]);

        $this->load($params);

        if (!$this->validate()) {
            // uncomment the following line if you do not want to return any records when validation fails
            // $query->where('0=1');
            return $dataProvider;
        }

        // grid filtering conditions
        $query->andFilterWhere([
            'id_entity' => $this->id_entity,
            'id_participant_platform_manager' => $this->id_participant_platform_manager,
            'id_entity_scope' => $this->id_entity_scope,
            'entity_is_main' => $this->entity_is_main,
            'id_entity_main' => $this->id_entity_main,
            'active' => $this->active,
        ]);

        $query->andFilterWhere(['like', 'name', $this->name])
            ->andFilterWhere(['like', 'address', $this->address])
            ->andFilterWhere(['like', 'city', $this->city])
            ->andFilterWhere(['like', 'postal_code', $this->postal_code])
            ->andFilterWhere(['like', 'id_zone1', $this->id_zone1])
            ->andFilterWhere(['like', 'id_zone2', $this->id_zone2])
            ->andFilterWhere(['like', 'id_zone3', $this->id_zone3])
            ->andFilterWhere(['like', 'phone', $this->phone])
            ->andFilterWhere(['like', 'email', $this->email])
            ->andFilterWhere(['like', 'direction_name', $this->direction_name])
            ->andFilterWhere(['like', 'direction_email', $this->direction_email])
            ->andFilterWhere(['like', 'direction_position', $this->direction_position])
            ->andFilterWhere(['like', 'alternative_contact_name', $this->alternative_contact_name])
            ->andFilterWhere(['like', 'alternative_contact_email', $this->alternative_contact_email])
            ->andFilterWhere(['like', 'alternative_contact_direct_phone', $this->alternative_contact_direct_phone])
            ->andFilterWhere(['like', 'notes', $this->notes]);

        return $dataProvider;
    }
}
