<?php

namespace app\models\search;

use app\models\EventParticipant;
use Yii;
use yii\base\Model;
use yii\data\ActiveDataProvider;
use yii\helpers\ArrayHelper;

/**
 * EventParticipantSearch represents the model behind the search form of `\app\models\EventParticipant`.
 */
class EventParticipantSearch extends EventParticipant
{
    public $id_event;

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id_event_participant', 'id_entity', 'id_participant', 'id_participant_type', 'id_event_participant_state'], 'integer'],
            [['id_event_skill', 'id_event'], 'safe'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return ArrayHelper::merge(parent::attributeLabels(), [
            'id_event' => Yii::t('app', 'Id_evento'),
        ]);
    }

    /**
     * @inheritdoc
     */
    public function scenarios()
    {
        // bypass scenarios() implementation in the parent class
        return Model::scenarios();
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params)
    {
        $query = EventParticipant::find()->joinWith('eventSkill.event');

        // add conditions that should always apply here

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
            'pagination' => [
                'pageSize' => 40,
            ],
        ]);

        $this->load($params);

        if (!$this->validate()) {
            // uncomment the following line if you do not want to return any records when validation fails
            // $query->where('0=1');
            return $dataProvider;
        }

        // grid filtering conditions
        $query->andFilterWhere([
            'id_event_participant' => $this->id_event_participant,
            'id_entity' => $this->id_entity,
            'id_participant' => $this->id_participant,
            'id_participant_type' => $this->id_participant_type,
            'id_event_participant_state' => $this->id_event_participant_state,
        ]);

        $query->andFilterWhere(['like', 'id_event_skill', $this->id_event_skill]);
        $query->andFilterWhere(['like', '{{%events}}.id_event', $this->id_event]);

        return $dataProvider;
    }
}
