<?php

namespace app\models\search;

use app\models\Participant;
use yii\base\Model;
use yii\data\ActiveDataProvider;

/**
 * LoginSearch represents the model behind the search form of `\app\models\Login`.
 */
class LoginSearch extends Participant
{
    public $has_login;
    public $email_verified;
    public $login_active;
    public $is_admin;
    public $admin_level;

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id_participant', 'name', 'email', 'has_login', 'email_verified', 'login_active', 'is_admin', 'admin_level'], 'safe'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function scenarios()
    {
        // bypass scenarios() implementation in the parent class
        return Model::scenarios();
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params)
    {
        $query = Participant::find()->joinWith('login');

        // add conditions that should always apply here

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
            'pagination' => [
                'pageSize' => 40,
            ],
        ]);

        $this->load($params);

        if (!$this->validate()) {
            // uncomment the following line if you do not want to return any records when validation fails
            // $query->where('0=1');
            return $dataProvider;
        }

        // grid filtering conditions
        $query->andFilterWhere([
            'IF(IFNULL(LENGTH(login.id_login), 0),1,0)' => $this->has_login,
            'IF(id_admin_level != 3, 1,0)' => $this->is_admin,
            'id_admin_level' => $this->admin_level,
            'IFNULL(login.login.status, 0)' => $this->login_active,
            'IFNULL(login.email_verified, 0)' => $this->email_verified,
        ]);

        $query
            ->andFilterWhere(['like', 'id_participant', $this->id_participant])
            ->andFilterWhere(['like', 'name', $this->name])
            ->andFilterWhere(['like', 'email', $this->email]);

        return $dataProvider;
    }
}
