<?php

namespace app\models\search;

use app\models\AccessManager;
use app\models\EventParticipant;
use app\models\Participant;
use Yii;
use yii\base\InvalidConfigException;
use yii\data\ActiveDataProvider;
use yii\helpers\ArrayHelper;

/**
 * ParticipantManagedSearch represents the model behind the search form of `\app\models\Participant`.
 */
class ParticipantManagedSearch extends EventParticipantSearch
{
    public $id_platform_manager;

    public $id_event;

    public $event;

    public $id_entity;

    public $id_event_skill;

    public $hasImageRights;

    public $participantName;

    public $hasPicture;

    public function __construct(Participant $platformManager, array $config = [])
    {
        $accessManager = AccessManager::findOne(4);

        $this->event = $accessManager->event ?? null;
        $this->id_event = $accessManager->id_event ?? null;

        if (!$platformManager->isPlatformManager) {
            throw new InvalidConfigException('Informe um participante que é gestor para buscar os participantes a serem geridos.');
        }

        $this->id_platform_manager = $platformManager->id_participant;

        parent::__construct($config);
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return array_merge(parent::rules(), [
            [['id_entity', 'id_event_skill', 'hasImageRights', 'hasPicture', 'participantName'], 'safe'],
        ]);
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return ArrayHelper::merge(parent::attributeLabels(), [
            'id_event' => Yii::t('app', 'Gestão dos dados de utilizadores inscritos no evento:'),
            'id_entity' => Yii::t('app', 'Id_entidade'),
        ]);
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params)
    {
        $query = EventParticipant::find()
            ->joinWith(['entity', 'eventSkill', 'participant'], true, 'INNER JOIN')
            ->andWhere(['entities.id_participant_platform_manager' => $this->id_platform_manager]);

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
            'pagination' => [
                'pageSize' => 40,
            ],
        ]);

        $this->load($params);

        if (!$this->validate()) {
            // uncomment the following line if you do not want to return any records when validation fails
            // $query->where('0=1');
            return $dataProvider;
        }

        // grid filtering conditions
        $query->andFilterWhere([
            'entities.id_entity' => $this->id_entity,
            'events_skills.id_event' => $this->id_event,
            'events_skills.id_event_skill' => $this->id_event_skill,
            'events_participants.id_participant_type' => $this->id_participant_type,
            'events_participants.id_event_participant_state' => $this->id_event_participant_state,
        ]);

        $query->andFilterWhere(['like', 'participants.name', $this->participantName])
            ->andFilterWhere(['like', 'IF(IFNULL(LENGTH(`picture`), 0),1,0)', $this->hasPicture])
            ->andFilterWhere(['like', 'IF(IFNULL(LENGTH(`image_rights_upload`), 0),1,0)', $this->hasImageRights]);

        return $dataProvider;
    }
}
