<?php

namespace app\models\search;

use app\models\Participant;
use Yii;
use yii\base\Model;
use yii\data\ActiveDataProvider;
use yii\helpers\ArrayHelper;

/**
 * ParticipantSearch represents the model behind the search form of `\app\models\Participant`.
 */
class ParticipantSearch extends Participant
{
    public $hasPicture;

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id_participant', 'id_login', 'id_nationality', 'id_document_type', 'id_education', 'id_vocational_skills_type', 'dietary_restriction', 'dr01', 'dr02', 'dr03', 'dr04', 'dr05', 'dr06', 'dr07', 'dr08', 'id_entity_current', 'active', 'hasPicture'], 'integer'],
            [['name', 'nickname', 'email', 'email_alternative', 'date_birth', 'place_of_birth', 'identification_number', 'date_expiration', 'tax_number', 'social_security_number', 'address', 'city', 'postal_code', 'id_zone1', 'id_zone2', 'id_zone3', 'phone', 'phone_alternative', 'vocational_skills', 'id_gender', 'tshirt_size', 'iban', 'extra01', 'extra02', 'extra03', 'extra04', 'extra05', 'extra06', 'extra07', 'extra08', 'extra09', 'extra10', 'dr_other', 'notes', 'picture'], 'safe'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return ArrayHelper::merge(parent::attributeLabels(), [
            'hasPicture' => Yii::t('app', 'Possui foto'),
        ]);
    }

    /**
     * @inheritdoc
     */
    public function scenarios()
    {
        // bypass scenarios() implementation in the parent class
        return Model::scenarios();
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params)
    {
        $query = Participant::find();

        // add conditions that should always apply here

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
            'pagination' => [
                'pageSize' => 40,
            ],
        ]);

        $this->load($params);

        if (!$this->validate()) {
            // uncomment the following line if you do not want to return any records when validation fails
            // $query->where('0=1');
            return $dataProvider;
        }

        // grid filtering conditions
        $query->andFilterWhere([
            'id_participant' => $this->id_participant,
            'id_login' => $this->id_login,
            'id_nationality' => $this->id_nationality,
            'date_birth' => $this->date_birth,
            'id_document_type' => $this->id_document_type,
            'date_expiration' => $this->date_expiration,
            'id_education' => $this->id_education,
            'id_vocational_skills_type' => $this->id_vocational_skills_type,
            'dietary_restriction' => $this->dietary_restriction,
            'dr01' => $this->dr01,
            'dr02' => $this->dr02,
            'dr03' => $this->dr03,
            'dr04' => $this->dr04,
            'dr05' => $this->dr05,
            'dr06' => $this->dr06,
            'dr07' => $this->dr07,
            'dr08' => $this->dr08,
            'id_entity_current' => $this->id_entity_current,
            'active' => $this->active,
        ]);

        $query->andFilterWhere(['like', 'name', $this->name])
            ->andFilterWhere(['like', 'nickname', $this->nickname])
            ->andFilterWhere(['like', 'email', $this->email])
            ->andFilterWhere(['like', 'email_alternative', $this->email_alternative])
            ->andFilterWhere(['like', 'place_of_birth', $this->place_of_birth])
            ->andFilterWhere(['like', 'identification_number', $this->identification_number])
            ->andFilterWhere(['like', 'tax_number', $this->tax_number])
            ->andFilterWhere(['like', 'social_security_number', $this->social_security_number])
            ->andFilterWhere(['like', 'address', $this->address])
            ->andFilterWhere(['like', 'city', $this->city])
            ->andFilterWhere(['like', 'postal_code', $this->postal_code])
            ->andFilterWhere(['like', 'id_zone1', $this->id_zone1])
            ->andFilterWhere(['like', 'id_zone2', $this->id_zone2])
            ->andFilterWhere(['like', 'id_zone3', $this->id_zone3])
            ->andFilterWhere(['like', 'phone', $this->phone])
            ->andFilterWhere(['like', 'phone_alternative', $this->phone_alternative])
            ->andFilterWhere(['like', 'vocational_skills', $this->vocational_skills])
            ->andFilterWhere(['like', 'id_gender', $this->id_gender])
            ->andFilterWhere(['like', 'tshirt_size', $this->tshirt_size])
            ->andFilterWhere(['like', 'iban', $this->iban])
            ->andFilterWhere(['like', 'extra01', $this->extra01])
            ->andFilterWhere(['like', 'extra02', $this->extra02])
            ->andFilterWhere(['like', 'extra03', $this->extra03])
            ->andFilterWhere(['like', 'extra04', $this->extra04])
            ->andFilterWhere(['like', 'extra05', $this->extra05])
            ->andFilterWhere(['like', 'extra06', $this->extra06])
            ->andFilterWhere(['like', 'extra07', $this->extra07])
            ->andFilterWhere(['like', 'extra08', $this->extra08])
            ->andFilterWhere(['like', 'extra09', $this->extra09])
            ->andFilterWhere(['like', 'extra10', $this->extra10])
            ->andFilterWhere(['like', 'dr_other', $this->dr_other])
            ->andFilterWhere(['like', 'notes', $this->notes])
            ->andFilterWhere(['like', 'picture', $this->picture])
            ->andFilterWhere(['like', 'IF(IFNULL(LENGTH(`picture`), 0),1,0)', $this->hasPicture]);

        return $dataProvider;
    }
}
