<?php

namespace app\modules\user\controllers;

use Yii;
use yii\web\Controller;
use yii\filters\AccessControl;

class DefaultController extends Controller
{
    public $module;

    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::className(),
                'rules' => [
                    [
                        'actions' => ['index'],
                        'allow' => true,
                        'roles' => ['?', '@'],
                    ],
                    [
                        'actions' => ['login', 'forgot', 'reset'],
                        'allow' => true,
                        'roles' => ['?'],
                    ],
                ],
            ],
        ];
    }

    public function actionIndex()
    {
        return $this->redirect(['/user/login']);
    }

    public function actionLogin()
    {
        $this->layout = '//login';
        $model = $this->module->model('LoginForm');

        $post = Yii::$app->request->post();

        if ($model->load($post) && $model->validate()) {
            $returnUrl = $this->performLogin($model->getUser(), $model->rememberMe);
            return $this->redirect($returnUrl);
        }

        return $this->render('login', compact('model'));
    }

    protected function performLogin($user, $rememberMe = true)
    {
        $loginDuration = $rememberMe ? $this->module->loginDuration : 0;
        Yii::$app->user->login($user, $loginDuration);

        $loginRedirect = $this->module->loginRedirect;
        $returnUrl = Yii::$app->user->getReturnUrl($loginRedirect);

        if (strpos($returnUrl, 'user/login') !== false || strpos($returnUrl, 'user/logout') !== false) {
            $returnUrl = null;
        }

        return $returnUrl;
    }

    public function actionForgot()
    {
        $this->layout = '//login';

        $model = $this->module->model('ForgotForm');

        if ($model->load(Yii::$app->request->post()) && $model->sendForgotEmail()) {
            Yii::$app->session->setFlash('Forgot-success', 'As instruções para alteração da password foram enviadas para o seu email..');
        }

        return $this->render('forgot', compact('model'));
    }

    public function actionReset($token)
    {
        $this->layout = '//login';

        $userToken = $this->module->model('UserToken');

        $userToken = $userToken::findByToken($token, $userToken::TYPE_PASSWORD_RESET);

        if (!$userToken) {
            return $this->render('reset', ['invalidToken' => true]);
        }

        $success = false;
        $user = $this->module->model('User');
        $user = $user::findOne($userToken->user_id);
        $user->setScenario('reset');

        if ($user->load(Yii::$app->request->post()) && $user->save()) {
            $userToken->delete();
            $success = true;
        }

        return $this->render('reset', compact('user', 'success'));
    }
}
