<?php

namespace app\modules\user\models\forms;

use Yii;
use yii\base\Model;
use yii\swiftmailer\Mailer;
use yii\swiftmailer\Message;

class ForgotForm extends Model
{
    public $email;

    protected $user = false;

    public $module;

    public function init()
    {
        if (!$this->module) 
        {
            $this->module = Yii::$app->getModule("user");
        }
    }

    public function rules()
    {
        return [
            ["email", "required"],
            ["email", "email"],
            ["email", "validateEmail"],
            ["email", "filter", "filter" => "trim"],
        ];
    }

    public function validateEmail()
    {
        $this->user = $this->getUser();

        if (!$this->user) 
        {
            $this->addError("email", "Email não encontrado.");
        }
    }

    public function getUser()
    {
        if ($this->user === false)
        {
            $user = $this->module->model("User");
            $this->user = $user::find()->joinWith(['participant'])->andWhere(["email" => $this->email])->one();
        }
        
        return $this->user;
    }

    public function attributeLabels()
    {
        return 
        [
            "email" => Yii::t("user", "Email"),
        ];
    }

    public function sendForgotEmail()
    {
        if ($this->validate())
        {
            $user = $this->getUser();

            $expireTime = $this->module->resetExpireTime;
            $expireTime = $expireTime ? gmdate("Y-m-d H:i:s", strtotime($expireTime)) : null;

            $userToken = $this->module->model("UserToken");
            $userToken = $userToken::generate($user->id_login, $userToken::TYPE_PASSWORD_RESET, null, $expireTime);

            $mailer = Yii::$app->mailer;
            $oldViewPath = $mailer->viewPath;
            $mailer->viewPath = $this->module->emailViewPath;

            $subject = Yii::t('app', "Recuperar password");
            $result = $mailer->compose('forgotPassword', compact("subject", "user", "userToken"))
                ->setTo($user->participant->email)
                ->setSubject($subject . ' - SIG Skills')
                ->send();

            $mailer->viewPath = $oldViewPath;
            return $result;
        }

        return false;
    }
}