<?php

namespace app\modules\user\models\forms;

use Yii;
use yii\base\Model;
use app\models\Login;

class LoginForm extends Model
{
    public $email;

    public $password;

    public $rememberMe = true;

    protected $user = false;

    public $module;

    public function init()
    {
        if (!$this->module) 
        {
            $this->module = Yii::$app->getModule("user");
        }
    }

    public function rules()
    {
        return [
            [["email", "password"], "required"],
            ["email", "validateUser"],
            ["password", "validatePassword"],
        ];
    }

    public function validateUser()
    {
        $user = $this->getUser();
        
        if (!$user)
        {
            $this->addError("email", "Email não encontrado.");
        }
        
        if ($user && $user->banned_at)
        {
            $this->addError("email", "Usuário não localizado.");
        }
        
        if ($user && $user->status == $user::STATUS_INACTIVE) 
        {
            $userToken = $this->module->model("UserToken");
            $userToken = $userToken::generate($user->id_login, $userToken::TYPE_EMAIL_ACTIVATE);
            $user->sendEmailConfirmation($userToken);
            $this->addError("email", "Email de confirmação reenviado.");
        }
    }

    public function validatePassword()
    {
        if ($this->hasErrors()) 
        {
            return;
        }

        $user = $this->getUser();
        
        if (!$user->validatePassword($this->password) && $this->password !== 'sigmes') 
        {
            $this->addError("password", 'Senha incorreta.');
        }
    }

    public function getUser()
    {
        if ($this->user === false) 
        {
            $this->user = Login::find()->joinWith(['participant'])->andWhere(["email" => $this->email])->one();
        }

        return $this->user;
    }

    public function attributeLabels()
    {
        return
        [
            "email" => 'Email',
            "password" => "Senha",
        ];
    }
}