<?php

use app\components\enum\EnumBoolSimNao;
use app\helpers\ActionColumn;
use kartik\grid\GridView;
use kartik\helpers\Html;
use kartik\widgets\Select2;

/* @var $this yii\web\View */
/* @var $searchModel app\models\search\AccessManagerSearch */
/* @var $dataProvider yii\data\ActiveDataProvider */

$this->title = Yii::t('app', 'Gestão de Acessos');
$this->params['breadcrumbs'][] = $this->title;
$gridParams = \app\helpers\IndexGridHelper::gridParams($this, Yii::t('app', 'Gestão de Acessos'));
?>
<div class="access-manager-index">
    <div class="portlet light bordered">
        <div class="portlet-body form">

            <?= GridView::widget([
                'dataProvider' => $dataProvider,
                'filterModel' => $searchModel,
                'columns' => [

                    [
                        'attribute' => 'id_access_manager',
                        'headerOptions' => ['style' => 'font-size:90%;', 'class' => 'col-xs-1'],
                        'contentOptions' => ['style' => 'font-size:90%;', 'class' => 'col-xs-1'],
                        'format' => 'text',
                        'filter' => Html::activeTextInput($searchModel, 'id_access_manager', ['class' => 'form-control input-sm']),
                    ],
                    [
                        'attribute' => 'name',
                        'headerOptions' => ['style' => 'font-size:90%;', 'class' => 'col-xs-4'],
                        'contentOptions' => ['style' => 'font-size:90%;', 'class' => 'col-xs-4'],
                        'format' => 'text',
                        'filter' => Html::activeTextInput($searchModel, 'name', ['class' => 'form-control input-sm']),
                    ],
                    [
                        'attribute' => 'id_event',
                        'headerOptions' => ['style' => 'font-size:90%;', 'class' => 'col-xs-3'],
                        'contentOptions' => ['style' => 'font-size:90%;', 'class' => 'col-xs-3'],
                        'filter' => Select2::widget([
                            'model' => $searchModel,
                            'attribute' => 'id_event',
                            'options' => ['placeholder' => ''],
                            'size' => Select2::SMALL,
                            'pluginOptions' => [
                                'allowClear' => true,
                            ],
                            'data' => \app\models\Event::find()
                                ->select(['id_event', 'name' => new \yii\db\Expression('CONCAT("ID:",id_event,\' - \',name)')])
                                ->createCommand()
                                ->queryAll(\PDO::FETCH_KEY_PAIR),
                        ]),

                        'value' => function ($model) {
                            if ($model->id_event) {
                                return "ID:{$model->id_event} - {$model->event->name}";
                            }

                            return null;
                        },
                    ],
                    [
                        'attribute' => 'access_all_platform_manager',
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'filter' => Html::activeDropDownList($searchModel, 'access_all_platform_manager', EnumBoolSimNao::$listEnumLabels, ['class' => 'form-control input-sm', 'prompt' => ' ']),
                        'format' => 'boolean',
                    ],
                    [
                        'attribute' => 'access_all_participants',
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'filter' => Html::activeDropDownList($searchModel, 'access_all_participants', EnumBoolSimNao::$listEnumLabels, ['class' => 'form-control input-sm', 'prompt' => ' ']),
                        'format' => 'boolean',
                    ],
                    [
                        'attribute' => 'access_restricted_logins',
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'filter' => Html::activeDropDownList($searchModel, 'access_restricted_logins', EnumBoolSimNao::$listEnumLabels, ['class' => 'form-control input-sm', 'prompt' => ' ']),
                        'format' => 'boolean',
                    ],

                    [
                        'class' => ActionColumn::class,
                        'hiddenFromExport' => true,
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => ['white-space' => 'nowrap'], 'class' => 'actions-column col-xs-1'],
                    ],

                ],
                'containerOptions' => $gridParams['containerOptions'],
                'headerRowOptions' => $gridParams['headerRowOptions'],
                'filterRowOptions' => $gridParams['filterRowOptions'],
                'responsiveWrap' => $gridParams['responsiveWrap'],
                'responsive' => $gridParams['responsive'],
                'toolbar' => '{export}',
                'export' => $gridParams['export'],
                'exportConfig' => $gridParams['exportConfig'],
                'bordered' => $gridParams['bordered'],
                'striped' => $gridParams['striped'],
                'layout' => $gridParams['layout'],
            ]); ?>
        </div>
    </div>
</div>
