<?php

use app\assets\EntityAsset;
use app\helpers\ActiveForm;
use app\models\Entity;
use app\models\Participant;
use app\models\Zone1;
use app\models\Zone2;
use kartik\helpers\Html;
use kartik\widgets\Select2;
use yii\widgets\MaskedInput;

/* @var $this yii\web\View */
/* @var $model app\models\Entity */
/* @var $form ActiveForm */

EntityAsset::register($this);
?>
<div class="row">
    <div class="col-sm-12 col-lg-12">
        <div class="entity-form">
            <div class="portlet light bordered">
                <div class="portlet-body form">
                    <?php $form = ActiveForm::begin(['id' => 'entity-form', 'type' => ActiveForm::TYPE_HORIZONTAL, 'formConfig' => ['labelSpan' => 3]]); ?>

                    <div class="form-body">
                        <p class="text-right">
                            <?= Html::a(Html::icon('menu-left') . ' ' . Yii::t('app', 'Voltar'), ['index'], ['class' => 'btn default']) ?>
                        </p>

                        <div class="row">
                            <div class="col-md-12">
                                <?= $form->field($model, 'name')->textInput(['maxlength' => true]) ?>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-12">
                                <?= $form->field($model, 'id_participant_platform_manager')->widget(Select2::className(), [
                                    'options' => ['placeholder' => ''],
                                    'pluginOptions' => [
                                        'allowClear' => true,
                                    ],
                                    'data' => Participant::find()
                                        ->select(['id_participant', 'name' => new \yii\db\Expression('CONCAT("ID:",id_participant,\' - \',name)')])
                                        ->createCommand()
                                        ->queryAll(\PDO::FETCH_KEY_PAIR),
                                ]); ?>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-12">
                                <?= $form->field($model, 'address')->textInput(['maxlength' => true]) ?>
                            </div>
                        </div>


                        <div class="row">
                            <div class="col-md-12">
                                <?= $form->field($model, 'city')->textInput(['maxlength' => true]) ?>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-12">
                                <?= $form->field($model, 'postal_code')->widget(MaskedInput::class, ['mask' => '9999-999']) ?>
                            </div>
                        </div>

                        <div class="row row-select-zones">
                            <div class="col-md-12">
                                <?= $form->field($model, 'id_zone1')->widget(Select2::className(), [
                                    'data' => Zone1::find()
                                        ->select(['id_zone1', 'name' => new \yii\db\Expression('CONCAT("ID:",id_zone1,\' - \',name)')])
                                        ->createCommand()
                                        ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    'options' => ['placeholder' => ''],
                                    'pluginOptions' => [
                                        'allowClear' => true,
                                    ],
                                ]); ?>
                            </div>
                        </div>

                        <div class="row row-select-zones">
                            <div class="col-md-12">
                                <?= $form->field($model, 'id_zone2')->widget(Select2::className(), [
                                    'data' => Zone2::find()
                                        ->select(['id_zone2', 'name' => new \yii\db\Expression('CONCAT("ID:",id_zone2,\' - \',name)')])
                                        ->andWhere(['id_zone1' => $model->id_zone1])
                                        ->createCommand()
                                        ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    'options' => ['placeholder' => ''],
                                    'pluginOptions' => [
                                        'allowClear' => true,
                                    ],
                                ]); ?>
                            </div>
                        </div>

                        <div class="row row-select-zones row-select-zone3" <?= (!$model->id_zone3) ? 'style="display: none;"' : ''; ?> >
                            <div class="col-md-12">
                                <?= $form->field($model, 'id_zone3')->widget(Select2::className(), [
                                    'options' => ['placeholder' => ''],
                                    'pluginOptions' => [
                                        'allowClear' => true,
                                    ],
                                ]); ?>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-12">
                                <?= $form->field($model, 'id_entity_scope')->widget(Select2::className(), [
                                    'options' => ['placeholder' => ''],
                                    'pluginOptions' => [
                                        'allowClear' => true,
                                    ],
                                    'data' => \app\models\EntityScope::find()
                                        ->select(['id_entity_scope', 'name' => new \yii\db\Expression('CONCAT("ID:",id_entity_scope,\' - \',name)')])
                                        ->createCommand()
                                        ->queryAll(\PDO::FETCH_KEY_PAIR),
                                ]); ?>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-12">
                                <?= $form->field($model, 'entity_is_main')->switchSimNao() ?>
                            </div>
                        </div>

                        <div id="div-select-id_entity_main" class="row"  style="display: <?= $model->entity_is_main ? 'none' : 'block' ?>;">
                            <div class="col-md-12">
                                <?= $form->field($model, 'id_entity_main')->widget(Select2::className(), [
                                    'options' => ['placeholder' => ''],
                                    'pluginOptions' => [
                                        'allowClear' => true,
                                    ],
                                    'data' => Entity::find()
                                        ->select(['id_entity', 'name' => new \yii\db\Expression('CONCAT("ID:",id_entity,\' - \',name)')])
                                        ->andWhere(['entity_is_main' => 1])
                                        ->createCommand()
                                        ->queryAll(\PDO::FETCH_KEY_PAIR),
                                ]); ?>
                            </div>
                        </div>


                        <div class="row">
                            <div class="col-md-12">
                                <?= $form->field($model, 'email')->textInput(['maxlength' => true]) ?>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-12">
                                <?= $form->field($model, 'phone')->textInput(['maxlength' => true, ]) ?>
                            </div>
                        </div>


                        <div class="row">
                            <div class="col-md-12">
                                <?= $form->field($model, 'direction_name')->textInput(['maxlength' => true]) ?>

                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-12">
                                <?= $form->field($model, 'direction_email')->textInput(['maxlength' => true]) ?>

                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-12">
                                <?= $form->field($model, 'direction_position')->textInput(['maxlength' => true]) ?>
                            </div>
                        </div>


                        <div class="row">
                            <div class="col-md-12">
                                <?= $form->field($model, 'alternative_contact_name')->textInput(['maxlength' => true]) ?>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-12">
                                <?= $form->field($model, 'alternative_contact_email')->textInput(['maxlength' => true]) ?>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-12">
                                <?= $form->field($model, 'alternative_contact_direct_phone')->textInput(['maxlength' => true]) ?>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-12">
                                <?= $form->field($model, 'notes')->textarea(['rows' => 6]) ?>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-12">
                                <?= $form->field($model, 'active')->switchSimNao() ?>
                            </div>
                        </div>
                    </div>

                    <?= $this->render('@layouts/_btnFormActions') ?>

                    <!-- END FORM-->
                    <?php ActiveForm::end(); ?>

                </div>
            </div>
        </div>
    </div>
</div>
