<?php

use app\components\enum\EnumBoolSimNao;
use app\helpers\ActionColumn;
use app\models\EntityScope;
use app\models\Participant;
use kartik\grid\GridView;
use kartik\helpers\Html;
use kartik\widgets\Select2;

/* @var $this yii\web\View */
/* @var $searchModel app\models\search\EntitySearch */
/* @var $dataProvider yii\data\ActiveDataProvider */

$this->title = Yii::t('app', 'Gerir Entidades');
$this->params['breadcrumbs'][] = $this->title;
$gridParams = \app\helpers\IndexGridHelper::gridParams($this, 'Entidade');

?>
<div class="entity-index">
    <div class="portlet light bordered">
        <div class="portlet-body form">
            <?= GridView::widget([
                'dataProvider' => $dataProvider,
                'filterModel' => $searchModel,
                'columns' => [
                    [
                        'attribute' => 'id_entity',
                        'headerOptions' => ['class' => 'col-xs-1', 'style' => 'font-size:90%;'],
                        'contentOptions' => ['class' => 'col-xs-1', 'style' => 'font-size:90%;'],
                        'filter' => Html::activeTextInput($searchModel, 'id_entity', ['class' => 'form-control input-sm']),
                    ],
                    [
                        'attribute' => 'name',
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'filter' => Html::activeTextInput($searchModel, 'name', ['class' => 'form-control input-sm']),
                    ],
                    [
                        'attribute' => 'city',
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'filter' => Html::activeTextInput($searchModel, 'city', ['class' => 'form-control input-sm']),
                    ],
                    [
                        'headerOptions' => ['class' => 'col-xs-3', 'style' => 'font-size:90%;'],
                        'contentOptions' => ['class' => 'col-xs-3', 'style' => 'font-size:90%;'],
                        'attribute' => 'id_participant_platform_manager',
                        'filter' => Select2::widget([
                            'model' => $searchModel,
                            'attribute' => 'id_participant_platform_manager',
                            'options' => ['placeholder' => ''],
                            'size' => Select2::SMALL,
                            'pluginOptions' => [
                                'allowClear' => true,
                            ],
                            'data' => Participant::find()
                                ->select(['id_participant', 'name' => new \yii\db\Expression('CONCAT("ID:",id_participant,\' - \',name)')])
                                ->createCommand()
                                ->queryAll(\PDO::FETCH_KEY_PAIR),
                        ]),
                        'value' => function ($model) {
                            if ($model->participantPlatformManager) {
                                return "ID:{$model->id_participant_platform_manager} - {$model->participantPlatformManager->name}";
                            }

                            return null;
                        },
                    ],
                    [
                        'headerOptions' => ['class' => 'col-xs-3', 'style' => 'font-size:90%;'],
                        'contentOptions' => ['class' => 'col-xs-3', 'style' => 'font-size:90%;'],
                        'attribute' => 'id_entity_scope',
                        'filter' => Select2::widget([
                            'size' => Select2::SMALL,
                            'model' => $searchModel,
                            'attribute' => 'id_entity_scope',
                            'options' => ['placeholder' => ''],
                            'pluginOptions' => [
                                'allowClear' => true,
                            ],
                            'data' => EntityScope::find()
                                ->select(['id_entity_scope', 'name' => new \yii\db\Expression('CONCAT("ID:",id_entity_scope,\' - \',name)')])
                                ->createCommand()
                                ->queryAll(\PDO::FETCH_KEY_PAIR),
                        ]),
                        'value' => function ($model) {
                            if ($model->entityScope) {
                                return "ID:{$model->id_entity_scope} - {$model->entityScope->name}";
                            }

                            return null;
                        },
                    ],
                    [
                        'headerOptions' => ['class' => 'col-xs-1', 'style' => 'font-size:90%;'],
                        'contentOptions' => ['class' => 'col-xs-1', 'style' => 'font-size:90%;'],
                        'attribute' => 'active',
                        'filter' => Html::activeDropDownList($searchModel, 'active', EnumBoolSimNao::$listEnumLabels, ['class' => 'form-control input-sm', 'prompt' => ' ']),
                        'format' => 'boolean',
                    ],

                    ['class' => ActionColumn::class],
                ],

                'containerOptions' => $gridParams['containerOptions'],
                'headerRowOptions' => $gridParams['headerRowOptions'],
                'filterRowOptions' => $gridParams['filterRowOptions'],
                'responsiveWrap' => $gridParams['responsiveWrap'],
                'responsive' => $gridParams['responsive'],
                'toolbar' => $gridParams['toolbar'],
                'export' => $gridParams['export'],
                'exportConfig' => $gridParams['exportConfig'],
                'bordered' => $gridParams['bordered'],
                'striped' => $gridParams['striped'],
                'layout' => $gridParams['layout'],
            ]); ?>
        </div>
    </div>
</div>
