<?php

use app\components\enum\EnumBoolSimNao;
use app\helpers\ConstantsHelper;
use app\models\Entity;
use kartik\grid\GridView;
use kartik\helpers\Html;
use kartik\widgets\Select2;
use yii\db\Expression;

/* @var $this yii\web\View */
/* @var $searchModel app\models\search\EventParticipantViewSearch */
/* @var $dataProvider yii\data\ActiveDataProvider */

$this->title = Yii::t('app', 'Visualizar Eventos/Participantes (Dados Detalhados)');
$this->params['breadcrumbs'][] = $this->title;
$gridParams = \app\helpers\IndexGridHelper::gridParams($this, Yii::t('app', 'Visualizar Eventos/Participantes (Dados Detalhados)'));
unset($gridParams['exportConfig'][GridView::PDF]);

$css = <<<CSS
.table thead tr th, .table-bordered > thead > tr > th, .table-bordered > thead > tr > td, .table-bordered > tbody > tr > th, .table-bordered > tbody > tr > td, .table-bordered > tfoot > tr > th, .table-bordered > tfoot > tr > td {
    font-size: 80%;
    padding:3px;
    min-width:75px;
}
.select2-container--krajee .select2-dropdown {
    font-size: 80%;
    min-width:200px;
}
.input-sm.select2-container--krajee .select2-selection--single, .input-group-sm .select2-container--krajee .select2-selection--single{
    padding-left: 2px;
}

.select2-container--krajee .select2-selection--single .select2-selection__clear {
    right: 2.1rem;
}

.select2-container--krajee .select2-selection--single .select2-selection__rendered{
    margin-right: 10px;
}
CSS;

$this->registerCss($css)
?>
<div class="event-participant-index">
    <div class="portlet light bordered">
        <div class="portlet-body form">
            <p>
                <?= $this->render('_search', ['model' => $searchModel]) ?>
            </p>

            <?php if ($searchModel->id_event) : ?>
                <hr>
                <div class="row">
                    <div class="col-xs-12">
                        <?= GridView::widget([
                            'dataProvider' => $dataProvider,
                            'filterModel' => $searchModel,
                            'columns' => [

                                [
                                    'attribute' => 'id_event_participant',
                                    'format' => 'text',
                                    'filter' => Html::activeTextInput($searchModel, 'id_event_participant', ['class' => 'form-control input-sm']),
                                ],

                                [
                                    'attribute' => 'id_participant',
                                    'filter' => Select2::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'id_participant',
                                        'options' => ['placeholder' => ''],
                                        'size' => Select2::SMALL,
                                        'pluginOptions' => [
                                            'allowClear' => true,
                                        ],
                                        'data' => \app\models\Participant::find()
                                            ->select(['id_participant', 'name' => new Expression('CONCAT("ID:",id_participant,\' - \',name)')])
                                            ->createCommand()
                                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    ]),
                                    'value' => function ($model) {
                                        if ($model->id_participant) {
                                            return "ID:{$model->id_participant} - {$model->name}";
                                        }

                                        return null;
                                    },
                                ],
                                [
                                    'attribute' => 'id_entity',
                                    'filter' => Select2::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'id_entity',
                                        'options' => ['placeholder' => ''],
                                        'size' => Select2::SMALL,
                                        'pluginOptions' => [
                                            'allowClear' => true,
                                        ],
                                        'data' => Entity::find()
                                            ->select(['id_entity', 'name' => new Expression('CONCAT("ID:",id_entity,\' - \',name)')])
                                            ->createCommand()
                                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    ]),
                                    'value' => function ($model) {
                                        if ($model->id_entity) {
                                            return "ID:{$model->id_entity} - {$model->entity->name}";
                                        }

                                        return null;
                                    },
                                ],

                                [
                                    'attribute' => 'id_event_skill',
                                    'filter' => Select2::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'id_event_skill',
                                        'options' => ['placeholder' => ''],
                                        'size' => Select2::SMALL,
                                        'pluginOptions' => [
                                            'allowClear' => true,
                                        ],
                                        'data' => \app\models\EventSkill::find()
                                            ->select(['id_event_skill', 'name' => new Expression('CONCAT("ID:",id_event_skill,\' - \',name)')])
                                            ->andWhere(['id_event' => $searchModel->id_event])
                                            ->createCommand()
                                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    ]),
                                    'value' => function ($model) {
                                        if ($model->id_event_skill) {
                                            return "ID:{$model->id_event_skill} - {$model->eventSkill->name}";
                                        }

                                        return null;
                                    },
                                ],
                                [
                                    'attribute' => 'id_participant_type',
                                    'filter' => Select2::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'id_participant_type',
                                        'options' => ['placeholder' => ''],
                                        'size' => Select2::SMALL,
                                        'pluginOptions' => [
                                            'allowClear' => true,
                                        ],
                                        'data' => \app\models\ParticipantType::find()
                                            ->select(['id_participant_type', 'name' => new Expression('CONCAT("ID:",id_participant_type,\' - \',name)')])
                                            ->createCommand()
                                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    ]),
                                    'value' => function ($model) {
                                        if ($model->id_participant_type) {
                                            return "ID:{$model->id_participant_type} - {$model->participantType->name}";
                                        }

                                        return null;
                                    },
                                ],

                                [
                                    'attribute' => 'id_event_participant_state',
                                    'filter' => Select2::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'id_event_participant_state',
                                        'options' => ['placeholder' => ''],
                                        'size' => Select2::SMALL,
                                        'pluginOptions' => [
                                            'allowClear' => true,
                                        ],
                                        'data' => \app\models\EventParticipantState::find()
                                            ->select(['id_event_participant_state', 'name' => new Expression('CONCAT("ID:",id_event_participant_state,\' - \',name)')])
                                            ->createCommand()
                                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    ]),
                                    'value' => function ($model) {
                                        if ($model->id_event_participant_state) {
                                            return "ID:{$model->id_event_participant_state} - {$model->eventParticipantState->name}";
                                        }

                                        return null;
                                    },
                                ],
                                [
                                    'attribute' => 'id_cluster',
                                    'filter' => Select2::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'id_cluster',
                                        'options' => ['placeholder' => ''],
                                        'size' => Select2::SMALL,
                                        'pluginOptions' => [
                                            'allowClear' => true,
                                        ],
                                        'data' => \app\models\Cluster::find()
                                            ->select(['id_cluster', 'name' => new Expression('CONCAT("ID:",id_cluster,\' - \',name)')])
                                            ->createCommand()
                                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    ]),
                                    'value' => function ($model) {
                                        if ($model->id_cluster) {
                                            return "ID:{$model->id_cluster} - {$model->clusterName}";
                                        }

                                        return null;
                                    },
                                ],

                                [
                                    'attribute' => 'id_venue_section',
                                    'filter' => Select2::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'id_venue_section',
                                        'options' => ['placeholder' => ''],
                                        'size' => Select2::SMALL,
                                        'pluginOptions' => [
                                            'allowClear' => true,
                                        ],
                                        'data' => \app\models\VenueSection::find()
                                            ->select(['id_venue_section', 'name' => new Expression('CONCAT("ID:",id_venue_section,\' - \',name)')])
                                            ->createCommand()
                                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    ]),
                                    'value' => function ($model) {
                                        if ($model->id_venue_section) {
                                            return "ID:{$model->id_venue_section} - {$model->venueSectionName}";
                                        }

                                        return null;
                                    },
                                ],

                                [
                                    'attribute' => 'id_organization_region',
                                    'filter' => Select2::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'id_organization_region',
                                        'options' => ['placeholder' => ''],
                                        'size' => Select2::SMALL,
                                        'pluginOptions' => [
                                            'allowClear' => true,
                                        ],
                                        'data' => \app\models\OrganizationRegion::find()
                                            ->select([
                                                'id_organization_region',
                                                'name' => new Expression('CONCAT("ID:",id_organization_region,\' - \',name)'),
                                            ])
                                            ->createCommand()
                                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    ]),
                                    'value' => function ($model) {
                                        if ($model->id_organization_region) {
                                            return "ID:{$model->id_organization_region} - {$model->organizationRegionName}";
                                        }

                                        return null;
                                    },
                                ],

                                [
                                    'attribute' => 'nickname',
                                    'format' => 'text',
                                    'filter' => Html::activeTextInput($searchModel, 'nickname', ['class' => 'form-control input-sm']),
                                ],

                                [
                                    'attribute' => 'email',
                                    'format' => 'text',
                                    'filter' => Html::activeTextInput($searchModel, 'email', ['class' => 'form-control input-sm']),
                                ],

                                [
                                    'attribute' => 'id_nationality',
                                    'filter' => Select2::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'id_nationality',
                                        'options' => ['placeholder' => ''],
                                        'size' => Select2::SMALL,
                                        'pluginOptions' => [
                                            'allowClear' => true,
                                        ],
                                        'data' => \app\models\Nationality::find()
                                            ->select(['id_nationality', 'name' => new \yii\db\Expression('CONCAT("ID:",id_nationality,\' - \',name)')])
                                            ->createCommand()
                                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    ]),
                                    'value' => function ($model) {
                                        return $model->id_nationality ? "ID:{$model->id_nationality} - {$model->nationalityName}" : null;
                                    },
                                ],

                                [
                                    'attribute' => 'date_birth',
                                    'filter' => Html::activeTextInput($searchModel, 'date_birth', ['class' => 'form-control input-sm']),
                                ],

                                [
                                    'attribute' => 'place_of_birth',
                                    'filter' => Html::activeTextInput($searchModel, 'place_of_birth', ['class' => 'form-control input-sm']),
                                ],

                                [
                                    'attribute' => 'id_document_type',
                                    'filter' => Select2::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'id_document_type',
                                        'options' => ['placeholder' => ''],
                                        'size' => Select2::SMALL,
                                        'pluginOptions' => [
                                            'allowClear' => true,
                                        ],
                                        'data' => \app\models\DocumentType::find()
                                            ->select(['id_document_type', 'name' => new \yii\db\Expression('CONCAT("ID:",id_document_type,\' - \',name)')])
                                            ->createCommand()
                                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    ]),
                                    'value' => function ($model) {
                                        return $model->id_document_type ? "ID:{$model->id_document_type} - {$model->documentTypeName}" : null;
                                    },
                                ],

                                [
                                    'attribute' => 'identification_number',
                                    'filter' => Html::activeTextInput($searchModel, 'identification_number', ['class' => 'form-control input-sm']),
                                ],

                                [
                                    'attribute' => 'date_expiration',
                                    'filter' => Html::activeTextInput($searchModel, 'date_expiration', ['class' => 'form-control input-sm']),
                                ],

                                [
                                    'attribute' => 'tax_number',
                                    'filter' => Html::activeTextInput($searchModel, 'tax_number', ['class' => 'form-control input-sm']),
                                ],

                                [
                                    'attribute' => 'social_security_number',
                                    'filter' => Html::activeTextInput($searchModel, 'social_security_number', ['class' => 'form-control input-sm']),
                                ],

                                [
                                    'attribute' => 'address',
                                    'filter' => Html::activeTextInput($searchModel, 'address', ['class' => 'form-control input-sm']),
                                ],

                                [
                                    'attribute' => 'city',
                                    'filter' => Html::activeTextInput($searchModel, 'city', ['class' => 'form-control input-sm']),
                                ],

                                [
                                    'attribute' => 'postal_code',
                                    'filter' => Html::activeTextInput($searchModel, 'postal_code', ['class' => 'form-control input-sm']),
                                ],

                                [
                                    'attribute' => 'id_zone1',
                                    'filter' => Select2::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'id_zone1',
                                        'options' => ['placeholder' => ''],
                                        'size' => Select2::SMALL,
                                        'pluginOptions' => [
                                            'allowClear' => true,
                                        ],
                                        'data' => \app\models\Zone1::find()
                                            ->select(['id_zone1', 'name' => new \yii\db\Expression('CONCAT("ID:",id_zone1,\' - \',name)')])
                                            ->createCommand()
                                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    ]),
                                    'value' => function ($model) {
                                        return $model->id_zone1 ? "ID:{$model->id_zone1} - {$model->zone1Name}" : null;
                                    },
                                ],
                                [
                                    'attribute' => 'id_zone2',
                                    'filter' => Select2::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'id_zone2',
                                        'options' => ['placeholder' => ''],
                                        'size' => Select2::SMALL,
                                        'pluginOptions' => [
                                            'allowClear' => true,
                                        ],
                                        'data' => \app\models\Zone2::find()
                                            ->select(['id_zone2', 'name' => new \yii\db\Expression('CONCAT("ID:",id_zone2,\' - \',name)')])
                                            ->createCommand()
                                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    ]),
                                    'value' => function ($model) {
                                        return $model->id_zone2 ? "ID:{$model->id_zone2} - {$model->zone2Name}" : null;
                                    },
                                ],
                                [
                                    'attribute' => 'id_zone3',
                                    'filter' => Select2::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'id_zone3',
                                        'options' => ['placeholder' => ''],
                                        'size' => Select2::SMALL,
                                        'pluginOptions' => [
                                            'allowClear' => true,
                                        ],
                                        'data' => \app\models\Zone3::find()
                                            ->select(['id_zone3', 'name' => new \yii\db\Expression('CONCAT("ID:",id_zone3,\' - \',name)')])
                                            ->createCommand()
                                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    ]),
                                    'value' => function ($model) {
                                        return $model->id_zone3 ? "ID:{$model->id_zone3} - {$model->zone3Name}" : null;
                                    },
                                ],


                                [
                                    'attribute' => 'phone',
                                    'filter' => Html::activeTextInput($searchModel, 'phone', ['class' => 'form-control input-sm']),
                                ],


                                [
                                    'attribute' => 'phone_alternative',
                                    'filter' => Html::activeTextInput($searchModel, 'phone_alternative', ['class' => 'form-control input-sm']),
                                ],

                                [
                                    'attribute' => 'id_education',
                                    'filter' => Select2::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'id_education',
                                        'options' => ['placeholder' => ''],
                                        'size' => Select2::SMALL,
                                        'pluginOptions' => [
                                            'allowClear' => true,
                                        ],
                                        'data' => \app\models\Education::find()
                                            ->select(['id_education', 'name' => new \yii\db\Expression('CONCAT("ID:",id_education,\' - \',name)')])
                                            ->createCommand()
                                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    ]),
                                    'value' => function ($model) {
                                        return $model->id_education ? "ID:{$model->id_education} - {$model->educationName}" : null;
                                    },
                                ],
                                [
                                    'attribute' => 'id_vocational_skills_type',
                                    'filter' => Select2::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'id_vocational_skills_type',
                                        'options' => ['placeholder' => ''],
                                        'size' => Select2::SMALL,
                                        'pluginOptions' => [
                                            'allowClear' => true,
                                        ],
                                        'data' => \app\models\VocationSkillType::find()
                                            ->select(['id_vocational_skills_type', 'name' => new \yii\db\Expression('CONCAT("ID:",id_vocational_skills_type,\' - \',name)')])
                                            ->createCommand()
                                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    ]),
                                    'value' => function ($model) {
                                        return $model->id_vocational_skills_type ? "ID:{$model->id_vocational_skills_type} - {$model->vocationSkillTypeName}" : null;
                                    },
                                ],
                                [
                                    'attribute' => 'id_gender',
                                    'filter' => Html::activeDropDownList(
                                        $searchModel,
                                        'id_gender',
                                        \app\models\Gender::find()
                                            ->select(['id_gender', 'name'])
                                            ->createCommand()
                                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                                        ['class' => 'form-control input-sm', 'prompt' => ' ']
                                    ),
                                    'value' => function ($model) {
                                        return $model->id_gender ? $model->genderName : null;
                                    },
                                ],

                                [
                                    'attribute' => 'tshirt_size',
                                    'filter' => Html::activeDropDownList(
                                        $searchModel,
                                        'tshirt_size',
                                        ConstantsHelper::tShitSizes(),
                                        ['class' => 'form-control input-sm', 'prompt' => ' ']
                                    ),
                                ],

                                [
                                    'attribute' => 'iban',
                                    'filter' => Html::activeTextInput($searchModel, 'iban', ['class' => 'form-control input-sm']),
                                ],

                                [
                                    'attribute' => 'id_entity_current',
                                    'filter' => Select2::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'id_entity_current',
                                        'options' => ['placeholder' => ''],
                                        'size' => Select2::SMALL,
                                        'pluginOptions' => [
                                            'allowClear' => true,
                                        ],
                                        'data' => Entity::find()
                                            ->select(['id_entity', 'name' => new \yii\db\Expression('CONCAT("ID:",id_entity,\' - \',name)')])
                                            ->createCommand()
                                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    ]),
                                    'value' => function ($model) {
                                        return $model->id_entity_current ? "ID:{$model->id_entity_current} - {$model->entityCurrentName}" : null;
                                    },
                                ],

                                [
                                    'attribute' => 'extra01',
                                    'filter' => Html::activeTextInput($searchModel, 'extra01', ['class' => 'form-control input-sm']),
                                    'visible' => ConstantsHelper::constantHasLabel('extra01'),
                                ],
                                [
                                    'attribute' => 'extra02',
                                    'filter' => Html::activeTextInput($searchModel, 'extra02', ['class' => 'form-control input-sm']),
                                    'visible' => ConstantsHelper::constantHasLabel('extra02'),
                                ],
                                [
                                    'attribute' => 'extra03',
                                    'filter' => Html::activeTextInput($searchModel, 'extra03', ['class' => 'form-control input-sm']),
                                    'visible' => ConstantsHelper::constantHasLabel('extra03'),
                                ],
                                [
                                    'attribute' => 'extra04',
                                    'filter' => Html::activeTextInput($searchModel, 'extra04', ['class' => 'form-control input-sm']),
                                    'visible' => ConstantsHelper::constantHasLabel('extra04'),
                                ],
                                [
                                    'attribute' => 'extra05',
                                    'filter' => Html::activeTextInput($searchModel, 'extra05', ['class' => 'form-control input-sm']),
                                    'visible' => ConstantsHelper::constantHasLabel('extra05'),
                                ],
                                [
                                    'attribute' => 'extra06',
                                    'filter' => Html::activeTextInput($searchModel, 'extra06', ['class' => 'form-control input-sm']),
                                    'visible' => ConstantsHelper::constantHasLabel('extra06'),
                                ],
                                [
                                    'attribute' => 'extra07',
                                    'filter' => Html::activeTextInput($searchModel, 'extra07', ['class' => 'form-control input-sm']),
                                    'visible' => ConstantsHelper::constantHasLabel('extra07'),
                                ],
                                [
                                    'attribute' => 'extra08',
                                    'filter' => Html::activeTextInput($searchModel, 'extra08', ['class' => 'form-control input-sm']),
                                    'visible' => ConstantsHelper::constantHasLabel('extra08'),
                                ],
                                [
                                    'attribute' => 'extra09',
                                    'filter' => Html::activeTextInput($searchModel, 'extra09', ['class' => 'form-control input-sm']),
                                    'visible' => ConstantsHelper::constantHasLabel('extra09'),
                                ],
                                [
                                    'attribute' => 'extra10',
                                    'filter' => Html::activeTextInput($searchModel, 'extra10', ['class' => 'form-control input-sm']),
                                    'visible' => ConstantsHelper::constantHasLabel('extra10'),
                                ],

                                [
                                    'attribute' => 'dietary_restriction',
                                    'format' => 'boolean',
                                    'filter' => Html::activeDropDownList(
                                        $searchModel,
                                        'dietary_restriction',
                                        EnumBoolSimNao::$listEnumLabels,
                                        ['class' => 'form-control input-sm', 'prompt' => ' ']
                                    ),
                                ],

                                [
                                    'attribute' => 'dr01',
                                    'format' => 'boolean',
                                    'filter' => Html::activeDropDownList(
                                        $searchModel,
                                        'dr01',
                                        EnumBoolSimNao::$listEnumLabels,
                                        ['class' => 'form-control input-sm', 'prompt' => ' ']
                                    ),
                                    'label' => strlen(ConstantsHelper::constantLabel('dr01')) > 26 ? substr(ConstantsHelper::constantLabel('dr01'), 0, 26) :
                                        ConstantsHelper::constantLabel('dr01'),
                                    'visible' => ConstantsHelper::constantHasLabel('dr01'),
                                ],
                                [
                                    'attribute' => 'dr02',
                                    'format' => 'boolean',
                                    'filter' => Html::activeDropDownList(
                                        $searchModel,
                                        'dr02',
                                        EnumBoolSimNao::$listEnumLabels,
                                        ['class' => 'form-control input-sm', 'prompt' => ' ']
                                    ),
                                    'visible' => ConstantsHelper::constantHasLabel('dr02'),
                                ],
                                [
                                    'attribute' => 'dr03',
                                    'format' => 'boolean',
                                    'filter' => Html::activeDropDownList(
                                        $searchModel,
                                        'dr03',
                                        EnumBoolSimNao::$listEnumLabels,
                                        ['class' => 'form-control input-sm', 'prompt' => ' ']
                                    ),
                                    'visible' => ConstantsHelper::constantHasLabel('dr03'),
                                ],
                                [
                                    'attribute' => 'dr04',
                                    'format' => 'boolean',
                                    'filter' => Html::activeDropDownList(
                                        $searchModel,
                                        'dr04',
                                        EnumBoolSimNao::$listEnumLabels,
                                        ['class' => 'form-control input-sm', 'prompt' => ' ']
                                    ),
                                    'visible' => ConstantsHelper::constantHasLabel('dr04'),
                                ],
                                [
                                    'attribute' => 'dr05',
                                    'format' => 'boolean',
                                    'filter' => Html::activeDropDownList(
                                        $searchModel,
                                        'dr05',
                                        EnumBoolSimNao::$listEnumLabels,
                                        ['class' => 'form-control input-sm', 'prompt' => ' ']
                                    ),
                                    'visible' => ConstantsHelper::constantHasLabel('dr05'),
                                ],
                                [
                                    'attribute' => 'dr06',
                                    'format' => 'boolean',
                                    'filter' => Html::activeDropDownList(
                                        $searchModel,
                                        'dr06',
                                        EnumBoolSimNao::$listEnumLabels,
                                        ['class' => 'form-control input-sm', 'prompt' => ' ']
                                    ),
                                    'visible' => ConstantsHelper::constantHasLabel('dr06'),
                                ],
                                [
                                    'attribute' => 'dr07',
                                    'format' => 'boolean',
                                    'filter' => Html::activeDropDownList(
                                        $searchModel,
                                        'dr07',
                                        EnumBoolSimNao::$listEnumLabels,
                                        ['class' => 'form-control input-sm', 'prompt' => ' ']
                                    ),
                                    'visible' => ConstantsHelper::constantHasLabel('dr07'),
                                ],
                                [
                                    'attribute' => 'dr08',
                                    'format' => 'boolean',
                                    'filter' => Html::activeDropDownList(
                                        $searchModel,
                                        'dr08',
                                        EnumBoolSimNao::$listEnumLabels,
                                        ['class' => 'form-control input-sm', 'prompt' => ' ']
                                    ),
                                    'visible' => ConstantsHelper::constantHasLabel('dr08'),
                                ],
                                [
                                    'attribute' => 'dr_other',
                                    'format' => 'ntext',
                                    'filter' => Html::activeTextInput($searchModel, 'dr_other', ['class' => 'form-control input-sm']),
                                ],
                                [
                                    'attribute' => 'hasImageRights',
                                    'label' => Yii::t('app', 'Dados Completos'),
                                    'format' => 'labelBoolean',
                                    'value' => function ($model) {
                                        return (bool)$model->participant->image_rights_upload;
                                    },
                                    'filter' => Html::activeDropDownList(
                                        $searchModel,
                                        'hasImageRights',
                                        EnumBoolSimNao::$listEnumLabels,
                                        ['class' => 'form-control input-sm', 'prompt' => ' ']
                                    ),
                                ],
                                [
                                    'attribute' => 'picture',
                                    'format' => 'labelBoolean',
                                    'value' => function ($model) {
                                        return (bool)$model->picture;
                                    },
                                    'filter' => Html::activeDropDownList(
                                        $searchModel,
                                        'picture',
                                        EnumBoolSimNao::$listEnumLabels,
                                        ['class' => 'form-control input-sm', 'prompt' => ' ']
                                    ),
                                ],
                            ],
                            'containerOptions' => $gridParams['containerOptions'],
                            'headerRowOptions' => $gridParams['headerRowOptions'],
                            'filterRowOptions' => $gridParams['filterRowOptions'],
                            'responsiveWrap' => true,
                            'responsive' => true,
                            'toolbar' => '{export}',
                            'export' => $gridParams['export'],
                            'exportConfig' => $gridParams['exportConfig'],
                            'bordered' => $gridParams['bordered'],
                            'striped' => $gridParams['striped'],
                            'layout' => $gridParams['layout'],
                        ]); ?>
                    </div>
                </div>
            <?php endif; ?>
        </div>
    </div>
</div>