<?php

use app\helpers\ActionColumn;
use kartik\grid\GridView;
use kartik\helpers\Html;
use kartik\widgets\Select2;
use yii\helpers\ArrayHelper;

/* @var $this yii\web\View */
/* @var $searchModel app\models\search\EventParticipantSearch */
/* @var $dataProvider yii\data\ActiveDataProvider */

$this->title = Yii::t('app', 'Gerir Eventos/Participantes');
$this->params['breadcrumbs'][] = $this->title;
$id_event = ArrayHelper::getValue(Yii::$app->request->queryParams, 'EventParticipantSearch.id_event');
$gridParams = \app\helpers\IndexGridHelper::gridParams($this, Yii::t('app', 'Evento/Participante'), ['create', 'id_event' => $id_event]);
?>
<div class="event-participant-index">
    <div class="portlet light bordered">
        <div class="portlet-body form">
            <p>
                <?= $this->render('_search', ['model' => $searchModel]) ?>
            </p>

            <?php if ($searchModel->id_event) : ?>
                <hr>
                <div class="row">
                    <div class="col-xs-12">
                        <?= GridView::widget([
                            'dataProvider' => $dataProvider,
                            'filterModel' => $searchModel,
                            'columns' => [

                                [
                                    'attribute' => 'id_event_participant',
                                    'headerOptions' => ['style' => 'font-size:90%;'],
                                    'contentOptions' => ['style' => 'font-size:90%;'],
                                    'format' => 'text',
                                    'filter' => Html::activeTextInput($searchModel, 'id_event_participant', ['class' => 'form-control input-sm']),
                                ],

                                [
                                    'headerOptions' => ['style' => 'font-size:90%;'],
                                    'contentOptions' => ['style' => 'font-size:90%;'],
                                    'attribute' => 'id_participant',
                                    'filter' => Select2::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'id_participant',
                                        'options' => ['placeholder' => ''],
                                        'size' => Select2::SMALL,
                                        'pluginOptions' => [
                                            'allowClear' => true,
                                        ],
                                        'data' => \app\models\Participant::find()
                                            ->select(['id_participant', 'name' => new \yii\db\Expression('CONCAT("ID:",id_participant,\' - \',name)')])
                                            ->createCommand()
                                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    ]),
                                    'value' => function ($model) {
                                        if ($model->id_participant) {
                                            return "ID:{$model->id_participant} - {$model->participant->name}";
                                        }

                                        return null;
                                    },
                                ],
                                [
                                    'headerOptions' => ['style' => 'font-size:90%;'],
                                    'contentOptions' => ['style' => 'font-size:90%;'],
                                    'attribute' => 'id_entity',
                                    'filter' => Select2::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'id_entity',
                                        'options' => ['placeholder' => ''],
                                        'size' => Select2::SMALL,
                                        'pluginOptions' => [
                                            'allowClear' => true,
                                        ],
                                        'data' => \app\models\Entity::find()
                                            ->select(['id_entity', 'name' => new \yii\db\Expression('CONCAT("ID:",id_entity,\' - \',name)')])
                                            ->createCommand()
                                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    ]),
                                    'value' => function ($model) {
                                        if ($model->id_entity) {
                                            return "ID:{$model->id_entity} - {$model->entity->name}";
                                        }

                                        return null;
                                    },
                                ],

                                [
                                    'headerOptions' => ['style' => 'font-size:90%;'],
                                    'contentOptions' => ['style' => 'font-size:90%;'],
                                    'attribute' => 'id_event_skill',
                                    'filter' => Select2::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'id_event_skill',
                                        'options' => ['placeholder' => ''],
                                        'size' => Select2::SMALL,
                                        'pluginOptions' => [
                                            'allowClear' => true,
                                        ],
                                        'data' => \app\models\EventSkill::find()
                                            ->select(['id_event_skill', 'name' => new \yii\db\Expression('CONCAT("ID:",id_event_skill,\' - \',name)')])
                                            ->andWhere(['id_event' => $id_event])
                                            ->createCommand()
                                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    ]),
                                    'value' => function ($model) {
                                        if ($model->id_event_skill) {
                                            return "ID:{$model->id_event_skill} - {$model->eventSkill->name}";
                                        }

                                        return null;
                                    },
                                ],
                                [
                                    'headerOptions' => ['style' => 'font-size:90%;'],
                                    'contentOptions' => ['style' => 'font-size:90%;'],
                                    'attribute' => 'id_participant_type',
                                    'filter' => Select2::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'id_participant_type',
                                        'options' => ['placeholder' => ''],
                                        'size' => Select2::SMALL,
                                        'pluginOptions' => [
                                            'allowClear' => true,
                                        ],
                                        'data' => \app\models\ParticipantType::find()
                                            ->select(['id_participant_type', 'name' => new \yii\db\Expression('CONCAT("ID:",id_participant_type,\' - \',name)')])
                                            ->createCommand()
                                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    ]),
                                    'value' => function ($model) {
                                        if ($model->id_participant_type) {
                                            return "ID:{$model->id_participant_type} - {$model->participantType->name}";
                                        }

                                        return null;
                                    },
                                ],

                                [
                                    'headerOptions' => ['style' => 'font-size:90%;'],
                                    'contentOptions' => ['style' => 'font-size:90%;'],
                                    'attribute' => 'id_event_participant_state',
                                    'filter' => Select2::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'id_event_participant_state',
                                        'options' => ['placeholder' => ''],
                                        'size' => Select2::SMALL,
                                        'pluginOptions' => [
                                            'allowClear' => true,
                                        ],
                                        'data' => \app\models\EventParticipantState::find()
                                            ->select(['id_event_participant_state', 'name' => new \yii\db\Expression('CONCAT("ID:",id_event_participant_state,\' - \',name)')])
                                            ->createCommand()
                                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    ]),
                                    'value' => function ($model) {
                                        if ($model->id_event_participant_state) {
                                            return "ID:{$model->id_event_participant_state} - {$model->eventParticipantState->name}";
                                        }

                                        return null;
                                    },
                                ],

                                [
                                    'class' => ActionColumn::class,
                                    'hiddenFromExport' => true,
                                    'headerOptions' => ['style' => 'font-size:90%;'],
                                    'contentOptions' => ['style' => ['white-space' => 'nowrap'],
                                                         'class' => 'actions-column'],
                                ],

                            ],
                            'containerOptions' => $gridParams['containerOptions'],
                            'headerRowOptions' => $gridParams['headerRowOptions'],
                            'filterRowOptions' => $gridParams['filterRowOptions'],
                            'responsiveWrap' => $gridParams['responsiveWrap'],
                            'responsive' => $gridParams['responsive'],
                            'toolbar' => $gridParams['toolbar'],
                            'export' => $gridParams['export'],
                            'exportConfig' => $gridParams['exportConfig'],
                            'bordered' => $gridParams['bordered'],
                            'striped' => $gridParams['striped'],
                            'layout' => $gridParams['layout'],
                        ]); ?>
                    </div>
                </div>
            <?php endif; ?>
        </div>
    </div>
</div>