<?php

use app\helpers\ActiveForm;
use app\models\Cluster;
use app\models\CompetitionType;
use app\models\Skill;
use app\models\VenueSection;
use kartik\datecontrol\DateControl;
use kartik\helpers\Html;
use kartik\widgets\Select2;
use yii\helpers\ArrayHelper;

/* @var $this yii\web\View */
/* @var $model app\models\EventSkill */
/* @var $form ActiveForm */

$js = <<<JS
    $('#eventskill-id_skill').on('change', function() {
          var selectedTxt = this.options[this.selectedIndex].text, arr, skillName;
          arr = selectedTxt.split(' - ');
          skillName = arr[arr.length-1];
          
        $('#eventskill-name').val(skillName);

        App.blockUI({target: ".event-skill-form", animate: !0});
          
        $.ajax({
            url: 'cluster?id_skill=' + $(this).val()
        })
            .done(function (result) {
                $('#eventskill-id_cluster').val(result).trigger('change');
            })
            .always(function () {
                App.unblockUI(".event-skill-form");
            });
    });

    $('#eventskill-id_event').on('change', function() {
        App.blockUI({target: ".event-skill-form", animate: !0});
          
        $.ajax({
            url: 'venues?id_event=' + $(this).val()
        })
            .done(function (venues) {
                var select2 = $('#eventskill-id_venue_section');

                select2.empty();
                select2.append('<option></option>');
                $.each(venues, function (index, value) {
                    select2.append('<option value="' + index + '">' + value + '</option>');
                });
            })
            .always(function () {
                App.unblockUI(".event-skill-form");
            });
    })
JS;

$this->registerJs($js);
?>
<div class="row">
    <div class="col-sm-12 col-lg-12">
        <div class="event-skill-form">
            <div class="portlet light bordered">
                <div class="portlet-body form">
                    <?php $form = ActiveForm::begin(['type' => ActiveForm::TYPE_HORIZONTAL, 'formConfig' => ['labelSpan' => 3]]); ?>
                    <p class="text-right">
                        <?= Html::a(Html::icon('menu-left') . ' ' . Yii::t('app', 'Voltar'), ['index', 'EventSkillSearch' => ['id_event' => $model->id_event]], ['class' => 'btn default']) ?>
                    </p>

                    <?= $model->id_event_skill ? $form->field($model, 'id_event_skill')->staticInput() : ''; ?>

                    <?= $form->field($model, 'id_event', ['staticValue' => "ID:{$model->id_event} - " . $model->event->name])->staticInput(); ?>

                    <?php if ($model->isNewRecord) : ?>

                        <?= $form->field($model, 'id_skill')->widget(Select2::className(), [
                            'data' => Skill::find()
                                ->select(['id_skill', 'name' => new \yii\db\Expression('CONCAT("ID:",id_skill,\' - \',name)')])
                                ->createCommand()
                                ->queryAll(\PDO::FETCH_KEY_PAIR),
                            'options' => ['placeholder' => ''],
                            'pluginOptions' => [
                                'allowClear' => true,
                            ],
                        ]); ?>

                    <?php else : ?>

                        <?= $form->field($model, 'id_skill', ['staticValue' => "ID:{$model->id_skill} - " . $model->skill->name])->staticInput(); ?>

                    <?php endif; ?>

                    <?= $form->field($model, 'name')->textInput(['maxlength' => true]) ?>

                    <?= $form->field($model, 'id_cluster')->widget(Select2::className(), [
                        'data' => Cluster::find()
                            ->select(['id_cluster', 'name' => new \yii\db\Expression('CONCAT("ID:",id_cluster,\' - \',name)')])
                            ->createCommand()
                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                        'options' => ['placeholder' => ''],
                        'pluginOptions' => [
                            'allowClear' => true,
                        ],
                    ]); ?>
                    <?= $form->field($model, 'id_competition_type')->widget(Select2::className(), [
                        'data' => CompetitionType::find()
                            ->select(['id_competition_type', 'name' => new \yii\db\Expression('CONCAT("ID:",id_competition_type,\' - \',name)')])
                            ->createCommand()
                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                        'options' => ['placeholder' => ''],
                        'pluginOptions' => [
                            'allowClear' => true,
                        ],
                    ]); ?>

                    <?= $form->field($model, 'id_venue_section')->widget(Select2::className(), [
                        'data' => VenueSection::find()
                            ->select(['id_venue_section', 'name' => new \yii\db\Expression('CONCAT("ID:",id_venue_section,\' - \',name)')])
                            ->andFilterWhere(['id_event' => $model->id_event])
                            ->createCommand()
                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                        'options' => ['placeholder' => ''],
                        'pluginOptions' => [
                            'allowClear' => true,
                        ],
                    ]); ?>

                    <?= $form->field($model, 'date_born_start')->widget(DateControl::className(), [
                        'type' => DateControl::FORMAT_DATE,
                        'widgetOptions' => [
                            'removeButton' => false,
                            'pluginOptions' => [
                                'autoclose' => true,
                            ],
                        ],
                    ]); ?>

                    <?= $form->field($model, 'date_born_end')->widget(DateControl::className(), [
                        'type' => DateControl::FORMAT_DATE,
                        'widgetOptions' => [
                            'removeButton' => false,
                            'pluginOptions' => [
                                'autoclose' => true,
                            ],
                        ],
                    ]); ?>

                    <?= $form->field($model, 'notes')->textarea(['rows' => 6]) ?>

                    <?= $this->render('@layouts/_btnFormActions') ?>
                    <?php ActiveForm::end(); ?>

                </div>
            </div>
        </div>
    </div>
</div>
