<?php

use app\helpers\ActionColumn;
use kartik\datecontrol\DateControl;
use kartik\grid\GridView;
use kartik\helpers\Html;
use kartik\widgets\Select2;
use yii\helpers\ArrayHelper;

/* @var $this yii\web\View */
/* @var $searchModel app\models\search\EventSkillSearch */
/* @var $dataProvider yii\data\ActiveDataProvider */

$this->title = Yii::t('app', 'Gerir Eventos/Profissões');
$this->params['breadcrumbs'][] = $this->title;
$id_event = ArrayHelper::getValue(Yii::$app->request->queryParams, 'EventSkillSearch.id_event');
$gridParams = \app\helpers\IndexGridHelper::gridParams($this, Yii::t('app', 'Evento/Secção'), ['create', 'id_event' => $id_event]);
?>
<div class="event-skill-index">
    <div class="portlet light bordered">
        <div class="portlet-body form">
            <p>
                <?= $this->render('_search', ['model' => $searchModel]) ?>
            </p>

            <?php if ($searchModel->id_event) : ?>
                <hr>
                <div class="row">
                    <div class="col-xs-12">
                        <?= GridView::widget([
                            'dataProvider' => $dataProvider,
                            'filterModel' => $searchModel,
                            'columns' => [

                                [
                                    'attribute' => 'id_event_skill',
                                    'headerOptions' => ['class' => 'col-xs-1', 'style' => 'font-size:90%;'],
                                    'contentOptions' => ['class' => 'col-xs-1', 'style' => 'font-size:90%;'],
                                    'format' => 'text',
                                    'filter' => Html::activeTextInput($searchModel, 'id_event_skill', ['class' => 'form-control input-sm']),
                                ],
                                [
                                    'headerOptions' => ['style' => 'font-size:90%;'],
                                    'contentOptions' => ['style' => 'font-size:90%;'],
                                    'attribute' => 'id_event',
                                    'filter' => false,
                                    'value' => function ($model) {
                                        if ($model->id_event) {
                                            return "ID:{$model->id_event} - {$model->event->name}";
                                        }

                                        return null;
                                    },
                                ],
                                [
                                    'headerOptions' => ['style' => 'font-size:90%;'],
                                    'contentOptions' => ['style' => 'font-size:90%;'],
                                    'attribute' => 'id_skill',
                                    'filter' => Select2::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'id_skill',
                                        'options' => ['placeholder' => ''],
                                        'size' => Select2::SMALL,
                                        'pluginOptions' => [
                                            'allowClear' => true,
                                        ],
                                        'data' => \app\models\Skill::find()
                                            ->select(['id_skill', 'name' => new \yii\db\Expression('CONCAT("ID:",id_skill,\' - \',name)')])
                                            ->createCommand()
                                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    ]),
                                    'value' => function ($model) {
                                        if ($model->id_skill) {
                                            return "ID:{$model->id_skill} - {$model->skill->name}";
                                        }

                                        return null;
                                    },
                                ],
                                [
                                    'attribute' => 'name',
                                    'headerOptions' => ['style' => 'font-size:90%;'],
                                    'contentOptions' => ['style' => 'font-size:90%;'],
                                    'format' => 'text',
                                    'filter' => Html::activeTextInput($searchModel, 'name', ['class' => 'form-control input-sm']),
                                ],

                                [
                                    'headerOptions' => ['style' => 'font-size:90%;'],
                                    'contentOptions' => ['style' => 'font-size:90%;'],
                                    'attribute' => 'id_cluster',
                                    'filter' => Select2::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'id_cluster',
                                        'options' => ['placeholder' => ''],
                                        'size' => Select2::SMALL,
                                        'pluginOptions' => [
                                            'allowClear' => true,
                                        ],
                                        'data' => \app\models\Cluster::find()
                                            ->select(['id_cluster', 'name' => new \yii\db\Expression('CONCAT("ID:",id_cluster,\' - \',name)')])
                                            ->createCommand()
                                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    ]),
                                    'value' => function ($model) {
                                        if ($model->id_cluster) {
                                            return "ID:{$model->id_cluster} - {$model->cluster->name}";
                                        }

                                        return null;
                                    },
                                ],
                                [
                                    'headerOptions' => ['style' => 'font-size:90%;'],
                                    'contentOptions' => ['style' => 'font-size:90%;'],
                                    'attribute' => 'id_competition_type',
                                    'filter' => Select2::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'id_competition_type',
                                        'options' => ['placeholder' => ''],
                                        'size' => Select2::SMALL,
                                        'pluginOptions' => [
                                            'allowClear' => true,
                                        ],
                                        'data' => \app\models\CompetitionType::find()
                                            ->select(['id_competition_type', 'name' => new \yii\db\Expression('CONCAT("ID:",id_competition_type,\' - \',name)')])
                                            ->createCommand()
                                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    ]),
                                    'value' => function ($model) {
                                        if ($model->id_competition_type) {
                                            return "ID:{$model->id_competition_type} - {$model->competitionType->name}";
                                        }

                                        return null;
                                    },
                                ],
                                [
                                    'headerOptions' => ['style' => 'font-size:90%;'],
                                    'contentOptions' => ['style' => 'font-size:90%;'],
                                    'attribute' => 'id_venue_section',
                                    'filter' => Select2::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'id_venue_section',
                                        'options' => ['placeholder' => ''],
                                        'size' => Select2::SMALL,
                                        'pluginOptions' => [
                                            'allowClear' => true,
                                        ],
                                        'data' => \app\models\VenueSection::find()
                                            ->select(['id_venue_section', 'name' => new \yii\db\Expression('CONCAT("ID:",id_venue_section,\' - \',name)')])
                                            ->createCommand()
                                            ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    ]),
                                    'value' => function ($model) {
                                        if ($model->id_venue_section) {
                                            return "ID:{$model->id_venue_section} - {$model->venueSection->name}";
                                        }

                                        return null;
                                    },
                                ],

                                [
                                    'attribute' => 'date_born_start',
                                    'headerOptions' => ['class' => 'col-xs-1', 'style' => 'font-size:90%;'],
                                    'contentOptions' => ['class' => 'col-xs-1', 'style' => 'font-size:90%;'],
                                    'filter' => DateControl::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'date_born_start',
                                        'type' => DateControl::FORMAT_DATE,
                                        'widgetOptions' => [
                                            'type' => \kartik\widgets\DateTimePicker::TYPE_INPUT,
                                            'size' => 'sm',
                                            'pluginOptions' => [
                                                'autoclose' => true,
                                            ],
                                        ],
                                    ]),
                                ],
                                [
                                    'attribute' => 'date_born_end',
                                    'headerOptions' => ['class' => 'col-xs-1', 'style' => 'font-size:90%;'],
                                    'contentOptions' => ['class' => 'col-xs-1', 'style' => 'font-size:90%;'],
                                    'filter' => DateControl::widget([
                                        'model' => $searchModel,
                                        'attribute' => 'date_born_end',
                                        'type' => DateControl::FORMAT_DATE,
                                        'widgetOptions' => [
                                            'type' => \kartik\widgets\DateTimePicker::TYPE_INPUT,
                                            'size' => 'sm',
                                            'pluginOptions' => [
                                                'autoclose' => true,
                                            ],
                                        ],
                                    ]),
                                ],

                                [
                                    'class' => ActionColumn::class,
                                    'hiddenFromExport' => true,
                                    'headerOptions' => ['style' => 'font-size:90%;'],
                                    'contentOptions' => ['style' => ['white-space' => 'nowrap'],
                                                         'class' => 'actions-column'],
                                ],

                            ],
                            'containerOptions' => $gridParams['containerOptions'],
                            'headerRowOptions' => $gridParams['headerRowOptions'],
                            'filterRowOptions' => $gridParams['filterRowOptions'],
                            'responsiveWrap' => $gridParams['responsiveWrap'],
                            'responsive' => $gridParams['responsive'],
                            'toolbar' => $gridParams['toolbar'],
                            'export' => $gridParams['export'],
                            'exportConfig' => $gridParams['exportConfig'],
                            'bordered' => $gridParams['bordered'],
                            'striped' => $gridParams['striped'],
                            'layout' => $gridParams['layout'],
                        ]); ?>
                    </div>
                </div>
            <?php endif; ?>
        </div>
    </div>
</div>
