<?php

use app\components\enum\EnumBoolSimNao;
use app\models\Cycle;
use app\models\EventKind;
use kartik\datecontrol\DateControl;
use app\helpers\ActionColumn;
use kartik\grid\GridView;
use kartik\helpers\Html;
use kartik\widgets\Select2;

/* @var $this yii\web\View */
/* @var $searchModel app\models\search\EventSearch */
/* @var $dataProvider yii\data\ActiveDataProvider */

$this->title = Yii::t('app', 'Gerir Eventos');
$this->params['breadcrumbs'][] = $this->title;
$gridParams = \app\helpers\IndexGridHelper::gridParams($this, Yii::t('app', 'Evento'));
?>
<div class="event-index">
    <div class="portlet light bordered">
        <div class="portlet-body form">

            <?= GridView::widget([
                'dataProvider' => $dataProvider,
                'filterModel' => $searchModel,
                'columns' => [

                    [
                        'attribute' => 'id_event',
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'format' => 'text',
                        'filter' => Html::activeTextInput($searchModel, 'id_event', ['class' => 'form-control input-sm']),
                    ],
                    [
                        'attribute' => 'name',
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'format' => 'text',
                        'filter' => Html::activeTextInput($searchModel, 'name', ['class' => 'form-control input-sm']),
                    ],

                    [
                        'headerOptions' => ['class' => 'col-xs-3', 'style' => 'font-size:90%;'],
                        'contentOptions' => ['class' => 'col-xs-3', 'style' => 'font-size:90%;'],
                        'attribute' => 'id_cycle',
                        'filter' => Select2::widget([
                            'model' => $searchModel,
                            'attribute' => 'id_cycle',
                            'options' => ['placeholder' => ''],
                            'size' => Select2::SMALL,
                            'pluginOptions' => [
                                'allowClear' => true,
                            ],
                            'data' => Cycle::find()
                                ->select(['id_cycle', 'name' => new \yii\db\Expression('CONCAT("ID:",id_cycle,\' - \',name)')])
                                ->createCommand()
                                ->queryAll(\PDO::FETCH_KEY_PAIR),
                        ]),
                        'value' => function ($model) {
                            if ($model->cycle) {
                                return "ID:{$model->id_cycle} - {$model->cycle->name}";
                            }

                            return null;
                        },
                    ],
                    [
                        'headerOptions' => ['class' => 'col-xs-3', 'style' => 'font-size:90%;'],
                        'contentOptions' => ['class' => 'col-xs-3', 'style' => 'font-size:90%;'],
                        'attribute' => 'id_event_kind',
                        'filter' => Select2::widget([
                            'model' => $searchModel,
                            'attribute' => 'id_event_kind',
                            'options' => ['placeholder' => ''],
                            'size' => Select2::SMALL,
                            'pluginOptions' => [
                                'allowClear' => true,
                            ],
                            'data' => EventKind::find()
                                ->select(['id_event_kind', 'name' => new \yii\db\Expression('CONCAT("ID:",id_event_kind,\' - \',name)')])
                                ->createCommand()
                                ->queryAll(\PDO::FETCH_KEY_PAIR),
                        ]),
                        'value' => function ($model) {
                            if ($model->cycle) {
                                return "ID:{$model->id_event_kind} - {$model->eventKind->name}";
                            }

                            return null;
                        },
                    ],
                    [
                        'attribute' => 'date_start',
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'filter' => DateControl::widget([
                            'model' => $searchModel,
                            'attribute' => 'date_start',
                            'type' => DateControl::FORMAT_DATE,
                            'widgetOptions' => [
                                'size' => 'sm',
                                'pluginOptions' => [
                                    'autoclose' => true,
                                ],
                            ],
                        ]),
                    ],
                    [
                        'attribute' => 'date_end',
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'filter' => DateControl::widget([
                            'model' => $searchModel,
                            'attribute' => 'date_end',
                            'type' => DateControl::FORMAT_DATE,
                            'widgetOptions' => [
                                'size' => 'sm',
                                'pluginOptions' => [
                                    'autoclose' => true,
                                ],
                            ],
                        ]),
                    ],
                    [
                        'attribute' => 'active',
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'filter' => Html::activeDropDownList($searchModel, 'active', EnumBoolSimNao::$listEnumLabels, ['class' => 'form-control input-sm', 'prompt' => ' ']),
                        'format' => 'boolean',
                    ],

                    [
                        'class' => ActionColumn::class,
                        'hiddenFromExport' => true,
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => ['white-space' => 'nowrap'],
                                             'class' => 'actions-column'],
                    ],

                ],
                'containerOptions' => $gridParams['containerOptions'],
                'headerRowOptions' => $gridParams['headerRowOptions'],
                'filterRowOptions' => $gridParams['filterRowOptions'],
                'responsiveWrap' => $gridParams['responsiveWrap'],
                'responsive' => $gridParams['responsive'],
                'toolbar' => $gridParams['toolbar'],
                'export' => $gridParams['export'],
                'exportConfig' => $gridParams['exportConfig'],
                'bordered' => $gridParams['bordered'],
                'striped' => $gridParams['striped'],
                'layout' => $gridParams['layout'],
            ]); ?>
        </div>
    </div>
</div>
