<?php

use app\components\enum\EnumBoolSimNao;
use app\helpers\ActionColumn;
use kartik\grid\GridView;
use kartik\helpers\Html;
use kartik\widgets\Select2;
use rmrevin\yii\fontawesome\FA;

/* @var $this yii\web\View */
/* @var $searchModel app\models\search\LoginSearch */
/* @var $dataProvider yii\data\ActiveDataProvider */

$this->title = Yii::t('app', 'Gerir Logins de Acesso');
$this->params['breadcrumbs'][] = $this->title;
$gridParams = \app\helpers\IndexGridHelper::gridParams($this, Yii::t('app', 'Logins de Acesso'));
?>
<div class="login-index">
    <div class="portlet light bordered">
        <div class="portlet-body form">

            <?= GridView::widget([
                'dataProvider' => $dataProvider,
                'filterModel' => $searchModel,
                'columns' => [

                    [
                        'attribute' => 'id_participant',
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'format' => 'text',
                        'filter' => Html::activeTextInput($searchModel, 'id_participant', ['class' => 'form-control input-sm']),
                    ],
                    [
                        'attribute' => 'name',
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'format' => 'text',
                        'filter' => Html::activeTextInput($searchModel, 'name', ['class' => 'form-control input-sm']),
                    ],
                    [
                        'attribute' => 'email',
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'format' => 'text',
                        'filter' => Html::activeTextInput($searchModel, 'email', ['class' => 'form-control input-sm']),
                    ],
                    [
                        'attribute' => 'has_login',
                        'label' => Yii::t('app', 'Login Criado'),
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'format' => 'boolean',
                        'value' => function ($model) {
                            return (bool)$model->id_login;
                        },
                        'filter' => Html::activeDropDownList(
                            $searchModel,
                            'has_login',
                            EnumBoolSimNao::$listEnumLabels,
                            ['class' => 'form-control input-sm', 'prompt' => ' ']
                        ),
                    ],
                    [
                        'attribute' => 'email_verified',
                        'label' => Yii::t('app', 'Email Verificado'),
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'format' => 'boolean',
                        'value' => function ($model) {
                            return $model->login && (bool)$model->login->email_verified;
                        },
                        'filter' => Html::activeDropDownList(
                            $searchModel,
                            'email_verified',
                            EnumBoolSimNao::$listEnumLabels,
                            ['class' => 'form-control input-sm', 'prompt' => ' ']
                        ),
                    ],

                    [
                        'attribute' => 'is_admin',
                        'label' => Yii::t('app', 'Utilizador Admin'),
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'format' => 'boolean',
                        'value' => function ($model) {
                            return $model->login && (int)$model->login->isAdmin;
                        },
                        'filter' => Html::activeDropDownList(
                            $searchModel,
                            'is_admin',
                            EnumBoolSimNao::$listEnumLabels,
                            ['class' => 'form-control input-sm', 'prompt' => ' ']
                        ),
                    ],

                    [
                        'attribute' => 'admin_level',
                        'label' => Yii::t('app', 'Nível de Admin'),
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'format' => 'text',
                        'value' => function ($model) {
                            return $model->login->adminLevel->name ?? null;
                        },
                        'filter' => Select2::widget([
                            'model' => $searchModel,
                            'attribute' => 'admin_level',
                            'options' => ['placeholder' => ''],
                            'size' => Select2::SMALL,
                            'pluginOptions' => [
                                'allowClear' => true,
                            ],
                            'data' => \app\models\AdminLevel::find()
                                ->select(['id_admin_level', 'name'])
                                ->createCommand()
                                ->queryAll(\PDO::FETCH_KEY_PAIR),
                        ]),
                    ],
                    [
                        'class' => ActionColumn::class,
                        'buttons' => [
                            'view' => function ($url, $model) {
                                if (!$model->id_login) {
                                    return '';
                                }

                                return Html::a(
                                    Html::icon('eye-open'),
                                    ['view', 'id' => $model->id_login],
                                    ['title' => Yii::t('app', 'Visualizar')]
                                );
                            },
                            'update' => function ($url, $model) {
                                if (!$model->id_login) {
                                    return '';
                                }

                                return Html::a(
                                    Html::icon('pencil'),
                                    ['update', 'id' => $model->id_login],
                                    ['title' => Yii::t('app', 'Editar')]
                                );
                            },
                            'create-login' => function ($url, $model) {
                                if ($model->id_login) {
                                    return '';
                                }

                                return Html::a(
                                    FA::i('lock'),
                                    ['create-login', 'id' => $model->id_participant],
                                    ['title' => Yii::t('app', 'Gerar Login')]
                                );
                            },
                        ],
                        'template' => '{view} {update} {create-login}',
                    ],


                ],
                'containerOptions' => $gridParams['containerOptions'],
                'headerRowOptions' => $gridParams['headerRowOptions'],
                'filterRowOptions' => $gridParams['filterRowOptions'],
                'responsiveWrap' => $gridParams['responsiveWrap'],
                'responsive' => $gridParams['responsive'],
                'toolbar' => '{export}',
                'export' => $gridParams['export'],
                'exportConfig' => $gridParams['exportConfig'],
                'bordered' => $gridParams['bordered'],
                'striped' => $gridParams['striped'],
                'layout' => $gridParams['layout'],
            ]); ?>
        </div>
    </div>
</div>
