<?php

use app\helpers\ActionColumn;
use kartik\grid\GridView;
use kartik\helpers\Html;

/* @var $this yii\web\View */
/* @var $dataProvider yii\data\ActiveDataProvider */

$this->title = Yii::t('app', 'Dados do Participante');
$this->params['breadcrumbs'][] = $this->title;
$gridParams = \app\helpers\IndexGridHelper::gridParams($this, Yii::t('app', 'Participante'));
?>
<div class="participant-index">
    <div class="portlet light bordered">
        <div class="portlet-body form">

            <?= GridView::widget([
                'dataProvider' => $dataProvider,
                'columns' => [
                    [
                        'class' => ActionColumn::class,
                        'buttons' => [
                            'view' => function () {
                                return Html::a(Html::icon('eye-open'), ['view'], ['title' => Yii::t('app', 'Visualizar')]);
                            },
                            'update' => function ($url, $model) {
                                /** @var \app\models\ParticipantProfile $model */
                                if (!$model->canUpdate()) {
                                    return null;
                                }

                                return Html::a(Html::icon('pencil'), ['update'], ['title' => Yii::t('app', 'Editar')]);
                            },
                            'upload' => function ($url, $model) {
                                /** @var \app\models\ParticipantProfile $model */
                                if (!$model->canUpdate()) {
                                    return null;
                                }

                                return Html::a(Html::icon('user'), ['upload-picture'], ['title' => Yii::t('app', 'Upload Foto')]);
                            },
                        ],
                        'template' => '{view} {update} {upload}',
                    ],
                    [
                        'attribute' => 'id_participant',
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'format' => 'text',
                    ],
                    [
                        'attribute' => 'name',
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'format' => 'text',
                    ],
                    [
                        'attribute' => 'nickname',
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'format' => 'text',
                    ],
                    [
                        'attribute' => 'email',
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'format' => 'email',
                    ],
                    [
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'attribute' => 'id_entity_current',
                        'value' => function ($model) {
                            if ($model->id_entity_current) {
                                return "ID:{$model->id_entity_current} - {$model->entityCurrent->name}";
                            }

                            return null;
                        },
                    ],
                    [
                        'attribute' => 'hasImageRights',
                        'label' => Yii::t('app', 'Dados Completos'),
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'format' => 'labelBoolean',
                        'value' => function ($model) {
                            return (bool)$model->image_rights_upload;
                        },
                    ],
                    [
                        'attribute' => 'picture',
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'format' => 'labelBoolean',
                        'value' => function ($model) {
                            return (bool)$model->picture;
                        },
                    ],
                    [
                        'headerOptions' => ['class' => 'col-xs-1', 'style' => 'font-size:90%;'],
                        'contentOptions' => ['class' => 'col-xs-1', 'style' => 'font-size:90%;'],
                        'attribute' => 'active',
                        'format' => 'boolean',
                    ],
                ],
                'containerOptions' => $gridParams['containerOptions'],
                'headerRowOptions' => $gridParams['headerRowOptions'],
                'filterRowOptions' => $gridParams['filterRowOptions'],
                'responsiveWrap' => $gridParams['responsiveWrap'],
                'responsive' => $gridParams['responsive'],
                'toolbar' => false,
                'export' => false,
                'exportConfig' => false,
                'bordered' => $gridParams['bordered'],
                'striped' => $gridParams['striped'],
                'layout' => str_replace('{summary}', '', $gridParams['layout']),
            ]); ?>

            <div class="note note-warning">
                <?= Yii::t('app', 'É necessário que todos os dados sejam preenchidos na ficha do participante e que seja feito o upload da foto do mesmo. Verifique a coluna "Dados Completos" e "Foto", que deve estar "Sim".') ?><br><br>
                <?= Yii::t('app', 'No caso do "Gestor Plataforma" que não tenha outra função no Evento, não é necessário que seja preenchida a totalidade dos dados de participante.') ?>
            </div>
        </div>
    </div>
</div>
