<?php

use app\components\enum\EnumBoolSimNao;
use app\helpers\ActionColumn;
use kartik\grid\GridView;
use kartik\helpers\Html;
use kartik\widgets\Select2;
use rmrevin\yii\fontawesome\FA;

/* @var $this yii\web\View */
/* @var $searchModel app\models\search\ParticipantSearch */
/* @var $dataProvider yii\data\ActiveDataProvider */

$this->title = Yii::t('app', 'Gerir Participantes');
$this->params['breadcrumbs'][] = $this->title;
$gridParams = \app\helpers\IndexGridHelper::gridParams($this, Yii::t('app', 'Participante'));
$gridParams['toolbar'][1] = Html::a(Html::icon('plus') . Yii::t('app', 'Adicionar (Básico)'), ['create-basic'], [
        'class' => 'btn btn-info',
        'title' => Yii::t('app', 'Registar Participante Básico'),
    ]) . $gridParams['toolbar'][1];
?>
<div class="participant-index">
    <div class="portlet light bordered">
        <div class="portlet-body form">

            <?= GridView::widget([
                'dataProvider' => $dataProvider,
                'filterModel' => $searchModel,
                'columns' => [

                    [
                        'attribute' => 'id_participant',
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'format' => 'text',
                        'filter' => Html::activeTextInput($searchModel, 'id_participant', ['class' => 'form-control input-sm']),
                    ],
                    [
                        'attribute' => 'name',
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'format' => 'text',
                        'filter' => Html::activeTextInput($searchModel, 'name', ['class' => 'form-control input-sm']),
                    ],
                    [
                        'attribute' => 'nickname',
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'format' => 'text',
                        'filter' => Html::activeTextInput($searchModel, 'nickname', ['class' => 'form-control input-sm']),
                    ],
                    [
                        'attribute' => 'email',
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'format' => 'email',
                        'filter' => Html::activeTextInput($searchModel, 'email', ['class' => 'form-control input-sm']),
                    ],
                    [
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'attribute' => 'id_entity_current',
                        'filter' => Select2::widget([
                            'model' => $searchModel,
                            'attribute' => 'id_entity_current',
                            'options' => ['placeholder' => ''],
                            'size' => Select2::SMALL,
                            'pluginOptions' => [
                                'allowClear' => true,
                            ],
                            'data' => \app\models\Entity::find()
                                ->select(['id_entity', 'name' => new \yii\db\Expression('CONCAT("ID:",id_entity,\' - \',name)')])
                                ->createCommand()
                                ->queryAll(\PDO::FETCH_KEY_PAIR),
                        ]),
                        'value' => function ($model) {
                            if ($model->id_entity_current) {
                                return "ID:{$model->id_entity_current} - {$model->entityCurrent->name}";
                            }

                            return null;
                        },
                    ],
                    [
                        'attribute' => 'picture',
                        'headerOptions' => ['style' => 'font-size:90%;'],
                        'contentOptions' => ['style' => 'font-size:90%;'],
                        'format' => 'boolean',
                        'value' => function ($model) {
                            return (bool)$model->picture;
                        },
                        'filter' => Html::activeDropDownList($searchModel, 'hasPicture', EnumBoolSimNao::$listEnumLabels, ['class' => 'form-control input-sm', 'prompt' => ' ']),
                    ],
                    [
                        'headerOptions' => ['class' => 'col-xs-1', 'style' => 'font-size:90%;'],
                        'contentOptions' => ['class' => 'col-xs-1', 'style' => 'font-size:90%;'],
                        'attribute' => 'active',
                        'filter' => Html::activeDropDownList($searchModel, 'active', EnumBoolSimNao::$listEnumLabels, ['class' => 'form-control input-sm', 'prompt' => ' ']),
                        'format' => 'boolean',
                    ],

                    [
                        'class' => ActionColumn::class,
                        'buttons' => [
                            'upload' => function ($url, $model) {
                                return Html::a(Html::icon('user'), ['upload-picture', 'id' => $model->id_participant], ['title' => Yii::t('app', 'Upload Foto')]);
                            },
                            'update-basic' => function ($url, $model) {
                                return Html::a(
                                    FA::i('pencil-square-o'),
                                    ['update-basic', 'id' => $model->id_participant],
                                    ['title' => Yii::t('app', 'Editar (Básico)')]
                                );
                            },
                        ],
                        'template' => '{view} {update} {update-basic} {upload} {delete}',
                    ],

                ],
                'containerOptions' => $gridParams['containerOptions'],
                'headerRowOptions' => $gridParams['headerRowOptions'],
                'filterRowOptions' => $gridParams['filterRowOptions'],
                'responsiveWrap' => $gridParams['responsiveWrap'],
                'responsive' => $gridParams['responsive'],
                'toolbar' => $gridParams['toolbar'],
                'export' => $gridParams['export'],
                'exportConfig' => $gridParams['exportConfig'],
                'bordered' => $gridParams['bordered'],
                'striped' => $gridParams['striped'],
                'layout' => $gridParams['layout'],
            ]); ?>
        </div>
    </div>
</div>
