<?php

use app\helpers\ActionColumn;
use kartik\grid\GridView;
use kartik\helpers\Html;

/* @var $this yii\web\View */
/* @var $searchModel app\models\search\ParticipantManagedSearch */
/* @var $dataProvider yii\data\ActiveDataProvider */
/* @var $platformManager \app\models\Participant */

$this->title = Yii::t('app', 'Dados de Participantes');
$this->params['breadcrumbs'][] = $this->title;
$gridParams = \app\helpers\IndexGridHelper::gridParams($this, Yii::t('app', 'Dados de Participantes'));
?>
<div class="participant-index">
    <div class="portlet light bordered">
        <div class="portlet-body form">

            <?php if (!$searchModel->event) : ?>

                <h2><?= Yii::t('app', 'Não existe nenhum evento activo.') ?></h2>

            <?php else : ?>

                <?= $this->render('_searchParticipants', ['model' => $searchModel, 'platformManager' => $platformManager,]) ?>

                <?php if ($searchModel->id_entity) : ?>
                    <?= GridView::widget([
                        'dataProvider' => $dataProvider,
                        'columns' => [

                            [
                                'class' => ActionColumn::class,
                                'buttons' => [
                                    'view' => function ($url, $model) use ($searchModel) {
                                        return Html::a(
                                            Html::icon('eye-open'),
                                            ['view-participant', 'id' => $model->id_participant, 'id_entity' => $searchModel->id_entity],
                                            ['title' => Yii::t('app', 'Visualizar')]
                                        );
                                    },
                                    'update' => function ($url, $model) use ($searchModel) {
                                        return Html::a(
                                            Html::icon('pencil'),
                                            ['update-participant', 'id' => $model->id_participant, 'id_entity' => $searchModel->id_entity],
                                            ['title' => Yii::t('app', 'Editar')]
                                        );
                                    },
                                    'upload' => function ($url, $model) use ($searchModel) {
                                        return Html::a(
                                            Html::icon('user'),
                                            ['upload-picture', 'id' => $model->id_participant, 'id_entity' => $searchModel->id_entity],
                                            ['title' => Yii::t('app', 'Upload Foto')]
                                        );
                                    },
                                ],
                                'template' => '{view} {update} {upload} {delete}',
                            ],

                            [
                                'attribute' => 'id_participant',
                                'headerOptions' => ['style' => 'font-size:90%;'],
                                'contentOptions' => ['style' => 'font-size:90%;'],
                                'format' => 'text',
                            ],
                            [
                                'attribute' => 'participant.name',
                                'headerOptions' => ['style' => 'font-size:90%;'],
                                'contentOptions' => ['style' => 'font-size:90%;'],
                                'format' => 'text',
                            ],
                            [
                                'attribute' => 'hasImageRights',
                                'label' => Yii::t('app', 'Dados Completos'),
                                'headerOptions' => ['style' => 'font-size:90%;'],
                                'contentOptions' => ['style' => 'font-size:90%;'],
                                'format' => 'labelBoolean',
                                'value' => function ($model) {
                                    return (bool)$model->participant->image_rights_upload;
                                },
                            ],
                            [
                                'attribute' => 'participant.picture',
                                'headerOptions' => ['style' => 'font-size:90%;'],
                                'contentOptions' => ['style' => 'font-size:90%;'],
                                'format' => 'labelBoolean',
                                'value' => function ($model) {
                                    return (bool)$model->participant->picture;
                                },
                            ],
                            [
                                'headerOptions' => ['style' => 'font-size:90%;'],
                                'contentOptions' => ['style' => 'font-size:90%;'],
                                'attribute' => 'id_event_participant',
                            ],

                            [
                                'headerOptions' => ['style' => 'font-size:90%;'],
                                'contentOptions' => ['style' => 'font-size:90%;'],
                                'attribute' => 'id_event_skill',
                                'value' => function ($model) {
                                    if ($model->id_event_skill) {
                                        return "ID:{$model->id_event_skill} - {$model->eventSkill->name}";
                                    }

                                    return null;
                                },
                            ],
                            [
                                'headerOptions' => ['style' => 'font-size:90%;'],
                                'contentOptions' => ['style' => 'font-size:90%;'],
                                'attribute' => 'id_participant_type',
                                'value' => function ($model) {
                                    if ($model->id_participant_type) {
                                        return "ID:{$model->id_participant_type} - {$model->participantType->name}";
                                    }

                                    return null;
                                },
                            ],
                            [
                                'headerOptions' => ['style' => 'font-size:90%;'],
                                'contentOptions' => ['style' => 'font-size:90%;'],
                                'attribute' => 'id_event_participant_state',
                                'value' => function ($model) {
                                    if ($model->id_event_participant_state) {
                                        return "ID:{$model->id_event_participant_state} - {$model->eventParticipantState->name}";
                                    }

                                    return null;
                                },
                            ],
                        ],
                        'containerOptions' => $gridParams['containerOptions'],
                        'headerRowOptions' => $gridParams['headerRowOptions'],
                        'filterRowOptions' => $gridParams['filterRowOptions'],
                        'responsiveWrap' => $gridParams['responsiveWrap'],
                        'responsive' => $gridParams['responsive'],
                        'toolbar' => false,
                        'export' => false,
                        'exportConfig' => $gridParams['exportConfig'],
                        'bordered' => $gridParams['bordered'],
                        'striped' => $gridParams['striped'],
                        'layout' => $gridParams['layout'],
                    ]); ?>

                    <div class="note note-warning">
                        <?= Yii::t('app', 'É necessário que os dados de todos os participantes sejam preenchidos na ficha do participante e que seja feito o upload da foto do mesmo. Verifique a coluna "Dados Completos" e "Foto" de todos os participantes da entidade, que deve estar "Sim".') ?>
                    </div>
                <?php endif; ?>
            <?php endif; ?>
        </div>
    </div>
</div>
