<?php

use app\helpers\ActiveForm;
use app\helpers\ConstantsHelper;
use app\models\Zone1;
use app\models\Zone2;
use app\models\Zone3;
use kartik\datecontrol\DateControl;
use kartik\helpers\Html;
use kartik\widgets\FileInput;
use kartik\widgets\Select2;
use yii\helpers\ArrayHelper;
use yii\widgets\MaskedInput;

/** @var $this yii\web\View */
/** @var $model app\models\ParticipantProfile */

$this->title = Yii::t('app', 'Editar Participante: {nameAttribute}', [
    'nameAttribute' => "ID:{$model->id_participant} - " . $model->name,
]);
$this->params['breadcrumbs'][] = ['label' => Yii::t('app', 'Dados do Participante'), 'url' => ['index']];
$this->params['breadcrumbs'][] = ['label' => $model->name, 'url' => ['view', 'id' => $model->id_participant]];
$this->params['breadcrumbs'][] = Yii::t('app', 'Editar');

\app\assets\ParticipantAsset::register($this);

$zones3 = Zone3::find()
    ->select(['id_zone3', 'name' => new \yii\db\Expression('CONCAT("ID:",id_zone3,\' - \',name)')])
    ->andWhere(['id_zone2' => $model->id_zone2])
    ->createCommand()
    ->queryAll(\PDO::FETCH_KEY_PAIR);

$id_entity = ArrayHelper::getValue(Yii::$app->request->queryParams, 'id_entity');
?>
<div class="participant-update">
    <div class="row">
        <div class="col-sm-12 col-lg-12">
            <div class="participant-form">
                <div class="portlet light bordered">
                    <div class="portlet-body form">
                        <?php $form = ActiveForm::begin([
                            'options' => ['enctype' => 'multipart/form-data'],
                            'type' => ActiveForm::TYPE_HORIZONTAL,
                            'formConfig' => ['labelSpan' => 3],
                            'enableAjaxValidation' => true,
                        ]); ?>

                        <p class="text-right">
                            <?= Html::a(
                                Html::icon('menu-left') . ' ' . Yii::t('app', 'Voltar'),
                                ['participants', 'ParticipantManagedSearch' => ['id_entity' => $id_entity]],
                                ['class' => 'btn default']
                            ) ?>
                        </p>

                        <?= $form->field($model, 'name')->textInput(['maxlength' => true]) ?>

                        <?= $form->field($model, 'nickname')->textInput(['maxlength' => true]) ?>

                        <?= $form->field($model, 'email')->textInput(['maxlength' => true]) ?>

                        <?= $form->field($model, 'id_nationality')->widget(Select2::className(), [
                            'data' => \app\models\Nationality::find()
                                ->select(['id_nationality', 'name' => new \yii\db\Expression('CONCAT("ID:",id_nationality,\' - \',name)')])
                                ->createCommand()
                                ->queryAll(\PDO::FETCH_KEY_PAIR),
                            'options' => ['placeholder' => ''],
                            'pluginOptions' => [
                                'allowClear' => true,
                            ],
                        ]); ?>

                        <?php if ($model->isCompetitorEnrolledToEvent()) : ?>

                            <?= $form->field($model, 'date_birth')->staticInput(); ?>

                        <?php else : ?>

                            <?= $form->field($model, 'date_birth')->widget(DateControl::className(), [
                                'type' => DateControl::FORMAT_DATE,
                                'widgetOptions' => [
                                    'removeButton' => false,
                                    'pluginOptions' => [
                                        'autoclose' => true,
                                    ],
                                ],
                            ]); ?>

                        <?php endif; ?>

                        <?= $form->field($model, 'place_of_birth')->textInput(['maxlength' => true]) ?>

                        <?= $form->field($model, 'id_document_type')->widget(Select2::className(), [
                            'data' => \app\models\DocumentType::find()
                                ->select(['id_document_type', 'name' => new \yii\db\Expression('CONCAT("ID:",id_document_type,\' - \',name)')])
                                ->createCommand()
                                ->queryAll(\PDO::FETCH_KEY_PAIR),
                            'options' => ['placeholder' => ''],
                            'pluginOptions' => [
                                'allowClear' => true,
                            ],
                        ]); ?>

                        <?= $form->field($model, 'identification_number')->textInput(['maxlength' => true]) ?>

                        <?= $form->field($model, 'date_expiration')->widget(DateControl::className(), [
                            'type' => DateControl::FORMAT_DATE,
                            'widgetOptions' => [
                                'removeButton' => false,
                                'pluginOptions' => [
                                    'autoclose' => true,
                                ],
                            ],
                        ]); ?>

                        <?= $form->field($model, 'tax_number')->textInput(['maxlength' => true]) ?>

                        <?= $form->field($model, 'social_security_number')->textInput(['maxlength' => true]) ?>

                        <?= $form->field($model, 'address')->textInput(['maxlength' => true]) ?>

                        <?= $form->field($model, 'city')->textInput(['maxlength' => true]) ?>

                        <?= $form->field($model, 'postal_code')->widget(MaskedInput::class, ['mask' => '9999-999']) ?>

                        <div class="row row-select-zones">
                            <div class="col-md-12">
                                <?= $form->field($model, 'id_zone1')->widget(Select2::className(), [
                                    'data' => Zone1::find()
                                        ->select(['id_zone1', 'name' => new \yii\db\Expression('CONCAT("ID:",id_zone1,\' - \',name)')])
                                        ->createCommand()
                                        ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    'options' => ['placeholder' => ''],
                                    'pluginOptions' => [
                                        'allowClear' => true,
                                    ],
                                ]); ?>
                            </div>
                        </div>

                        <div class="row row-select-zones">
                            <div class="col-md-12">
                                <?= $form->field($model, 'id_zone2')->widget(Select2::className(), [
                                    'data' => Zone2::find()
                                        ->select(['id_zone2', 'name' => new \yii\db\Expression('CONCAT("ID:",id_zone2,\' - \',name)')])
                                        ->andWhere(['id_zone1' => $model->id_zone1])
                                        ->createCommand()
                                        ->queryAll(\PDO::FETCH_KEY_PAIR),
                                    'options' => ['placeholder' => ''],
                                    'pluginOptions' => [
                                        'allowClear' => true,
                                    ],
                                ]); ?>
                            </div>
                        </div>

                        <div class="row row-select-zones row-select-zone3" <?= (!$zones3) ? 'style="display: none;"' : ''; ?> >
                            <div class="col-md-12">
                                <?= $form->field($model, 'id_zone3')->widget(Select2::className(), [
                                    'data' => $zones3,
                                    'options' => ['placeholder' => ''],
                                    'pluginOptions' => [
                                        'allowClear' => true,
                                    ],
                                ]); ?>
                            </div>
                        </div>

                        <?= $form->field($model, 'phone')->textInput(['maxlength' => true]) ?>

                        <?= $form->field($model, 'phone_alternative')->textInput(['maxlength' => true]) ?>

                        <?= $form->field($model, 'id_education')->widget(Select2::className(), [
                            'data' => \app\models\Education::find()
                                ->select(['id_education', 'name' => new \yii\db\Expression('CONCAT("ID:",id_education,\' - \',name)')])
                                ->createCommand()
                                ->queryAll(\PDO::FETCH_KEY_PAIR),
                            'options' => ['placeholder' => ''],
                            'pluginOptions' => [
                                'allowClear' => true,
                            ],
                        ]); ?>

                        <?= $form->field($model, 'id_vocational_skills_type')->widget(Select2::className(), [
                            'data' => \app\models\VocationSkillType::find()
                                ->select(['id_vocational_skills_type', 'name' => new \yii\db\Expression('CONCAT("ID:",id_vocational_skills_type,\' - \',name)')])
                                ->createCommand()
                                ->queryAll(\PDO::FETCH_KEY_PAIR),
                            'options' => ['placeholder' => ''],
                            'pluginOptions' => [
                                'allowClear' => true,
                            ],
                        ]); ?>

                        <?= $form->field($model, 'vocational_skills')->textInput(['maxlength' => true]) ?>

                        <?= $form->field($model, 'id_gender')->radioList(\app\models\Gender::find()
                            ->select(['id_gender', 'name'])
                            ->createCommand()
                            ->queryAll(\PDO::FETCH_KEY_PAIR), ['inline' => true]) ?>

                        <?= $form->field($model, 'tshirt_size')->drop(ConstantsHelper::tShitSizes()) ?>


                        <?php for ($i = 1; $i <= 10; $i++) {
                            $extraAttribute = 'extra' . sprintf('%02d', $i);

                            if (ConstantsHelper::constantHasLabel($extraAttribute)) {
                                echo $form->field($model, $extraAttribute)->textInput(['maxlength' => true]);
                            }
                        } ?>

                        <?= $form->field($model, 'dietary_restriction')->switchSimNao() ?>

                        <?php
                        $display = (!(bool)$model->dietary_restriction) ? 'none' : 'block';
                        for ($i = 1; $i <= 6; $i++) {
                            $drAttribute = 'dr' . sprintf('%02d', $i);
                            if (ConstantsHelper::constantHasLabel($drAttribute)) {
                                echo $form->field($model, $drAttribute, ['options' => ['class' => 'form-group dietary-restriction-item', 'style' => "display: {$display};"]])
                                    ->switchSimNao();
                            }
                        } ?>

                        <?php
                        echo $form->field($model, 'dr_other', ['options' => ['class' => 'form-group dietary-restriction-item', 'style' => "display: {$display};"]])
                            ->textInput(['maxlength' => true]);
                        ?>

                        <?= $form->field($model, 'image_rights_upload', ['addon' => [
                            'append' => [
                                'options' => ['style' => 'cursor:pointer;'],
                                'content' => FileInput::widget([
                                    'model' => $model,
                                    'attribute' => 'image_rights_file',
                                    'pluginOptions' => [
                                        'showPreview' => false,
                                        'showCaption' => false,
                                        'showRemove' => false,
                                        'browseClass' => false,
                                        'showUpload' => false,
                                    ],
                                ])]]])->textInput(['readonly' => true]) ?>

                        <?= $form->field($model, 'id_entity_current')->widget(Select2::className(), [
                            'data' => \app\models\Entity::find()
                                ->select(['id_entity', 'name' => new \yii\db\Expression('CONCAT("ID:",id_entity,\' - \',name)')])
                                ->createCommand()
                                ->queryAll(\PDO::FETCH_KEY_PAIR),
                            'options' => ['placeholder' => ''],
                            'pluginOptions' => [
                                'allowClear' => true,
                            ],
                        ]); ?>

                        <?= $this->render('@layouts/_btnFormActions') ?>
                        <?php ActiveForm::end(); ?>

                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
